@@ -51,8 +51,8 @@
 #include "CacheableObjectXml.hpp"
 #include "CacheableBuiltins.hpp"
 #include "Log.hpp"
+#include "String.hpp"
 #include "Struct.hpp"
-#include "impl/MemoryPressureHandler.hpp"
 #include "impl/SafeConvert.hpp"
 #include "impl/PdxType.hpp"
 #include "impl/EnumInfo.hpp"
@@ -135,7 +135,7 @@ namespace Apache
         // TODO AppDomain should we be able to create a DS directly?
         _GF_MG_EXCEPTION_TRY2
 
-        auto nativeDistributedSystem = native::DistributedSystem::create(marshal_as<std::string>(name),
+        auto nativeDistributedSystem = native::DistributedSystem::create(to_utf8(name),
                                                            config->GetNative());
         nativeDistributedSystem.connect();
 
@@ -401,14 +401,6 @@ namespace Apache
         }
       }
 
-      void DistributedSystem::HandleMemoryPressure(System::Object^ state)
-      {
-        // TODO global - Need single memory pressue event running?
-        ACE_Time_Value dummy(1);
-        MemoryPressureHandler handler;
-        handler.handle_timeout(dummy, nullptr);
-      }
-
       DistributedSystem^ DistributedSystem::Create(native::DistributedSystem* nativeptr)
       {
         auto instance = gcnew DistributedSystem(nativeptr);
@@ -427,7 +419,6 @@ namespace Apache
 
       DistributedSystem::~DistributedSystem()
       {
-        m_memoryPressureHandler->Dispose(nullptr);
       }
 
       void DistributedSystem::registerCliCallback()
