@@ -87,14 +87,8 @@ class APACHE_GEODE_EXPORT AuthenticatedView : public RegionService {
    */
   std::vector<std::shared_ptr<Region>> rootRegions() const override;
 
-  /**
-   * @brief destructor
-   */
-  virtual ~AuthenticatedView();
+  ~AuthenticatedView() override;
 
-  /**
-   * @brief constructors
-   */
   AuthenticatedView(std::shared_ptr<Properties> credentials,
                     std::shared_ptr<Pool> pool, CacheImpl* cacheImpl);
   AuthenticatedView(AuthenticatedView&& other) = default;
