@@ -27,10 +27,6 @@
 #include "GeodeCache.hpp"
 #include "internal/geode_globals.hpp"
 
-/**
- * @file
- */
-
 namespace apache {
 namespace geode {
 namespace client {
@@ -67,9 +63,6 @@ enum class RegionShortcut;
  *
  */
 class APACHE_GEODE_EXPORT Cache : public GeodeCache {
-  /**
-   * @brief public methods
-   */
  public:
   /**
    * Returns the {@link RegionFactory} to create the region.
@@ -183,8 +176,8 @@ class APACHE_GEODE_EXPORT Cache : public GeodeCache {
    *
    * @see RegionService
    * @see PoolFactory#setMultiuserAuthentication(boolean)
-   * @return the {@link RegionService} instance associated with a user and given
-   *         properties.
+   * @return the {@link RegionService} instance associated with a user and
+   * given properties.
    * @throws UnsupportedOperationException
    *           when invoked with multiuser-authentication as false.
    *
@@ -261,16 +254,14 @@ class APACHE_GEODE_EXPORT Cache : public GeodeCache {
   LogLevel getLogLevel();
 
   Cache() = delete;
-  virtual ~Cache();
+  ~Cache() override;
+
   Cache(const Cache& other) = delete;
   Cache& operator=(const Cache& other) = delete;
   Cache(Cache&& other) noexcept;
   Cache& operator=(Cache&& other) noexcept;
 
  private:
-  /**
-   * @brief constructors
-   */
   Cache(const std::shared_ptr<Properties>& dsProp, bool ignorePdxUnreadFields,
         bool readPdxSerialized,
         const std::shared_ptr<AuthInitialize>& authInitialize);
@@ -284,6 +275,7 @@ class APACHE_GEODE_EXPORT Cache : public GeodeCache {
   friend class CacheXmlCreation;
   friend class RegionXmlCreation;
 };
+
 }  // namespace client
 }  // namespace geode
 }  // namespace apache
