@@ -474,7 +474,7 @@ class APACHE_GEODE_EXPORT DiskFailureException : public Exception {
 
 /**
  *@brief Thrown by the persistence manager when the data
- *@brief to be read from disk is corrupt.
+ * to be read from disk is corrupt.
  **/
 class APACHE_GEODE_EXPORT DiskCorruptException : public Exception {
  public:
@@ -812,6 +812,32 @@ class APACHE_GEODE_EXPORT PutAllPartialResultException : public Exception {
   }
 };
 
+/**
+ * @brief Thrown if an operation causes fails due to critical memory threshold
+ *        reached.
+ **/
+class APACHE_GEODE_EXPORT LowMemoryException : public Exception {
+ public:
+  using Exception::Exception;
+  ~LowMemoryException() noexcept override {}
+  std::string getName() const override {
+    return "apache::geode::client::LowMemoryException";
+  }
+};
+
+/**
+ * @brief Thrown if the query monitoring featuring detects the server is running
+ *        low on memory
+ **/
+class APACHE_GEODE_EXPORT QueryExecutionLowMemoryException : public Exception {
+ public:
+  using Exception::Exception;
+  ~QueryExecutionLowMemoryException() noexcept override {}
+  std::string getName() const override {
+    return "apache::geode::client::QueryExecutionLowMemoryException";
+  }
+};
+
 /**
  *@brief Thrown when an error is encountered during an SSL operation.
  **/
