@@ -27,27 +27,27 @@ namespace client {
 enum class PdxFieldTypes {
   UNKNOWN = -1,
   BOOLEAN = 0,
-  BYTE,
-  CHAR,
-  SHORT,
-  INT,
-  LONG,
-  FLOAT,
-  DOUBLE,
-  DATE,
-  STRING,
-  OBJECT,
-  BOOLEAN_ARRAY,
-  CHAR_ARRAY,
-  BYTE_ARRAY,
-  SHORT_ARRAY,
-  INT_ARRAY,
-  LONG_ARRAY,
-  FLOAT_ARRAY,
-  DOUBLE_ARRAY,
-  STRING_ARRAY,
-  OBJECT_ARRAY,
-  ARRAY_OF_BYTE_ARRAYS
+  BYTE = 1,
+  CHAR = 2,
+  SHORT = 3,
+  INT = 4,
+  LONG = 5,
+  FLOAT = 6,
+  DOUBLE = 7,
+  DATE = 8,
+  STRING = 9,
+  OBJECT = 10,
+  BOOLEAN_ARRAY = 11,
+  CHAR_ARRAY = 12,
+  BYTE_ARRAY = 13,
+  SHORT_ARRAY = 14,
+  INT_ARRAY = 15,
+  LONG_ARRAY = 16,
+  FLOAT_ARRAY = 17,
+  DOUBLE_ARRAY = 18,
+  STRING_ARRAY = 19,
+  OBJECT_ARRAY = 20,
+  ARRAY_OF_BYTE_ARRAYS = 21
 };
 
 }  // namespace client
