@@ -62,10 +62,10 @@
 
 /** Deletes array x only if it exists */
 #define _GEODE_SAFE_DELETE_ARRAY(x) \
-  {                                 \
+  do {                              \
     delete[] x;                     \
     x = nullptr;                    \
-  }
+  } while (0)
 
 #include <chrono>
 #include <string>
@@ -77,8 +77,6 @@ namespace client {
 constexpr static std::chrono::milliseconds DEFAULT_QUERY_RESPONSE_TIMEOUT =
     std::chrono::seconds{15};
 
-static const std::string EMPTY_STRING{};
-
 }  // namespace client
 }  // namespace geode
 }  // namespace apache
