@@ -22,8 +22,6 @@
 
 #include <cstdlib>
 
-#include <ace/OS.h>
-
 #include <geode/Region.hpp>
 #include <geode/ResultSet.hpp>
 #include <geode/StructSet.hpp>
@@ -32,6 +30,7 @@
 #include "CacheImpl.hpp"
 #include "CacheRegionHelper.hpp"
 #include "DistributedSystemImpl.hpp"
+#include "SerializationRegistry.hpp"
 #include "testobject/Portfolio.hpp"
 #include "testobject/Position.hpp"
 #include "testobject/PdxType.hpp"
@@ -51,7 +50,7 @@
 #define ROOT_SCOPE LOCAL
 #endif
 
-namespace { // NOLINT(google-build-namespaces)
+namespace {  // NOLINT(google-build-namespaces)
 
 using apache::geode::client::CacheableKey;
 using apache::geode::client::CacheableStringArray;
@@ -88,7 +87,7 @@ class QueryHelper {
     positionNumSets = 1;
   }
 
-  virtual ~QueryHelper() { ; }
+  virtual ~QueryHelper() {}
 
   virtual void populatePortfolioData(
       std::shared_ptr<Region>& pregion, size_t setSize, size_t numSets,
@@ -119,8 +118,7 @@ class QueryHelper {
     for (int i = (sizeof(constantExpectedRowsRS) / sizeof(int)) - 1; i > -1;
          i--) {
       if (constantExpectedRowsRS[i] == queryindex) {
-        printf("index %d is having constant rows \n",
-               constantExpectedRowsRS[i]);
+        std::cout << "index " << constantExpectedRowsRS[i] << " is having constant rows \n";
         return true;
       }
     }
@@ -132,8 +130,7 @@ class QueryHelper {
     for (int i = (sizeof(constantExpectedRowsPQRS) / sizeof(int)) - 1; i > -1;
          i--) {
       if (constantExpectedRowsPQRS[i] == queryindex) {
-        printf("index %d is having constant rows \n",
-               constantExpectedRowsPQRS[i]);
+        std::cout << "index " << constantExpectedRowsPQRS[i] << " is having constant rows \n";
         return true;
       }
     }
@@ -145,8 +142,7 @@ class QueryHelper {
     for (int i = (sizeof(constantExpectedRowsSS) / sizeof(int)) - 1; i > -1;
          i--) {
       if (constantExpectedRowsSS[i] == queryindex) {
-        printf("index %d is having constant rows \n",
-               constantExpectedRowsSS[i]);
+        std::cout << "index " << constantExpectedRowsSS[i] << " is having constant rows \n";
         return true;
       }
     }
@@ -158,8 +154,7 @@ class QueryHelper {
     for (int i = (sizeof(constantExpectedRowsSSPQ) / sizeof(int)) - 1; i > -1;
          i--) {
       if (constantExpectedRowsSSPQ[i] == queryindex) {
-        printf("index %d is having constant rows \n",
-               constantExpectedRowsSSPQ[i]);
+        std::cout << "index " << constantExpectedRowsSSPQ[i] << " is having constant rows \n";
         return true;
       }
     }
@@ -188,19 +183,14 @@ void QueryHelper::populatePortfolioData(
       auto port = std::make_shared<Portfolio>(static_cast<int32_t>(current),
                                               objSize, nm);
 
-      char portname[100] = {0};
-      ACE_OS::sprintf(portname, "port%zd-%zd", set, current);
-
-      auto keyport = CacheableKey::create(portname);
-      // printf(" QueryHelper::populatePortfolioData creating key = %s and
-      // puting data \n",portname);
+      std::string key =
+          "port" + std::to_string(set) + '-' + std::to_string(current);
+      auto keyport = CacheableKey::create(key);
       rptr->put(keyport, port);
     }
   }
-  // portfolioSetSize = setSize; portfolioNumSets = numSets; objectSize =
-  // objSize;
 
-  printf("all puts done \n");
+  std::cout << "all puts done \n";
 }
 
 const char* secIds[] = {"SUN", "IBM",  "YHOO", "GOOG", "MSFT",
@@ -215,10 +205,9 @@ void QueryHelper::populatePositionData(std::shared_ptr<Region>& rptr,
       auto pos = std::make_shared<Position>(
           secIds[current % numSecIds], static_cast<int32_t>(current * 100));
 
-      char posname[100] = {0};
-      ACE_OS::sprintf(posname, "pos%zd-%zd", set, current);
-
-      auto keypos = CacheableKey::create(posname);
+      std::string key =
+          "pos" + std::to_string(set) + '-' + std::to_string(current);
+      auto keypos = CacheableKey::create(key);
       rptr->put(keypos, pos);
     }
   }
@@ -235,21 +224,18 @@ void QueryHelper::populatePortfolioPdxData(std::shared_ptr<Region>& rptr,
     for (size_t current = 1; current <= setSize; current++) {
       auto port = std::make_shared<PortfolioPdx>(static_cast<int32_t>(current),
                                                  objSize);
+      std::string key =
+          "port" + std::to_string(set) + '-' + std::to_string(current);
 
-      char portname[100] = {0};
-      ACE_OS::sprintf(portname, "port%zd-%zd", set, current);
-
-      auto keyport = CacheableKey::create(portname);
-
+      auto keyport = CacheableKey::create(key);
       rptr->put(keyport, port);
+
       LOGDEBUG("populatePortfolioPdxData:: Put for iteration current = %d done",
                current);
     }
   }
-  // portfolioSetSize = setSize; portfolioNumSets = numSets; objectSize =
-  // objSize;
 
-  printf("all puts done \n");
+  std::cout << "all puts done \n";
 }
 
 void QueryHelper::populatePositionPdxData(std::shared_ptr<Region>& rptr,
@@ -261,10 +247,10 @@ void QueryHelper::populatePositionPdxData(std::shared_ptr<Region>& rptr,
       auto pos = std::make_shared<PositionPdx>(
           secIds[current % numSecIds], static_cast<int32_t>(current * 100));
 
-      char posname[100] = {0};
-      ACE_OS::sprintf(posname, "pos%zd-%zd", set, current);
+      std::string key =
+          "pos" + std::to_string(set) + '-' + std::to_string(current);
 
-      auto keypos = CacheableKey::create(posname);
+      auto keypos = CacheableKey::create(key);
       rptr->put(keypos, pos);
     }
   }
@@ -339,8 +325,10 @@ bool QueryHelper::verifyRS(std::shared_ptr<SelectResults>& resultSet,
       foundRows++;
     }
 
-    printf("found rows %zd, expected %zd \n", foundRows, expectedRows);
-    if (foundRows == expectedRows) return true;
+    std::cout << "found rows " << foundRows << ", expected " << expectedRows << "\n";
+    if (foundRows == expectedRows) {
+      return true;
+    }
   }
   return false;
 }
@@ -355,7 +343,7 @@ bool QueryHelper::verifySS(std::shared_ptr<SelectResults>& structSet,
       auto siptr = std::dynamic_pointer_cast<Struct>(ser);
 
       if (siptr == nullptr) {
-        printf("siptr is nullptr \n\n");
+        std::cout << "siptr is nullptr \n\n";
         return false;
       }
 
@@ -365,10 +353,8 @@ bool QueryHelper::verifySS(std::shared_ptr<SelectResults>& structSet,
       }
 
       if (foundFields != expectedFields) {
-        char buffer[1024] = {'\0'};
-        sprintf(buffer, "found fields %d, expected fields %d \n", foundFields,
-                expectedFields);
-        LOG(buffer);
+        LOG(std::string("found fields ") + std::to_string(foundFields) +
+            ", expected fields " + std::to_string(expectedFields) + " \n");
         return false;
       }
     }
@@ -376,10 +362,8 @@ bool QueryHelper::verifySS(std::shared_ptr<SelectResults>& structSet,
     if (foundRows == expectedRows) return true;
 
     // lets log and return in case of error only situation
-    char buffer[1024] = {'\0'};
-    sprintf(buffer, "found rows %zd, expected rows %zd\n", foundRows,
-            expectedRows);
-    LOG(buffer);
+    LOG(std::string("found rows ") + std::to_string(foundRows) +
+        ", expected rows" + std::to_string(expectedRows) + " \n");
   } else {
     if (expectedRows == 0 && expectedFields == 0) {
       return true;  // quite possible we got a null set back.
