@@ -21,9 +21,7 @@
  */
 
 #include "fw_dunit.hpp"
-#include <ace/High_Res_Timer.h>
 
-#include <ace/OS.h>
 #include <string>
 
 #define ThinClientFailover2 "DistOps"
@@ -31,7 +29,7 @@
 
 #include "CacheHelper.hpp"
 
-namespace { // NOLINT(google-build-namespaces)
+namespace {  // NOLINT(google-build-namespaces)
 
 using apache::geode::client::CacheableKey;
 using apache::geode::client::CacheableString;
@@ -50,7 +48,7 @@ CacheHelper* cacheHelper = nullptr;
 #define SERVER2 s2p2
 static bool isLocator = false;
 static int numberOfLocators = 0;
-const char* locatorsG =
+const std::string locatorsG =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, numberOfLocators);
 #include "LocatorHelper.hpp"
 void initClient(const bool isthinClient) {
@@ -75,20 +73,18 @@ void _verifyEntry(const char* name, const char* key, const char* val,
                   bool noKey) {
   // Verify key and value exist in this region, in this process.
   const char* value = val ? val : "";
-  char* buf =
-      reinterpret_cast<char*>(malloc(1024 + strlen(key) + strlen(value)));
-  ASSERT(buf, "Unable to malloc buffer for logging.");
+  std::string msg;
   if (noKey) {
-    sprintf(buf, "Verify key %s does not exist in region %s", key, name);
+    msg =
+        std::string("Verify key ") + key + " does not exist in region " + name;
   } else if (!val) {
-    sprintf(buf, "Verify value for key %s does not exist in region %s", key,
-            name);
+    msg = std::string("Verify value for key ") + key +
+          " does not exist in region " + name;
   } else {
-    sprintf(buf, "Verify value for key %s is: %s in region %s", key, value,
-            name);
+    msg = std::string("Verify value for key ") + key + " is: " + value +
+          " in region " + name;
   }
-  LOG(buf);
-  free(buf);
+  LOG(msg);
 
   auto regPtr = getHelper()->getRegion(name);
   ASSERT(regPtr != nullptr, "Region not found.");
@@ -129,7 +125,8 @@ void _verifyEntry(const char* name, const char* key, const char* val,
           std::dynamic_pointer_cast<CacheableString>(regPtr->get(keyPtr));
 
       ASSERT(checkPtr != nullptr, "Value Ptr should not be null.");
-      LOG("In verify loop, get returned " + checkPtr->value() + " for key " + key);
+      LOG("In verify loop, get returned " + checkPtr->value() + " for key " +
+          key);
       if (strcmp(checkPtr->value().c_str(), value) != 0) {
         testValueCnt++;
       } else {
@@ -144,9 +141,8 @@ void _verifyEntry(const char* name, const char* key, const char* val,
 #define verifyInvalid(x, y) _verifyInvalid(x, y, __LINE__)
 
 void _verifyInvalid(const char* name, const char* key, int line) {
-  char logmsg[1024];
-  sprintf(logmsg, "verifyInvalid() called from %d.\n", line);
-  LOG(logmsg);
+  LOG(std::string("verifyInvalid() called from ") + std::to_string(line) +
+      "\n");
   _verifyEntry(name, key, nullptr, false);
   LOG("Entry invalidated.");
 }
@@ -154,9 +150,8 @@ void _verifyInvalid(const char* name, const char* key, int line) {
 #define verifyDestroyed(x, y) _verifyDestroyed(x, y, __LINE__)
 
 void _verifyDestroyed(const char* name, const char* key, int line) {
-  char logmsg[1024];
-  sprintf(logmsg, "verifyDestroyed() called from %d.\n", line);
-  LOG(logmsg);
+  LOG(std::string("verifyDestroyed() called from ") + std::to_string(line) +
+      "\n");
   _verifyEntry(name, key, nullptr, true);
   LOG("Entry destroyed.");
 }
@@ -165,9 +160,7 @@ void _verifyDestroyed(const char* name, const char* key, int line) {
 
 void _verifyEntry(const char* name, const char* key, const char* val,
                   int line) {
-  char logmsg[1024];
-  sprintf(logmsg, "verifyEntry() called from %d.\n", line);
-  LOG(logmsg);
+  LOG(std::string("verifyEntry() called from ") + std::to_string(line) + "\n");
   _verifyEntry(name, key, val, false);
   LOG("Entry verified.");
 }
@@ -175,21 +168,24 @@ void _verifyEntry(const char* name, const char* key, const char* val,
 void createRegion(const char* name, bool ackMode, const char* endpoints,
                   bool clientNotificationEnabled = false) {
   LOG("createRegion() entered.");
-  fprintf(stdout, "Creating region --  %s  ackMode is %d\n", name, ackMode);
-  fflush(stdout);
+  std::cout << "Creating region --  " << name << " ackMode is " << ackMode
+            << "\n"
+            << std::flush;
   // ack, caching
   auto regPtr = getHelper()->createRegion(name, ackMode, true, nullptr,
                                           endpoints, clientNotificationEnabled);
   ASSERT(regPtr != nullptr, "Failed to create region.");
   LOG("Region created.");
 }
-void createPooledRegion(const char* name, bool ackMode, const char* locators,
-                        const char* poolname,
+void createPooledRegion(const std::string& name, bool ackMode,
+                        const std::string& locators,
+                        const std::string& poolname,
                         bool clientNotificationEnabled = false,
                         bool cachingEnable = true) {
   LOG("createRegion_Pool() entered.");
-  fprintf(stdout, "Creating region --  %s  ackMode is %d\n", name, ackMode);
-  fflush(stdout);
+  std::cout << "Creating region --  " << name << " ackMode is " << ackMode
+            << "\n"
+            << std::flush;
   auto regPtr =
       getHelper()->createPooledRegion(name, ackMode, locators, poolname,
                                       cachingEnable, clientNotificationEnabled);
@@ -198,9 +194,9 @@ void createPooledRegion(const char* name, bool ackMode, const char* locators,
 }
 void createEntry(const char* name, const char* key, const char* value) {
   LOG("createEntry() entered.");
-  fprintf(stdout, "Creating entry -- key: %s  value: %s in region %s\n", key,
-          value, name);
-  fflush(stdout);
+  std::cout << "Creating entry -- key: " << key << " value: " << value
+            << " in region " << name << "\n"
+            << std::flush;
   // Create entry, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
   auto valPtr = CacheableString::create(value);
@@ -223,9 +219,9 @@ void createEntry(const char* name, const char* key, const char* value) {
 
 void updateEntry(const char* name, const char* key, const char* value) {
   LOG("updateEntry() entered.");
-  fprintf(stdout, "Updating entry -- key: %s  value: %s in region %s\n", key,
-          value, name);
-  fflush(stdout);
+  std::cout << "Updating entry -- key: " << key << " value: " << value
+            << " in region " << name << "\n"
+            << std::flush;
   // Update entry, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
   auto valPtr = CacheableString::create(value);
@@ -246,16 +242,14 @@ void updateEntry(const char* name, const char* key, const char* value) {
 
 void doNetsearch(const char* name, const char* key, const char* value) {
   LOG("doNetsearch() entered.");
-  fprintf(
-      stdout,
-      "Netsearching for entry -- key: %s  expecting value: %s in region %s\n",
-      key, value, name);
-  fflush(stdout);
+  std::cout << "Netsearching for entry -- key: " << key
+            << " expecting value: " << value << " in region " << name << "\n"
+            << std::flush;
   // Get entry created in Process A, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
 
   auto regPtr = getHelper()->getRegion(name);
-  fprintf(stdout, "netsearch  region %s\n", regPtr->getName().c_str());
+  std::cout << "netsearch region " << regPtr->getName() << "\n" << std::flush;
   fflush(stdout);
   ASSERT(regPtr != nullptr, "Region not found.");
 
@@ -272,10 +266,8 @@ void doNetsearch(const char* name, const char* key, const char* value) {
 
   if (checkPtr != nullptr) {
     LOG("checkPtr is not null");
-    char buf[1024];
-    sprintf(buf, "In net search, get returned %s for key %s",
-            checkPtr->value().c_str(), key);
-    LOG(buf);
+    LOG(std::string("In net search, get returned ") + checkPtr->value() +
+        " for key " + key);
   } else {
     LOG("checkPtr is nullptr");
   }
@@ -285,8 +277,7 @@ void doNetsearch(const char* name, const char* key, const char* value) {
 
 void invalidateEntry(const char* name, const char* key) {
   LOG("invalidateEntry() entered.");
-  fprintf(stdout, "Invalidating entry -- key: %s  in region %s\n", key, name);
-  fflush(stdout);
+  std::cout << "Invalidating entry -- key: " << key << " in region " << name << "\n" << std::flush;
   // Invalidate entry, verify entry is invalidated
   auto keyPtr = CacheableKey::create(key);
 
@@ -306,8 +297,7 @@ void invalidateEntry(const char* name, const char* key) {
 
 void destroyEntry(const char* name, const char* key) {
   LOG("destroyEntry() entered.");
-  fprintf(stdout, "Destroying entry -- key: %s  in region %s\n", key, name);
-  fflush(stdout);
+  std::cout << "Destroying entry -- key: " << key << " in region " << name << "\n" << std::flush;
   // Destroy entry, verify entry is destroyed
   auto keyPtr = CacheableKey::create(key);
 
@@ -335,7 +325,7 @@ const char* vals[] = {"Value-1", "Value-2", "Value-3", "Value-4", "Value-5"};
 const char* nvals[] = {"New Value-1", "New Value-2", "New Value-3",
                        "New Value-4", "New Value-5"};
 
-const char* regionNames[] = {"DistRegionAck", "DistRegionNoAck"};
+const char* regionName = "DistRegionAck";
 
 const bool USE_ACK = true;
 const bool NO_ACK = false;
@@ -349,17 +339,9 @@ END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT1, StepOne_Pool_Locator)
   {
-    char buff[2048];
-    char* buf = getcwd(buff, 2048);
-    LOG(buf);
     initClient(true);
-    createPooledRegion(regionNames[0], USE_ACK, locatorsG, "__TEST_POOL1__",
-                       true);
-    createPooledRegion(regionNames[1], NO_ACK, locatorsG, "__TEST_POOL1__",
-                       true);
-    auto regPtr = getHelper()->getRegion(regionNames[0]);
-    regPtr->registerAllKeys(false, false, false);
-    regPtr = getHelper()->getRegion(regionNames[1]);
+    createPooledRegion(regionName, USE_ACK, locatorsG, "__TEST_POOL1__", true);
+    auto regPtr = getHelper()->getRegion(regionName);
     regPtr->registerAllKeys(false, false, false);
     LOG("StepOne complete.");
   }
@@ -367,17 +349,9 @@ END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT2, StepTwo_Pool_Locator)
   {
-    char buff[2048];
-    char* buf = getcwd(buff, 2048);
-    LOG(buf);
     initClient(true);
-    createPooledRegion(regionNames[0], USE_ACK, locatorsG, "__TEST_POOL1__",
-                       true);
-    createPooledRegion(regionNames[1], NO_ACK, locatorsG, "__TEST_POOL1__",
-                       true);
-    auto regPtr = getHelper()->getRegion(regionNames[0]);
-    regPtr->registerAllKeys(false, false, false);
-    regPtr = getHelper()->getRegion(regionNames[1]);
+    createPooledRegion(regionName, USE_ACK, locatorsG, "__TEST_POOL1__", true);
+    auto regPtr = getHelper()->getRegion(regionName);
     regPtr->registerAllKeys(false, false, false);
     LOG("StepTwo complete.");
   }
@@ -385,19 +359,16 @@ END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT1, StepThree)
   {
-    createEntry(regionNames[0], keys[0], vals[0]);
-    createEntry(regionNames[1], keys[2], vals[2]);
-    createEntry(regionNames[0], keys[4], vals[4]);
+    createEntry(regionName, keys[0], vals[0]);
+    createEntry(regionName, keys[4], vals[4]);
     LOG("StepThree complete.");
   }
 END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT2, StepFour)
   {
-    doNetsearch(regionNames[0], keys[0], vals[0]);
-    doNetsearch(regionNames[1], keys[2], vals[2]);
-    createEntry(regionNames[0], keys[1], vals[1]);
-    createEntry(regionNames[1], keys[3], vals[3]);
+    doNetsearch(regionName, keys[0], vals[0]);
+    createEntry(regionName, keys[1], vals[1]);
     LOG("StepFour complete.");
   }
 END_TASK_DEFINITION
@@ -420,12 +391,9 @@ END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT1, StepFive)
   {
-    auto reg0 = getHelper()->getRegion(regionNames[0]);
-    auto reg1 = getHelper()->getRegion(regionNames[1]);
+    auto reg0 = getHelper()->getRegion(regionName);
     auto vec0 = reg0->serverKeys();
-    auto vec1 = reg1->serverKeys();
     ASSERT(vec0.size() == 3, "Should have 3 keys in first region.");
-    ASSERT(vec1.size() == 2, "Should have 2 keys in second region.");
 
     std::string key0, key1, key2;
     key0 = vec0[0]->toString().c_str();
@@ -441,20 +409,9 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFive)
     ASSERT(key2 == keys[0] || key2 == keys[1] || key2 == keys[4],
            "Unexpected key in first region.");
 
-    key0 = vec1[0]->toString().c_str();
-    key1 = vec1[1]->toString().c_str();
-    ASSERT(key0 != key1, "The two keys should be different in second region.");
-    ASSERT(key0 == keys[2] || key0 == keys[3],
-           "Unexpected key in second region.");
-    ASSERT(key1 == keys[2] || key1 == keys[3],
-           "Unexpected key in second region.");
-
-    doNetsearch(regionNames[0], keys[1], vals[1]);
-    doNetsearch(regionNames[1], keys[3], vals[3]);
-    updateEntry(regionNames[0], keys[0], nvals[0]);
-    updateEntry(regionNames[1], keys[2], nvals[2]);
-    verifyEntry(regionNames[0], keys[0], nvals[0]);
-    verifyEntry(regionNames[1], keys[2], nvals[2]);
+    doNetsearch(regionName, keys[1], vals[1]);
+    updateEntry(regionName, keys[0], nvals[0]);
+    verifyEntry(regionName, keys[0], nvals[0]);
     LOG("StepFive complete.");
   }
 END_TASK_DEFINITION
@@ -465,43 +422,35 @@ DUNIT_TASK_DEFINITION(CLIENT2, StepSix)
     // This step get the value from region, if key is inavalidate in region,
     // value
     // will get from server.
-    // doNetsearch( regionNames[0], keys[4], vals[4] );
-    verifyEntry(regionNames[0], keys[0], nvals[0]);
-    verifyEntry(regionNames[1], keys[2], nvals[2]);
-    updateEntry(regionNames[0], keys[1], nvals[1]);
-    updateEntry(regionNames[1], keys[3], nvals[3]);
+    doNetsearch(regionName, keys[0], nvals[0]);
+    updateEntry(regionName, keys[1], nvals[1]);
     LOG("StepSix complete.");
   }
 END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT1, StepSeven)
   {
-    verifyEntry(regionNames[0], keys[1], nvals[1]);
-    verifyEntry(regionNames[1], keys[3], nvals[3]);
+    verifyEntry(regionName, keys[1], nvals[1]);
     LOG("StepSeven complete.");
   }
 END_TASK_DEFINITION
 DUNIT_TASK_DEFINITION(CLIENT1, StepEight)
   {
-    destroyEntry(regionNames[0], keys[0]);
-    destroyEntry(regionNames[1], keys[2]);
+    destroyEntry(regionName, keys[0]);
     LOG("StepEight complete.");
   }
 END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT2, StepNine)
   {
-    verifyDestroyed(regionNames[0], keys[0]);
-    verifyDestroyed(regionNames[1], keys[2]);
-    destroyEntry(regionNames[0], keys[1]);
-    destroyEntry(regionNames[1], keys[3]);
+    verifyDestroyed(regionName, keys[0]);
+    destroyEntry(regionName, keys[1]);
     LOG("StepNine complete.");
   }
 END_TASK_DEFINITION
 DUNIT_TASK_DEFINITION(CLIENT1, StepTen)
   {
-    verifyDestroyed(regionNames[0], keys[1]);
-    verifyDestroyed(regionNames[1], keys[3]);
+    verifyDestroyed(regionName, keys[1]);
     LOG("StepTen complete.");
   }
 END_TASK_DEFINITION
