@@ -22,8 +22,9 @@
 
 #include <chrono>
 
-#include <ace/OS.h>
-#include <ace/High_Res_Timer.h>
+
+#include <boost/process.hpp>
+
 #include "testUtils.hpp"
 #include "security/typedefs.hpp"
 #include "security/CredentialGenerator.hpp"
@@ -42,7 +43,7 @@
 
 #include "CacheHelper.hpp"
 
-namespace { // NOLINT(google-build-namespaces)
+namespace {  // NOLINT(google-build-namespaces)
 
 using apache::geode::client::CacheableInt32;
 using apache::geode::client::CacheHelper;
@@ -66,7 +67,7 @@ void initClient(const bool isthinClient,
 }
 
 void initClientWithPool(const bool isthinClient, const char* poolName,
-                        const char* locators, const char* serverGroup,
+                        const std::string& locators, const char* serverGroup,
                         const std::shared_ptr<Properties>& configPtr = nullptr,
                         int redundancy = 0, bool clientNotification = false,
                         int subscriptionAckInterval = -1, int connections = -1,
@@ -141,21 +142,18 @@ void _verifyEntry(const std::string& name, const char* key, const char* val,
                   bool noKey, bool checkVal = true) {
   // Verify key and value exist in this region, in this process.
   const char* value = val ? val : "";
-  char* buf =
-      reinterpret_cast<char*>(malloc(1024 + strlen(key) + strlen(value)));
-  ASSERT(buf, "Unable to malloc buffer for logging.");
+  std::string msg;
   if (noKey) {
-    sprintf(buf, "Verify key %s does not exist in region %s", key,
-            name.c_str());
+    msg =
+        std::string("Verify key ") + key + " does not exist in region " + name;
   } else if (!val) {
-    sprintf(buf, "Verify value for key %s does not exist in region %s", key,
-            name.c_str());
+    msg = std::string("Verify value for key ") + key +
+          " does not exist in region " + name;
   } else {
-    sprintf(buf, "Verify value for key %s is: %s in region %s", key, value,
-            name.c_str());
+    msg = std::string("Verify value for key ") + key + " is: " + value +
+          " in region " + name;
   }
-  LOG(buf);
-  free(buf);
+  LOG(msg);
 
   auto regPtr = getHelper()->getRegion(name);
   ASSERT(regPtr != nullptr, "Region not found.");
@@ -199,7 +197,8 @@ void _verifyEntry(const std::string& name, const char* key, const char* val,
           std::dynamic_pointer_cast<CacheableString>(regPtr->get(keyPtr));
 
       ASSERT(checkPtr != nullptr, "Value Ptr should not be null.");
-      LOG("In verify loop, get returned " + checkPtr->value() + " for key " + key);
+      LOG("In verify loop, get returned " + checkPtr->value() + " for key " +
+          key);
 
       if (strcmp(checkPtr->value().c_str(), value) != 0) {
         testValueCnt++;
@@ -215,9 +214,8 @@ void _verifyEntry(const std::string& name, const char* key, const char* val,
 #define verifyInvalid(x, y) _verifyInvalid(x, y, __LINE__)
 
 void _verifyInvalid(const char* name, const char* key, int line) {
-  char logmsg[1024];
-  sprintf(logmsg, "verifyInvalid() called from %d.\n", line);
-  LOG(logmsg);
+  LOG(std::string("verifyInvalid() called from ") + std::to_string(line) +
+      "\n");
   _verifyEntry(name, key, nullptr, false);
   LOG("Entry invalidated.");
 }
@@ -225,18 +223,16 @@ void _verifyInvalid(const char* name, const char* key, int line) {
 #define verifyDestroyed(x, y) _verifyDestroyed(x, y, __LINE__)
 
 void _verifyDestroyed(const char* name, const char* key, int line) {
-  char logmsg[1024];
-  sprintf(logmsg, "verifyDestroyed() called from %d.\n", line);
-  LOG(logmsg);
+  LOG(std::string("verifyDestroyed() called from ") + std::to_string(line) +
+      "\n");
   _verifyEntry(name, key, nullptr, true);
   LOG("Entry destroyed.");
 }
 
 void verifyEntry(const std::string& name, const char* key, const char* val,
                  bool checkVal = true) {
-  char logmsg[1024];
-  sprintf(logmsg, "verifyEntry() called from %d.\n", __LINE__);
-  LOG(logmsg);
+  LOG(std::string("verifyEntry() called from ") + std::to_string(__LINE__) +
+      "\n");
   _verifyEntry(name, key, val, false, checkVal);
   LOG("Entry verified.");
 }
@@ -245,21 +241,19 @@ void _verifyIntEntry(const char* name, const char* key, const int val,
                      bool noKey, bool isCreated = false) {
   // Verify key and value exist in this region, in this process.
   int value = val;
-  char* buf = reinterpret_cast<char*>(malloc(1024 + strlen(key) + 20));
-  ASSERT(buf, "Unable to malloc buffer for logging.");
+  std::string msg;
   if (!isCreated) {
     if (noKey) {
-      sprintf(buf, "Verify key %s does not exist in region %s", key, name);
+      msg = std::string("Verify key ") + key + " does not exist in region " +
+            name;
     } else if (val == 0) {
-      sprintf(buf, "Verify value for key %s does not exist in region %s", key,
-              name);
+      msg = std::string("Verify value for key ") + key +
+            " does not exist in region " + name;
     } else {
-      sprintf(buf, "Verify value for key %s is: %d in region %s", key, value,
-              name);
+      msg = std::string("Verify value for key ") + key +
+            " is: " + std::to_string(value) + " in region " + name;
     }
-    LOG(buf);
-
-    free(buf);
+    LOG(msg);
   }
 
   auto regPtr = getHelper()->getRegion(name);
@@ -317,7 +311,8 @@ void _verifyIntEntry(const char* name, const char* key, const int val,
             std::dynamic_pointer_cast<CacheableInt32>(regPtr->get(keyPtr));
 
         ASSERT(checkPtr != nullptr, "Value Ptr should not be null.");
-        LOG("In verify loop, get returned " + std::to_string(checkPtr->value()) + " for key " + key);
+        LOG("In verify loop, get returned " +
+            std::to_string(checkPtr->value()) + " for key " + key);
 
         if (checkPtr->value() != value) {
           testValueCnt++;
@@ -334,9 +329,8 @@ void _verifyIntEntry(const char* name, const char* key, const int val,
 #define verifyIntEntry(x, y, z) _verifyIntEntry(x, y, z, __LINE__)
 void _verifyIntEntry(const char* name, const char* key, const int val,
                      int line) {
-  char logmsg[1024];
-  sprintf(logmsg, "verifyIntEntry() called from %d.\n", line);
-  LOG(logmsg);
+  LOG(std::string("verifyIntEntry() called from ") + std::to_string(line) +
+      "\n");
   _verifyIntEntry(name, key, val, false);
   LOG("Entry verified.");
 }
@@ -346,8 +340,9 @@ void createRegion(const char* name, bool ackMode,
                   const std::shared_ptr<CacheListener>& listener = nullptr,
                   bool caching = true) {
   LOG("createRegion() entered.");
-  fprintf(stdout, "Creating region --  %s  ackMode is %d\n", name, ackMode);
-  fflush(stdout);
+  std::cout << "Creating region --  " << name << " ackMode is " << ackMode
+            << "\n"
+            << std::flush;
   // ack, caching
   auto regPtr = getHelper()->createRegion(name, ackMode, caching, listener,
                                           clientNotificationEnabled);
@@ -367,7 +362,7 @@ std::shared_ptr<Region> createOverflowRegion(const char* name, bool,
   sqLiteProps->insert("PageSize", "65536");
   sqLiteProps->insert("MaxPageCount", "1073741823");
   std::string sqlite_dir =
-      "SqLiteRegionData" + std::to_string(ACE_OS::getpid());
+      "SqLiteRegionData" + std::to_string(boost::this_process::get_id());
   sqLiteProps->insert("PersistenceDirectory", sqlite_dir.c_str());
   regionAttributesFactory.setPersistenceManager(
       "SqLiteImpl", "createSqLiteInstance", sqLiteProps);
@@ -380,13 +375,14 @@ std::shared_ptr<Region> createOverflowRegion(const char* name, bool,
   return regionPtr;
 }
 std::shared_ptr<Region> createPooledRegion(
-    const char* name, bool ackMode, const char* locators, const char* poolname,
-    bool clientNotificationEnabled = false,
+    const char* name, bool ackMode, const std::string& locators,
+    const char* poolname, bool clientNotificationEnabled = false,
     const std::shared_ptr<CacheListener>& listener = nullptr,
     bool caching = true) {
   LOG("createPooledRegion() entered.");
-  fprintf(stdout, "Creating region --  %s  ackMode is %d\n", name, ackMode);
-  fflush(stdout);
+  std::cout << "Creating region --  " << name << " ackMode is " << ackMode
+            << "\n"
+            << std::flush;
 
   if (cacheHelper == nullptr) {
     cacheHelper = new CacheHelper(true, poolname, locators, nullptr);
@@ -409,8 +405,9 @@ std::shared_ptr<Pool> findPool(const char* poolName) {
   return poolPtr;
 }
 std::shared_ptr<Pool> createPool(
-    const char* poolName, const char* locators, const char* serverGroup,
-    int redundancy = 0, bool clientNotification = false,
+    const std::string& poolName, const std::string& locators,
+    const std::string& serverGroup, int redundancy = 0,
+    bool clientNotification = false,
     std::chrono::milliseconds subscriptionAckInterval =
         std::chrono::milliseconds::zero(),
     int connections = -1, int loadConditioningInterval = -1) {
@@ -424,8 +421,9 @@ std::shared_ptr<Pool> createPool(
   return poolPtr;
 }
 std::shared_ptr<Pool> createPoolAndDestroy(
-    const char* poolName, const char* locators, const char* serverGroup,
-    int redundancy = 0, bool clientNotification = false,
+    const std::string& poolName, const std::string& locators,
+    const std::string& serverGroup, int redundancy = 0,
+    bool clientNotification = false,
     std::chrono::milliseconds subscriptionAckInterval =
         std::chrono::milliseconds::zero(),
     int connections = -1) {
@@ -440,9 +438,10 @@ std::shared_ptr<Pool> createPoolAndDestroy(
   return poolPtr;
 }
 // this will create pool even endpoints and locatorhost has been not defined
-std::shared_ptr<Pool> createPool2(const char* poolName, const char* locators,
-                                  const char* serverGroup,
-                                  const char* servers = nullptr,
+std::shared_ptr<Pool> createPool2(const std::string& poolName,
+                                  const std::string& locators,
+                                  const std::string& serverGroup,
+                                  const std::string& servers = nullptr,
                                   int redundancy = 0,
                                   bool clientNotification = false) {
   LOG("createPool2() entered.");
@@ -471,9 +470,9 @@ std::shared_ptr<Region> createRegionAndAttachPool(
 
 void createEntry(const std::string& name, const char* key, const char* value) {
   LOG("createEntry() entered.");
-  fprintf(stdout, "Creating entry -- key: %s  value: %s in region %s\n", key,
-          value, name.c_str());
-  fflush(stdout);
+  std::cout << "Creating entry -- key: " << key << " value: " << value
+            << " in region " << name << "\n"
+            << std::flush;
   // Create entry, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
   auto valPtr = CacheableString::create(value);
@@ -497,9 +496,9 @@ void createEntry(const std::string& name, const char* key, const char* value) {
 void updateEntry(const char* name, const char* key, const char* value,
                  bool checkVal = true, bool checkKey = true) {
   LOG("updateEntry() entered.");
-  fprintf(stdout, "Updating entry -- key: %s  value: %s in region %s\n", key,
-          value, name);
-  fflush(stdout);
+  std::cout << "Updating entry -- key: " << key << " value: " << value
+            << " in region " << name << "\n"
+            << std::flush;
   // Update entry, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
   auto valPtr = CacheableString::create(value);
@@ -526,16 +525,14 @@ void updateEntry(const char* name, const char* key, const char* value,
 void doNetsearch(const char* name, const char* key, const char* value,
                  bool checkVal = true) {
   LOG("doNetsearch() entered.");
-  fprintf(
-      stdout,
-      "Netsearching for entry -- key: %s  expecting value: %s in region %s\n",
-      key, value, name);
-  fflush(stdout);
+  std::cout << "Netsearching for entry -- key: " << key
+            << " expecting value: " << value << " in region " << name << "\n"
+            << std::flush;
   // Get entry created in Process A, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
 
   auto regPtr = getHelper()->getRegion(name);
-  fprintf(stdout, "netsearch  region %s\n", regPtr->getName().c_str());
+  std::cout << "netsearch region " << regPtr->getName() << "\n" << std::flush;
   fflush(stdout);
   ASSERT(regPtr != nullptr, "Region not found.");
 
@@ -551,10 +548,8 @@ void doNetsearch(const char* name, const char* key, const char* value,
 
   if (checkPtr != nullptr) {
     LOG("checkPtr is not null");
-    char buf[1024];
-    sprintf(buf, "In net search, get returned %s for key %s",
-            checkPtr->value().c_str(), key);
-    LOG(buf);
+    LOG(std::string("In net search, get returned ") + checkPtr->value() +
+        " for key " + key);
   } else {
     LOG("checkPtr is nullptr");
   }
@@ -565,9 +560,9 @@ void doNetsearch(const char* name, const char* key, const char* value,
 void createIntEntry(const char* name, const char* key, const int value,
                     bool onlyCreate = false) {
   LOG("createEntry() entered.");
-  fprintf(stdout, "Creating entry -- key: %s  value: %d in region %s\n", key,
-          value, name);
-  fflush(stdout);
+  std::cout << "Creating entry -- key: " << key << " value: " << value
+            << " in region " << name << "\n"
+            << std::flush;
 
   // Create entry, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
@@ -592,8 +587,7 @@ void createIntEntry(const char* name, const char* key, const int value,
 
 void invalidateEntry(const char* name, const char* key) {
   LOG("invalidateEntry() entered.");
-  fprintf(stdout, "Invalidating entry -- key: %s  in region %s\n", key, name);
-  fflush(stdout);
+  std::cout << "Invalidating entry -- key: " << key << " in region " << name << "\n" << std::flush;
   // Invalidate entry, verify entry is invalidated
   auto keyPtr = CacheableKey::create(key);
 
@@ -613,8 +607,7 @@ void invalidateEntry(const char* name, const char* key) {
 
 void destroyEntry(const char* name, const char* key) {
   LOG("destroyEntry() entered.");
-  fprintf(stdout, "Destroying entry -- key: %s  in region %s\n", key, name);
-  fflush(stdout);
+  std::cout << "Destroying entry -- key: " << key << " in region " << name << "\n" << std::flush;
   // Destroy entry, verify entry is destroyed
   auto keyPtr = CacheableKey::create(key);
 
@@ -644,47 +637,41 @@ class RegionOperations {
 
   void putOp(int keysMax = 1,
              const std::shared_ptr<Serializable>& aCallbackArgument = nullptr) {
-    char keybuf[100];
-    char valbuf[100];
     for (int i = 1; i <= keysMax; i++) {
-      sprintf(keybuf, "key%d", i);
-      sprintf(valbuf, "value%d", i);
-      auto valPtr = CacheableString::create(valbuf);
-      m_regionPtr->put(keybuf, valPtr, aCallbackArgument);
+      auto key = std::string("key") + std::to_string(i);
+      auto value = std::string("value") + std::to_string(i);
+      auto valPtr = CacheableString::create(value);
+      m_regionPtr->put(key, valPtr, aCallbackArgument);
     }
   }
   void invalidateOp(
       int keysMax = 1,
       const std::shared_ptr<Serializable>& aCallbackArgument = nullptr) {
-    char keybuf[100];
-    char valbuf[100] = {0};
     for (int i = 1; i <= keysMax; i++) {
-      sprintf(keybuf, "key%d", i);
-      auto valPtr = CacheableString::create(valbuf);
-      m_regionPtr->localInvalidate(keybuf, aCallbackArgument);
+      auto key = std::string("key") + std::to_string(i);
+      std::string value;
+      auto valPtr = CacheableString::create(value);
+      m_regionPtr->localInvalidate(key, aCallbackArgument);
     }
   }
   void destroyOp(
       int keysMax = 1,
       const std::shared_ptr<Serializable>& aCallbackArgument = nullptr) {
-    char keybuf[100];
-    char valbuf[100] = {0};
     for (int i = 1; i <= keysMax; i++) {
-      sprintf(keybuf, "key%d", i);
-      auto valPtr = CacheableString::create(valbuf);
-      m_regionPtr->destroy(keybuf, aCallbackArgument);
+      auto key = std::string("key") + std::to_string(i);
+      std::string value;
+      auto valPtr = CacheableString::create(value);
+      m_regionPtr->destroy(key, aCallbackArgument);
     }
   }
   void removeOp(
       int keysMax = 1,
       const std::shared_ptr<Serializable>& aCallbackArgument = nullptr) {
-    char keybuf[100];
-    char valbuf[100] = {0};
     for (int i = 1; i <= keysMax; i++) {
-      sprintf(keybuf, "key%d", i);
-      sprintf(valbuf, "value%d", i);
-      auto valPtr = CacheableString::create(valbuf);
-      m_regionPtr->remove(keybuf, valPtr, aCallbackArgument);
+      auto key = std::string("key") + std::to_string(i);
+      auto value = std::string("value") + std::to_string(i);
+      auto valPtr = CacheableString::create(value);
+      m_regionPtr->remove(key, valPtr, aCallbackArgument);
     }
   }
   std::shared_ptr<Region> m_regionPtr;
