@@ -21,8 +21,6 @@
 #define GEODE_INTEGRATION_TEST_THINCLIENTPUTGETALL_H_
 
 #include "fw_dunit.hpp"
-#include <ace/OS.h>
-#include <ace/High_Res_Timer.h>
 #include <string>
 #include <unordered_map>
 
@@ -38,7 +36,7 @@
 #define CLIENT2 s1p2
 #define SERVER1 s2p1
 
-namespace { // NOLINT(google-build-namespaces)
+namespace {  // NOLINT(google-build-namespaces)
 
 using PdxTests::PdxTypes1;
 using PdxTests::PdxTypes10;
@@ -59,7 +57,7 @@ static bool isLocalServer = false;
 static bool isLocator = false;
 static int numberOfLocators = 0;
 
-const char* locatorsG =
+const std::string locatorsG =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, numberOfLocators);
 const char* poolName = "__TEST_POOL1__";
 
@@ -93,8 +91,10 @@ void verifyGetAll(std::shared_ptr<Region> region, const char** _values,
       const auto key = std::dynamic_pointer_cast<CacheableKey>(iter.first);
       const auto& mVal = iter.second;
       if (mVal != nullptr) {
-        LOG(std::string("Value from map ") + mVal->toString() + ", expected value " + expected[key->toString()]);
-        ASSERT(mVal->toString() == expected[key->toString()], "value not matched");
+        LOG(std::string("Value from map ") + mVal->toString() +
+            ", expected value " + expected[key->toString()]);
+        ASSERT(mVal->toString() == expected[key->toString()],
+               "value not matched");
       } else {
         ASSERT(key->toString() == "keyNotThere",
                "keyNotThere value is not null");
@@ -109,13 +109,15 @@ void verifyGetAllWithCallBackArg(std::shared_ptr<Region> region,
   verifyGetAll(region, values, startIndex, callBack);
 }
 
-void createPooledRegion(const char* name, bool ackMode, const char* locators,
-                        const char* poolname,
+void createPooledRegion(const std::string& name, bool ackMode,
+                        const std::string& locators,
+                        const std::string& poolname,
                         bool clientNotificationEnabled = false,
                         bool cachingEnable = true) {
   LOG("createRegion_Pool() entered.");
-  fprintf(stdout, "Creating region --  %s  ackMode is %d\n", name, ackMode);
-  fflush(stdout);
+  std::cout << "Creating region --  " << name << " ackMode is " << ackMode
+            << "\n"
+            << std::flush;
   auto regPtr =
       getHelper()->createPooledRegion(name, ackMode, locators, poolname,
                                       cachingEnable, clientNotificationEnabled);
