@@ -20,13 +20,14 @@
 #ifndef GEODE_INTEGRATION_TEST_THINCLIENTSECURITYHELPER_H_
 #define GEODE_INTEGRATION_TEST_THINCLIENTSECURITYHELPER_H_
 
-#include <ace/Process.h>
+#include <boost/process.hpp>
+#include <boost/lexical_cast.hpp>
 
 #include "fw_dunit.hpp"
 #include "ThinClientHelper.hpp"
 #include "hacks/AceThreadId.h"
 
-namespace { // NOLINT(google-build-namespaces)
+namespace {  // NOLINT(google-build-namespaces)
 
 using apache::geode::client::CacheableBoolean;
 using apache::geode::client::Exception;
@@ -51,22 +52,12 @@ using apache::geode::client::testframework::security::opCodeList;
 bool isLocator = false;
 bool isLocalServer = false;
 
-const char* locHostPort =
+const std::string locHostPort =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, 1);
 
 const char* regionNamesAuth[] = {"DistRegionAck"};
 std::shared_ptr<CredentialGenerator> credentialGeneratorHandler;
 
-std::string getXmlPath() {
-  char xmlPath[1000] = {'\0'};
-  const char* path = ACE_OS::getenv("TESTSRC");
-  ASSERT(path != nullptr,
-         "Environment variable TESTSRC for test source directory is not set.");
-  strncpy(xmlPath, path, strlen(path) - strlen("cppcache"));
-  strncat(xmlPath, "xml/Security/", sizeof(xmlPath) - strlen(xmlPath) - 1);
-  return std::string(xmlPath);
-}
-
 void initCredentialGenerator() {
   static int loopNum = 1;
 
@@ -141,29 +132,32 @@ void initClientAuth(char UserType) {
     case 'W':
       credentialGeneratorHandler->getAllowedCredentialsForOps(wr, config,
                                                               nullptr);
-      printf("User is %s Pass is %s ",
-             config->find("security-username")->value().c_str(),
-             (config->find("security-password") != nullptr
-                  ? config->find("security-password")->value().c_str()
-                  : " not set"));
+      std::cout << "User is " << config->find("security-username")->value()
+                << " Pass is "
+                << (config->find("security-password") != nullptr
+                        ? config->find("security-password")->value()
+                        : " not set")
+                << "\n";
       break;
     case 'R':
       credentialGeneratorHandler->getAllowedCredentialsForOps(rt, config,
                                                               nullptr);
-      printf("User is %s Pass is %s ",
-             config->find("security-username")->value().c_str(),
-             (config->find("security-password") != nullptr
-                  ? config->find("security-password")->value().c_str()
-                  : " not set"));
+      std::cout << "User is " << config->find("security-username")->value()
+                << " Pass is "
+                << (config->find("security-password") != nullptr
+                        ? config->find("security-password")->value()
+                        : " not set")
+                << "\n";
       break;
     case 'A':
       credentialGeneratorHandler->getAllowedCredentialsForOps(ad, config,
                                                               nullptr);
-      printf("User is %s Pass is %s ",
-             config->find("security-username")->value().c_str(),
-             (config->find("security-password") != nullptr
-                  ? config->find("security-password")->value().c_str()
-                  : " not set"));
+      std::cout << "User is " << config->find("security-username")->value()
+                << " Pass is "
+                << (config->find("security-password") != nullptr
+                        ? config->find("security-password")->value()
+                        : " not set")
+                << "\n";
       break;
     default:
       break;
@@ -176,112 +170,126 @@ void initClientAuth(char UserType) {
   }
 }
 
-// This putThread class is used in
+// This PutThread class is used in
 // testThinClientTracking,testThinClientTicket304, testThinClientTicket317
 
-class putThread : public ACE_Task_Base {
+class PutThread {
  public:
-  explicit putThread(std::shared_ptr<Region> r, bool regInt = false,
-                     int waitTime = 0) {
-    m_reg = r;
-    m_regInt = regInt;
-    m_numthreads = 1;
-    m_numops = 0;
-    m_isCallBack = false;
-    m_sameKey = false;
-    m_waitTime = waitTime;
+  explicit PutThread(std::shared_ptr<Region> r, bool regInt = false,
+                     int waitTime = 0)
+      : region_{r},
+        numOps_{0},
+        numThreads_{1},
+        isCallback_{false},
+        sameKey_{false},
+        regInt_{regInt},
+        waitTime_{waitTime} {
   }
 
   void setParams(int opcode, int numofops, int numthreads,
                  bool isCallBack = false, bool sameKey = false,
                  int waitTime = 0) {  //
-    m_opcode = opcode;
-    m_numops = numofops;
-    m_numthreads = numthreads;
-    m_isCallBack = isCallBack;
-    m_sameKey = sameKey;
-    m_waitTime = waitTime;
+    opcode_ = opcode;
+    numOps_ = numofops;
+    numThreads_ = numthreads;
+    isCallback_ = isCallBack;
+    sameKey_ = sameKey;
+    waitTime_ = waitTime;
   }
 
   void start() {
-    m_run = true;
-    activate(THR_NEW_LWP | THR_JOINABLE, m_numthreads);
+    for(auto i = 0; i < numThreads_; ++i) {
+      threads_.emplace_back([this](){
+        run();
+      });
+    }
+  }
+
+  void wait() {
+    for(auto& thread : threads_) {
+      if(thread.joinable()) {
+        thread.join();
+      }
+    }
   }
 
   void stop() {
-    if (m_run) {
-      m_run = false;
       wait();
-    }
   }
 
-  int svc(void) {
+  void run() {
     int ops = 0;
-    auto pid = ACE_OS::getpid();
+    std::string key_str;
     std::shared_ptr<CacheableKey> key;
     std::shared_ptr<CacheableString> value;
     std::vector<std::shared_ptr<CacheableKey>> keys0;
-    char buf[20];
-    char valbuf[20];
-    if (m_regInt) {
-      m_reg->registerAllKeys(false, true);
+
+    auto pid = boost::this_process::get_id();
+    if (regInt_) {
+      region_->registerAllKeys(false, true);
     }
-    if (m_waitTime != 0) {
-      ACE_OS::sleep(m_waitTime);
+    if (waitTime_ != 0) {
+      std::this_thread::sleep_for(std::chrono::seconds{waitTime_});
     }
-    while (ops++ < m_numops) {
-      if (m_sameKey) {
-        sprintf(buf, "key-%d", 1);
+    while (ops++ < numOps_) {
+      if (sameKey_) {
+        key_str = "key-1";
       } else {
-        sprintf(buf, "key-%d", ops);
+        key_str = "key-" + std::to_string(ops);
       }
-      key = CacheableKey::create(buf);
-      if (m_opcode == 0) {
-        if (m_isCallBack) {
+
+      key = CacheableKey::create(key_str);
+      if (opcode_ == 0) {
+        std::string value_str;
+
+        if (isCallback_) {
           auto boolptr = CacheableBoolean::create("true");
-          sprintf(valbuf, "client1-value%d", ops);
-          value = CacheableString::create(valbuf);
-          m_reg->put(key, value, boolptr);
+          value_str = "client1-value" + std::to_string(ops);
+          value = CacheableString::create(value_str);
+          region_->put(key, value, boolptr);
         } else {
-          sprintf(valbuf, "client2-value%d", ops);
-          value = CacheableString::create(valbuf);
-          m_reg->put(key, value);
+          value_str = "client2-value" + std::to_string(ops);
+          value = CacheableString::create(value_str);
+          region_->put(key, value);
         }
-      } else if (m_opcode == 1) {
-        m_reg->get(key);
-      } else if (m_opcode == 5) {
+      } else if (opcode_ == 1) {
+        region_->get(key);
+      } else if (opcode_ == 5) {
         keys0.push_back(key);
-        if (ops == m_numops) {
-          m_reg->registerKeys(keys0, false, true);
+        if (ops == numOps_) {
+          region_->registerKeys(keys0, false, true);
         }
-      } else if (m_opcode == 6) {
-        m_reg->registerRegex("key-[1-3]", false, true);
+      } else if (opcode_ == 6) {
+        region_->registerRegex("key-[1-3]", false, true);
       } else {
         try {
-          if (m_isCallBack) {
+          if (isCallback_) {
             auto boolptr = CacheableBoolean::create("true");
-            m_reg->destroy(key, boolptr);
+            region_->destroy(key, boolptr);
           } else {
-            m_reg->destroy(key);
+            region_->destroy(key);
           }
         } catch (Exception& ex) {
-          printf("%d: %" PRIu64 " exception got and exception message = %s\n",
-                 pid, hacks::aceThreadId(ACE_OS::thr_self()), ex.what());
+          auto tid =
+              boost::lexical_cast<std::string>(std::this_thread::get_id());
+          std::cout << pid << ": " << tid << " exception got and exception message = " << ex.what() << "\n";
         }
       }
     }
-    return 0;
   }
 
-  std::shared_ptr<Region> m_reg;
-  bool m_run;
-  int m_opcode;
-  int m_numops;
-  int m_numthreads;
-  bool m_isCallBack;
-  bool m_sameKey;
-  bool m_regInt;
-  int m_waitTime;
+ protected:
+  std::shared_ptr<Region> region_;
+
+  int opcode_;
+  int numOps_;
+  int numThreads_;
+  bool isCallback_;
+  bool sameKey_;
+  bool regInt_;
+  int waitTime_;
+
+  std::vector<std::thread> threads_;
 };
 
 }  // namespace
