@@ -21,11 +21,9 @@
 #define GEODE_INTEGRATION_TEST_THINCLIENTTRANSACTIONS_H_
 
 #include "fw_dunit.hpp"
-#include <ace/Auto_Event.h>
-#include <ace/OS.h>
-#include <ace/High_Res_Timer.h>
 
 #include <string>
+
 #include <geode/TransactionId.hpp>
 #include <geode/CacheTransactionManager.hpp>
 
@@ -33,9 +31,11 @@
 #define ROOT_SCOPE DISTRIBUTED_ACK
 
 #include "CacheHelper.hpp"
+#include "util/concurrent/binary_semaphore.hpp"
 
-namespace { // NOLINT(google-build-namespaces)
+namespace {  // NOLINT(google-build-namespaces)
 
+using apache::geode::client::binary_semaphore;
 using apache::geode::client::CacheableKey;
 using apache::geode::client::CacheableString;
 using apache::geode::client::CacheHelper;
@@ -58,7 +58,7 @@ static bool isLocalServer = false;
 static bool isLocator = false;
 static int numberOfLocators = 0;
 
-const char* locatorsG =
+const std::string locatorsG =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, numberOfLocators);
 
 void initClient(const bool isthinClient) {
@@ -86,20 +86,18 @@ void _verifyEntry(const char* name, const char* key, const char* val,
                   bool noKey) {
   // Verify key and value exist in this region, in this process.
   const char* value = val ? val : "";
-  char* buf =
-      reinterpret_cast<char*>(malloc(1024 + strlen(key) + strlen(value)));
-  ASSERT(buf, "Unable to malloc buffer for logging.");
+  std::string msg;
   if (noKey) {
-    sprintf(buf, "Verify key %s does not exist in region %s", key, name);
+    msg =
+        std::string("Verify key ") + key + " does not exist in region " + name;
   } else if (!val) {
-    sprintf(buf, "Verify value for key %s does not exist in region %s", key,
-            name);
+    msg = std::string("Verify value for key ") + key +
+          " does not exist in region " + name;
   } else {
-    sprintf(buf, "Verify value for key %s is: %s in region %s", key, value,
-            name);
+    msg = std::string("Verify value for key ") + key + " is: " + value +
+          " in region " + name;
   }
-  LOG(buf);
-  free(buf);
+  LOG(msg);
 
   auto regPtr = getHelper()->getRegion(name);
   ASSERT(regPtr != nullptr, "Region not found.");
@@ -144,7 +142,8 @@ void _verifyEntry(const char* name, const char* key, const char* val,
           std::dynamic_pointer_cast<CacheableString>(regPtr->get(keyPtr));
 
       ASSERT(checkPtr != nullptr, "Value Ptr should not be null.");
-      LOG("In verify loop, get returned " + checkPtr->value() + " for key " + key);
+      LOG("In verify loop, get returned " + checkPtr->value() + " for key " +
+          key);
 
       if (strcmp(checkPtr->value().c_str(), value) != 0) {
         testValueCnt++;
@@ -161,9 +160,7 @@ void _verifyEntry(const char* name, const char* key, const char* val,
 
 void _verifyEntry(const char* name, const char* key, const char* val,
                   int line) {
-  char logmsg[1024];
-  sprintf(logmsg, "verifyEntry() called from %d.\n", line);
-  LOG(logmsg);
+  LOG(std::string("verifyEntry() called from ") + std::to_string(line) + "\n");
   _verifyEntry(name, key, val, false);
   LOG("Entry verified.");
 }
@@ -172,20 +169,23 @@ void createRegion(const char* name, bool ackMode, const char* endpoints,
                   bool clientNotificationEnabled = false,
                   bool cachingEnable = true) {
   LOG("createRegion() entered.");
-  fprintf(stdout, "Creating region --  %s  ackMode is %d\n", name, ackMode);
-  fflush(stdout);
+  std::cout << "Creating region --  " << name << " ackMode is " << ackMode
+            << "\n"
+            << std::flush;
   auto regPtr = getHelper()->createRegion(name, ackMode, cachingEnable, nullptr,
                                           endpoints, clientNotificationEnabled);
   ASSERT(regPtr != nullptr, "Failed to create region.");
   LOG("Region created.");
 }
-void createPooledRegion(const char* name, bool ackMode, const char* locators,
-                        const char* poolname,
+void createPooledRegion(const std::string& name, bool ackMode,
+                        const std::string& locators,
+                        const std::string& poolname,
                         bool clientNotificationEnabled = false,
                         bool cachingEnable = true) {
   LOG("createRegion_Pool() entered.");
-  fprintf(stdout, "Creating region --  %s  ackMode is %d\n", name, ackMode);
-  fflush(stdout);
+  std::cout << "Creating region --  " << name << " ackMode is " << ackMode
+            << "\n"
+            << std::flush;
   auto regPtr =
       getHelper()->createPooledRegion(name, ackMode, locators, poolname,
                                       cachingEnable, clientNotificationEnabled);
@@ -193,13 +193,15 @@ void createPooledRegion(const char* name, bool ackMode, const char* locators,
   LOG("Pooled Region created.");
 }
 
-void createPooledRegionSticky(const char* name, bool ackMode,
-                              const char* locators, const char* poolname,
+void createPooledRegionSticky(const std::string& name, bool ackMode,
+                              const std::string& locators,
+                              const std::string& poolname,
                               bool clientNotificationEnabled = false,
                               bool cachingEnable = true) {
   LOG("createRegion_Pool() entered.");
-  fprintf(stdout, "Creating region --  %s  ackMode is %d\n", name, ackMode);
-  fflush(stdout);
+  std::cout << "Creating region --  " << name << " ackMode is " << ackMode
+            << "\n"
+            << std::flush;
   auto regPtr = getHelper()->createPooledRegionSticky(
       name, ackMode, locators, poolname, cachingEnable,
       clientNotificationEnabled);
@@ -209,9 +211,9 @@ void createPooledRegionSticky(const char* name, bool ackMode,
 
 void createEntry(const char* name, const char* key, const char* value) {
   LOG("createEntry() entered.");
-  fprintf(stdout, "Creating entry -- key: %s  value: %s in region %s\n", key,
-          value, name);
-  fflush(stdout);
+  std::cout << "Creating entry -- key: " << key << " value: " << value
+            << " in region " << name << "\n"
+            << std::flush;
   // Create entry, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
   auto valPtr = CacheableString::create(value);
@@ -233,10 +235,8 @@ void createEntry(const char* name, const char* key, const char* value) {
 }
 void createEntryTwice(const char* name, const char* key, const char* value) {
   LOG("createEntryTwice() entered.");
-  char message[500];
-  sprintf(message, "Creating entry -- key: %s  value: %s in region %s\n", key,
-          value, name);
-  LOG(message);
+  LOG(std::string("Creating entry -- key: ") + key + " value : " + value +
+      " in region " + name);
   auto keyPtr = CacheableKey::create(key);
   auto valPtr = CacheableString::create(value);
   auto regPtr = getHelper()->getRegion(name);
@@ -256,9 +256,10 @@ void createEntryTwice(const char* name, const char* key, const char* value) {
 
 void updateEntry(const char* name, const char* key, const char* value) {
   LOG("updateEntry() entered.");
-  fprintf(stdout, "Updating entry -- key: %s  value: %s in region %s\n", key,
-          value, name);
-  fflush(stdout);
+  std::cout << "Updating entry -- key: " << key << " value: " << value
+            << " in region " << name << "\n"
+            << std::flush;
+
   // Update entry, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
   auto valPtr = CacheableString::create(value);
@@ -279,16 +280,16 @@ void updateEntry(const char* name, const char* key, const char* value) {
 
 void doGetAgain(const char* name, const char* key, const char* value) {
   LOG("doGetAgain() entered.");
-  fprintf(stdout,
-          "get for entry -- key: %s  expecting value: %s in region %s\n", key,
-          value, name);
-  fflush(stdout);
+  std::cout << "Netsearching for entry -- key: " << key << " value: " << value
+            << " in region " << name << "\n"
+            << std::flush;
+
   // Get entry created in Process A, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
 
   auto regPtr = getHelper()->getRegion(name);
-  fprintf(stdout, "get  region name%s\n", regPtr->getName().c_str());
-  fflush(stdout);
+  std::cout << "netsearch  region " << regPtr->getName() << "\n" << std::flush;
+
   ASSERT(regPtr != nullptr, "Region not found.");
 
   auto checkPtr = std::dynamic_pointer_cast<CacheableString>(
@@ -296,10 +297,8 @@ void doGetAgain(const char* name, const char* key, const char* value) {
 
   if (checkPtr != nullptr) {
     LOG("checkPtr is not null");
-    char buf[1024];
-    sprintf(buf, "In doGetAgain, get returned %s for key %s",
-            checkPtr->value().c_str(), key);
-    LOG(buf);
+    LOG(std::string("In doGetAgain, get returned ") + checkPtr->value() +
+        " for key  " + key);
   } else {
     LOG("checkPtr is nullptr");
   }
@@ -309,18 +308,17 @@ void doGetAgain(const char* name, const char* key, const char* value) {
 
 void doNetsearch(const char* name, const char* key, const char* value) {
   LOG("doNetsearch() entered.");
-  fprintf(
-      stdout,
-      "Netsearching for entry -- key: %s  expecting value: %s in region %s\n",
-      key, value, name);
-  fflush(stdout);
+  std::cout << "Netsearching for entry -- key: " << key
+            << " expecting value: " << value << " in region " << name << "\n"
+            << std::flush;
+
   static int count = 0;
   // Get entry created in Process A, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
 
   auto regPtr = getHelper()->getRegion(name);
-  fprintf(stdout, "netsearch  region %s\n", regPtr->getName().c_str());
-  fflush(stdout);
+  std::cout << "netsearch region " << regPtr->getName() << "\n" << std::flush;
+
   ASSERT(regPtr != nullptr, "Region not found.");
 
   if (count == 0) {
@@ -335,10 +333,8 @@ void doNetsearch(const char* name, const char* key, const char* value) {
 
   if (checkPtr != nullptr) {
     LOG("checkPtr is not null");
-    char buf[1024];
-    sprintf(buf, "In net search, get returned %s for key %s",
-            checkPtr->value().c_str(), key);
-    LOG(buf);
+    LOG(std::string("In net search, get returned ") + checkPtr->value() +
+        " for key " + key);
   } else {
     LOG("checkPtr is nullptr");
   }
@@ -360,79 +356,73 @@ const bool USE_ACK = true;
 const bool NO_ACK = false;
 #include "LocatorHelper.hpp"
 #define THREADERRORCHECK(x, y) \
-  if (!(x)) {                  \
-    m_isFailed = true;         \
-    sprintf(m_error, y);       \
-    return -1;                 \
-  }
-
-class SuspendTransactionThread : public ACE_Task_Base {
- private:
-  TransactionId* m_suspendedTransaction;
-  bool m_sleep;
-  ACE_Auto_Event* m_txEvent;
+  do {                         \
+    if (!(x)) {                \
+      failed_ = true;          \
+      error_ = y;              \
+      return;                  \
+    }                          \
+  } while (0)
 
+class SuspendTransactionThread {
  public:
-  SuspendTransactionThread(bool sleep, ACE_Auto_Event* txEvent)
-      : m_suspendedTransaction(nullptr), m_sleep(sleep), m_txEvent(txEvent) {}
-
-  int svc(void) {
-    char buf[1024];
-    sprintf(buf, " In SuspendTransactionThread");
-    LOG(buf);
+  SuspendTransactionThread(bool sleep, binary_semaphore& event)
+      : sleep_{sleep}, sem_{event} {}
 
+  void run() {
+    LOG(" In SuspendTransactionThread");
     auto txManager = getHelper()->getCache()->getCacheTransactionManager();
 
     txManager->begin();
-
     createEntry(regionNames[0], keys[4], vals[4]);
     createEntry(regionNames[1], keys[5], vals[5]);
 
-    m_suspendedTransaction = &txManager->getTransactionId();
+    tx_ = &txManager->getTransactionId();
 
-    if (m_sleep) {
-      m_txEvent->wait();
-      ACE_OS::sleep(5);
+    if (sleep_) {
+      sem_.acquire();
+
+      std::this_thread::sleep_for(std::chrono::seconds{5});
     }
 
-    m_suspendedTransaction = &txManager->suspend();
-    sprintf(buf, " Out SuspendTransactionThread");
-    LOG(buf);
+    tx_ = &txManager->suspend();
+    LOG(" Out SuspendTransactionThread");
 
     getHelper()
         ->getCache()
         ->getPoolManager()
         .find("__TESTPOOL1_")
         ->releaseThreadLocalConnection();
-
-    return 0;
   }
-  void start() { activate(); }
-  void stop() { wait(); }
-  TransactionId& getSuspendedTx() { return *m_suspendedTransaction; }
+
+  void start() {
+    thread_ = std::thread{[this]() { run(); }};
+  }
+
+  void stop() {
+    if (thread_.joinable()) {
+      thread_.join();
+    }
+  }
+
+  TransactionId& getSuspendedTx() { return *tx_; }
+
+ protected:
+  bool sleep_;
+  std::thread thread_;
+  binary_semaphore& sem_;
+  TransactionId* tx_{nullptr};
 };
-class ResumeTransactionThread : public ACE_Task_Base {
- private:
-  TransactionId& m_suspendedTransaction;
-  bool m_commit;
-  bool m_tryResumeWithSleep;
-  bool m_isFailed;
-  char m_error[256];
-  ACE_Auto_Event* m_txEvent;
 
+class ResumeTransactionThread {
  public:
-  ResumeTransactionThread(TransactionId& suspendedTransaction, bool commit,
-                          bool tryResumeWithSleep, ACE_Auto_Event* txEvent)
-      : m_suspendedTransaction(suspendedTransaction),
-        m_commit(commit),
-        m_tryResumeWithSleep(tryResumeWithSleep),
-        m_isFailed(false),
-        m_txEvent(txEvent) {}
 
-  int svc(void) {
-    char buf[1024];
-    sprintf(buf, "In ResumeTransactionThread");
-    LOG(buf);
+  ResumeTransactionThread(TransactionId& tx, bool commit, bool sleep,
+                          binary_semaphore& event)
+      : tx_(tx), commit_{commit}, sleep_(sleep), failed_{false}, sem_{event} {}
+
+  void run() {
+    LOG("In ResumeTransactionThread");
 
     auto regPtr0 = getHelper()->getRegion(regionNames[0]);
     THREADERRORCHECK(regPtr0 != nullptr,
@@ -455,25 +445,25 @@ class ResumeTransactionThread : public ACE_Task_Base {
                      "found in region.");
 
     auto txManager = getHelper()->getCache()->getCacheTransactionManager();
-    if (m_tryResumeWithSleep) {
-      THREADERRORCHECK(!txManager->isSuspended(m_suspendedTransaction),
+    if (sleep_) {
+      THREADERRORCHECK(!txManager->isSuspended(tx_),
                        "In ResumeTransactionThread - the transaction should "
                        "NOT be in suspended state");
     } else {
-      THREADERRORCHECK(txManager->isSuspended(m_suspendedTransaction),
+      THREADERRORCHECK(txManager->isSuspended(tx_),
                        "In ResumeTransactionThread - the transaction should be "
                        "in suspended state");
     }
 
     THREADERRORCHECK(
-        txManager->exists(m_suspendedTransaction),
+        txManager->exists(tx_),
         "In ResumeTransactionThread - the transaction should exist");
 
-    if (m_tryResumeWithSleep) {
-      m_txEvent->signal();
-      txManager->tryResume(m_suspendedTransaction, std::chrono::seconds(30));
+    if (sleep_) {
+      sem_.release();
+      txManager->tryResume(tx_, std::chrono::seconds(30));
     } else {
-      txManager->resume(m_suspendedTransaction);
+      txManager->resume(tx_);
     }
 
     THREADERRORCHECK(
@@ -485,7 +475,7 @@ class ResumeTransactionThread : public ACE_Task_Base {
 
     createEntry(regionNames[1], keys[6], vals[6]);
 
-    if (m_commit) {
+    if (commit_) {
       txManager->commit();
       THREADERRORCHECK(
           regPtr0->containsKeyOnServer(keyPtr4),
@@ -510,7 +500,7 @@ class ResumeTransactionThread : public ACE_Task_Base {
                        "found in region.");
     }
 
-    if (m_commit) {
+    if (commit_) {
       regPtr1->destroy(keyPtr6);
       regPtr1->destroy(keyPtr5);
       regPtr0->destroy(keyPtr4);
@@ -544,19 +534,38 @@ class ResumeTransactionThread : public ACE_Task_Base {
         LOG("Got expected EntryNotFoundException for keyPtr4");
       }
     }
+
     getHelper()
         ->getCache()
         ->getPoolManager()
         .find("__TESTPOOL1_")
         ->releaseThreadLocalConnection();
-    sprintf(buf, " Out ResumeTransactionThread");
-    LOG(buf);
-    return 0;
+    LOG(" Out ResumeTransactionThread");
   }
-  void start() { activate(); }
-  void stop() { wait(); }
-  bool isFailed() { return m_isFailed; }
-  char* getError() { return m_error; }
+
+  void start() {
+    thread_ = std::thread{[this]() { run(); }};
+  }
+
+  void stop() {
+    if (thread_.joinable()) {
+      thread_.join();
+    }
+  }
+
+  bool isFailed() { return failed_; }
+
+  std::string getError() { return error_; }
+
+ protected:
+  TransactionId& tx_;
+  bool commit_;
+  bool sleep_;
+  bool failed_;
+  std::string error_;
+
+  std::thread thread_;
+  binary_semaphore& sem_;
 };
 
 DUNIT_TASK_DEFINITION(SERVER1, CreateServer1)
@@ -674,7 +683,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, SuspendTimeOut)
     ASSERT(txManager->exists(tid2),
            "In SuspendTimeOut - the transaction should exist");
 
-    ACE_OS::sleep(65);
+    std::this_thread::sleep_for(std::chrono::seconds(65));
     ASSERT(!txManager->tryResume(tid2),
            "In SuspendTimeOut - the transaction should NOT have been resumed");
     ASSERT(!txManager->isSuspended(tid2),
@@ -777,86 +786,78 @@ DUNIT_TASK_DEFINITION(CLIENT1, SuspendResumeRollback)
 END_TASK_DEFINITION
 DUNIT_TASK_DEFINITION(CLIENT1, SuspendResumeInThread)
   {
-    // start suspend thread  and resume thread and rollback immedidately
-    char buf[1024];
-    sprintf(
-        buf,
-        "start suspend thread  and resume thread and rollback immedidately");
-    LOG(buf);
-    ACE_Auto_Event txEvent;
+    LOG("Start suspend thread and resume thread and rollback immedidately");
 
-    SuspendTransactionThread* suspendTh =
-        new SuspendTransactionThread(false, &txEvent);
-    suspendTh->activate();
-    ACE_OS::sleep(2);
-    ResumeTransactionThread* resumeTh = new ResumeTransactionThread(
-        suspendTh->getSuspendedTx(), false, false, &txEvent);
-    resumeTh->activate();
+    {
+      binary_semaphore event{0};
+      SuspendTransactionThread suspend{false, event};
+      suspend.start();
 
-    suspendTh->wait();
-    delete suspendTh;
-    resumeTh->wait();
-    ASSERT(!resumeTh->isFailed(), resumeTh->getError());
-    delete resumeTh;
+      std::this_thread::sleep_for(std::chrono::seconds{2});
+      ResumeTransactionThread resume{suspend.getSuspendedTx(), false, false,
+                                     event};
+      resume.start();
 
-    // start suspend thread  and resume thread and commit immedidately
-    sprintf(buf,
-            "start suspend thread  and resume thread and commit immedidately");
-    LOG(buf);
-    suspendTh = new SuspendTransactionThread(false, &txEvent);
-    suspendTh->activate();
-    ACE_OS::sleep(2);
-    resumeTh = new ResumeTransactionThread(suspendTh->getSuspendedTx(), true,
-                                           false, &txEvent);
-    resumeTh->activate();
+      suspend.stop();
+      resume.stop();
 
-    suspendTh->wait();
-    delete suspendTh;
-    resumeTh->wait();
-    ASSERT(!resumeTh->isFailed(), resumeTh->getError());
-    delete resumeTh;
+      ASSERT(!resume.isFailed(), resume.getError());
+    }
 
-    // start suspend thread  and tryresume thread with rollback. make tryResume
-    // to
-    // sleep
-    sprintf(buf,
-            "start suspend thread  and tryresume thread with rollback. make "
-            "tryResume to sleep");
-    LOG(buf);
-    suspendTh = new SuspendTransactionThread(true, &txEvent);
-    suspendTh->activate();
-    ACE_OS::sleep(2);
-    resumeTh = new ResumeTransactionThread(suspendTh->getSuspendedTx(), false,
-                                           true, &txEvent);
-    resumeTh->activate();
+    LOG("Start suspend thread  and resume thread and commit immedidately");
+    {
+      binary_semaphore event{0};
+      SuspendTransactionThread suspend{false, event};
 
-    suspendTh->wait();
-    delete suspendTh;
-    resumeTh->wait();
-    ASSERT(!resumeTh->isFailed(), resumeTh->getError());
-    delete resumeTh;
+      suspend.start();
+      std::this_thread::sleep_for(std::chrono::seconds{2});
+      ResumeTransactionThread resume{suspend.getSuspendedTx(), true, false,
+                                     event};
+      resume.start();
 
-    // start suspend thread  and tryresume thread with commit. make tryResume to
-    // sleep
-    sprintf(buf,
-            "start suspend thread  and tryresume thread with commit. make "
-            "tryResume to sleep");
-    LOG(buf);
-    suspendTh = new SuspendTransactionThread(true, &txEvent);
-    suspendTh->activate();
-    ACE_OS::sleep(2);
-    sprintf(buf, "suspendTh->activate();");
-    LOG(buf);
+      suspend.stop();
+      resume.stop();
+      ASSERT(!resume.isFailed(), resume.getError());
+    }
 
-    resumeTh = new ResumeTransactionThread(suspendTh->getSuspendedTx(), true,
-                                           true, &txEvent);
-    resumeTh->activate();
+    LOG("Start suspend thread  and tryresume thread with rollback. make "
+        "tryResume to sleep");
+    {
+      binary_semaphore event{0};
+      SuspendTransactionThread suspend{true, event};
+      suspend.start();
 
-    suspendTh->wait();
-    delete suspendTh;
-    resumeTh->wait();
-    ASSERT(!resumeTh->isFailed(), resumeTh->getError());
-    delete resumeTh;
+      std::this_thread::sleep_for(std::chrono::seconds{2});
+      ResumeTransactionThread resume{suspend.getSuspendedTx(), false, true,
+                                     event};
+      resume.start();
+
+      suspend.stop();
+      resume.stop();
+
+      ASSERT(!resume.isFailed(), resume.getError());
+    }
+
+    LOG("Start suspend thread  and tryresume thread with commit. make "
+        "tryResume to sleep");
+
+    {
+      binary_semaphore event{0};
+      SuspendTransactionThread suspend{true, event};
+      suspend.start();
+
+      std::this_thread::sleep_for(std::chrono::seconds{2});
+      LOG("suspendTh->activate();");
+
+      ResumeTransactionThread resume{suspend.getSuspendedTx(), true, true,
+                                     event};
+      resume.start();
+
+      suspend.stop();
+      resume.stop();
+
+      ASSERT(!resume.isFailed(), resume.getError());
+    }
   }
 END_TASK_DEFINITION
 
@@ -869,10 +870,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, CreateNonexistentServerRegion_Pooled_Locator)
       FAIL(
           "Expected exception when doing operations on a non-existent region.");
     } catch (const CacheServerException& ex) {
-      printf(
-          "Got expected CacheServerException when performing operation "
-          "on a non-existent region: %s\n",
-          ex.what());
+      std::cout << "Got expected CacheServerException when performing operation on a non-existent region: " << ex.what() << "\n";
     }
   }
 END_TASK_DEFINITION
@@ -887,10 +885,7 @@ DUNIT_TASK_DEFINITION(CLIENT1,
       FAIL(
           "Expected exception when doing operations on a non-existent region.");
     } catch (const CacheServerException& ex) {
-      printf(
-          "Got expected CacheServerException when performing operation "
-          "on a non-existent region: %s\n",
-          ex.what());
+      std::cout << "Got expected CacheServerException when performing operation on a non-existent region: " << ex.what() << "\n";
     }
   }
 END_TASK_DEFINITION
@@ -1016,13 +1011,13 @@ DUNIT_TASK_DEFINITION(CLIENT1, CreateClient1KeyThriceWithoutSticky)
     try {
       reg->create(keyPtr, valPtr);
       char message[200];
-      sprintf(message, "First create on Key %s ", CREATE_TWICE_KEY);
+      LOG(std::string("First create on Key ") + CREATE_TWICE_KEY);
       LOG(message);
       reg->create(keyPtr, valPtr);
-      sprintf(message, "Second create on Key %s ", CREATE_TWICE_KEY);
+      LOG(std::string("Second create on Key ") + CREATE_TWICE_KEY);
       LOG(message);
       reg->create(keyPtr, valPtr);
-      sprintf(message, "Third create on Key %s ", CREATE_TWICE_KEY);
+      LOG(std::string("Third create on Key ") + CREATE_TWICE_KEY);
       LOG(message);
     } catch (const EntryExistsException& geodeExcp) {
       LOG(geodeExcp.what());
@@ -1057,13 +1052,13 @@ DUNIT_TASK_DEFINITION(CLIENT1, CreateClient1KeyThriceWithSticky)
     try {
       reg->create(keyPtr, valPtr);
       char message[200];
-      sprintf(message, "First create on Key %s ", CREATE_TWICE_KEY);
+      LOG(std::string("First create on Key ") + CREATE_TWICE_KEY);
       LOG(message);
       reg->create(keyPtr, valPtr);
-      sprintf(message, "Second create on Key %s ", CREATE_TWICE_KEY);
+      LOG(std::string("Second create on Key ") + CREATE_TWICE_KEY);
       LOG(message);
       reg->create(keyPtr, valPtr);
-      sprintf(message, "Third create on Key %s ", CREATE_TWICE_KEY);
+      LOG(std::string("Third create on Key ") + CREATE_TWICE_KEY);
       LOG(message);
     } catch (const EntryExistsException& geodeExcp) {
       LOG(geodeExcp.what());
