@@ -21,9 +21,6 @@
 #define GEODE_INTEGRATION_TEST_THINCLIENTTRANSACTIONSXA_H_
 
 #include "fw_dunit.hpp"
-#include <ace/Auto_Event.h>
-#include <ace/OS.h>
-#include <ace/High_Res_Timer.h>
 
 #include <string>
 #include <geode/TransactionId.hpp>
@@ -34,16 +31,19 @@
 
 #include "CacheHelper.hpp"
 
-namespace { // NOLINT(google-build-namespaces)
+#include "util/concurrent/binary_semaphore.hpp"
 
+namespace {  // NOLINT(google-build-namespaces)
+
+using apache::geode::client::binary_semaphore;
 using apache::geode::client::CacheableKey;
 using apache::geode::client::CacheableString;
 using apache::geode::client::CacheHelper;
 using apache::geode::client::CacheServerException;
+using apache::geode::client::CacheTransactionManager;
 using apache::geode::client::EntryExistsException;
 using apache::geode::client::EntryNotFoundException;
 using apache::geode::client::IllegalStateException;
-using apache::geode::client::CacheTransactionManager;
 using apache::geode::client::Properties;
 using apache::geode::client::TransactionException;
 using apache::geode::client::TransactionId;
@@ -59,7 +59,7 @@ static bool isLocalServer = false;
 static bool isLocator = false;
 static int numberOfLocators = 0;
 
-const char* locatorsG =
+const std::string locatorsG =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, numberOfLocators);
 
 void initClient(const bool isthinClient) {
@@ -87,20 +87,18 @@ void _verifyEntry(const char* name, const char* key, const char* val,
                   bool noKey) {
   // Verify key and value exist in this region, in this process.
   const char* value = val ? val : "";
-  char* buf =
-      reinterpret_cast<char*>(malloc(1024 + strlen(key) + strlen(value)));
-  ASSERT(buf, "Unable to malloc buffer for logging.");
+  std::string msg;
   if (noKey) {
-    sprintf(buf, "Verify key %s does not exist in region %s", key, name);
+    msg =
+        std::string("Verify key ") + key + " does not exist in region " + name;
   } else if (!val) {
-    sprintf(buf, "Verify value for key %s does not exist in region %s", key,
-            name);
+    msg = std::string("Verify value for key ") + key +
+          " does not exist in region " + name;
   } else {
-    sprintf(buf, "Verify value for key %s is: %s in region %s", key, value,
-            name);
+    msg = std::string("Verify value for key ") + key + " is: " + value +
+          " in region " + name;
   }
-  LOG(buf);
-  free(buf);
+  LOG(msg);
 
   auto regPtr = getHelper()->getRegion(name);
   ASSERT(regPtr != nullptr, "Region not found.");
@@ -145,7 +143,8 @@ void _verifyEntry(const char* name, const char* key, const char* val,
           std::dynamic_pointer_cast<CacheableString>(regPtr->get(keyPtr));
 
       ASSERT(checkPtr != nullptr, "Value Ptr should not be null.");
-      LOG("In verify loop, get returned " + checkPtr->value() + " for key " + key);
+      LOG("In verify loop, get returned " + checkPtr->value() + " for key " +
+          key);
 
       if (strcmp(checkPtr->value().c_str(), value) != 0) {
         testValueCnt++;
@@ -162,9 +161,7 @@ void _verifyEntry(const char* name, const char* key, const char* val,
 
 void _verifyEntry(const char* name, const char* key, const char* val,
                   int line) {
-  char logmsg[1024];
-  sprintf(logmsg, "verifyEntry() called from %d.\n", line);
-  LOG(logmsg);
+  LOG(std::string("verifyEntry() called from ") + std::to_string(line) + "\n");
   _verifyEntry(name, key, val, false);
   LOG("Entry verified.");
 }
@@ -173,20 +170,23 @@ void createRegion(const char* name, bool ackMode, const char* endpoints,
                   bool clientNotificationEnabled = false,
                   bool cachingEnable = true) {
   LOG("createRegion() entered.");
-  fprintf(stdout, "Creating region --  %s  ackMode is %d\n", name, ackMode);
-  fflush(stdout);
+  std::cout << "Creating region --  " << name << " ackMode is " << ackMode
+            << "\n"
+            << std::flush;
   auto regPtr = getHelper()->createRegion(name, ackMode, cachingEnable, nullptr,
                                           endpoints, clientNotificationEnabled);
   ASSERT(regPtr != nullptr, "Failed to create region.");
   LOG("Region created.");
 }
-void createPooledRegion(const char* name, bool ackMode, const char* locators,
-                        const char* poolname,
+void createPooledRegion(const std::string& name, bool ackMode,
+                        const std::string& locators,
+                        const std::string& poolname,
                         bool clientNotificationEnabled = false,
                         bool cachingEnable = true) {
   LOG("createRegion_Pool() entered.");
-  fprintf(stdout, "Creating region --  %s  ackMode is %d\n", name, ackMode);
-  fflush(stdout);
+  std::cout << "Creating region --  " << name << " ackMode is " << ackMode
+            << "\n" << std::flush;
+
   auto regPtr =
       getHelper()->createPooledRegion(name, ackMode, locators, poolname,
                                       cachingEnable, clientNotificationEnabled);
@@ -194,13 +194,16 @@ void createPooledRegion(const char* name, bool ackMode, const char* locators,
   LOG("Pooled Region created.");
 }
 
-void createPooledRegionSticky(const char* name, bool ackMode,
-                              const char* locators, const char* poolname,
+void createPooledRegionSticky(const std::string& name, bool ackMode,
+                              const std::string& locators,
+                              const std::string& poolname,
                               bool clientNotificationEnabled = false,
                               bool cachingEnable = true) {
   LOG("createRegion_Pool() entered.");
-  fprintf(stdout, "Creating region --  %s  ackMode is %d\n", name, ackMode);
-  fflush(stdout);
+
+  std::cout << "Creating region --  " << name << " ackMode is " << ackMode
+            << "\n" << std::flush;
+
   auto regPtr = getHelper()->createPooledRegionSticky(
       name, ackMode, locators, poolname, cachingEnable,
       clientNotificationEnabled);
@@ -210,9 +213,9 @@ void createPooledRegionSticky(const char* name, bool ackMode,
 
 void createEntry(const char* name, const char* key, const char* value) {
   LOG("createEntry() entered.");
-  fprintf(stdout, "Creating entry -- key: %s  value: %s in region %s\n", key,
-          value, name);
-  fflush(stdout);
+  std::cout << "Creating entry -- key: " << key << " value: " << value
+            << " in region " << name << "\n"
+            << std::flush;
   // Create entry, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
   auto valPtr = CacheableString::create(value);
@@ -234,10 +237,8 @@ void createEntry(const char* name, const char* key, const char* value) {
 }
 void createEntryTwice(const char* name, const char* key, const char* value) {
   LOG("createEntryTwice() entered.");
-  char message[500];
-  sprintf(message, "Creating entry -- key: %s  value: %s in region %s\n", key,
-          value, name);
-  LOG(message);
+  LOG(std::string("Creating entry -- key: ") + key + " value : " + value +
+      " in region " + name);
   auto keyPtr = CacheableKey::create(key);
   auto valPtr = CacheableString::create(value);
   auto regPtr = getHelper()->getRegion(name);
@@ -257,9 +258,9 @@ void createEntryTwice(const char* name, const char* key, const char* value) {
 
 void updateEntry(const char* name, const char* key, const char* value) {
   LOG("updateEntry() entered.");
-  fprintf(stdout, "Updating entry -- key: %s  value: %s in region %s\n", key,
-          value, name);
-  fflush(stdout);
+  std::cout << "Updating entry -- key: " << key << " value: " << value
+            << " in region " << name << "\n"
+            << std::flush;
   // Update entry, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
   auto valPtr = CacheableString::create(value);
@@ -280,16 +281,14 @@ void updateEntry(const char* name, const char* key, const char* value) {
 
 void doGetAgain(const char* name, const char* key, const char* value) {
   LOG("doGetAgain() entered.");
-  fprintf(stdout,
-          "get for entry -- key: %s  expecting value: %s in region %s\n", key,
-          value, name);
-  fflush(stdout);
+  std::cout << "get for entry -- key: " << key << " expecting value: " << value
+            << " in region " << name << "\n"
+            << std::flush;
   // Get entry created in Process A, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
 
   auto regPtr = getHelper()->getRegion(name);
-  fprintf(stdout, "get  region name%s\n", regPtr->getName().c_str());
-  fflush(stdout);
+  std::cout << "get  region name " << regPtr->getName() << "\n" << std::flush;
   ASSERT(regPtr != nullptr, "Region not found.");
 
   auto checkPtr = std::dynamic_pointer_cast<CacheableString>(
@@ -297,10 +296,8 @@ void doGetAgain(const char* name, const char* key, const char* value) {
 
   if (checkPtr != nullptr) {
     LOG("checkPtr is not null");
-    char buf[1024];
-    sprintf(buf, "In doGetAgain, get returned %s for key %s",
-            checkPtr->value().c_str(), key);
-    LOG(buf);
+    LOG(std::string("In doGetAgain, get returned ") + checkPtr->value() +
+        " for key  " + key);
   } else {
     LOG("checkPtr is nullptr");
   }
@@ -310,18 +307,16 @@ void doGetAgain(const char* name, const char* key, const char* value) {
 
 void doNetsearch(const char* name, const char* key, const char* value) {
   LOG("doNetsearch() entered.");
-  fprintf(
-      stdout,
-      "Netsearching for entry -- key: %s  expecting value: %s in region %s\n",
-      key, value, name);
-  fflush(stdout);
+  std::cout << "Netsearching for entry -- key: " << key
+            << " expecting value: " << value << " in region " << name << "\n"
+            << std::flush;
   static int count = 0;
   // Get entry created in Process A, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
 
   auto regPtr = getHelper()->getRegion(name);
-  fprintf(stdout, "netsearch  region %s\n", regPtr->getName().c_str());
-  fflush(stdout);
+  std::cout << "netsearch region " << regPtr->getName() << "\n" << std::flush;
+
   ASSERT(regPtr != nullptr, "Region not found.");
 
   if (count == 0) {
@@ -336,10 +331,8 @@ void doNetsearch(const char* name, const char* key, const char* value) {
 
   if (checkPtr != nullptr) {
     LOG("checkPtr is not null");
-    char buf[1024];
-    sprintf(buf, "In net search, get returned %s for key %s",
-            checkPtr->value().c_str(), key);
-    LOG(buf);
+    LOG(std::string("In net search, get returned ") + checkPtr->value() +
+        " for key " + key);
   } else {
     LOG("checkPtr is nullptr");
   }
@@ -355,88 +348,82 @@ const char* nvals[] = {"New Value-1", "New Value-2", "New Value-3",
                        "New Value-4", "New Value-5", "New Value-6",
                        "New Value-7"};
 
-const char* regionNames[] = {"DistRegionAck", "DistRegionNoAck", "testregion"};
+const char* regionNames[] = {"DistRegionAck", "not-used", "not-used"};
 
 const bool USE_ACK = true;
 const bool NO_ACK = false;
 #include "LocatorHelper.hpp"
 #define THREADERRORCHECK(x, y) \
-  if (!(x)) {                  \
-    m_isFailed = true;         \
-    sprintf(m_error, y);       \
-    return -1;                 \
-  }
-
-class SuspendTransactionThread : public ACE_Task_Base {
- private:
-  TransactionId* m_suspendedTransaction;
-  bool m_sleep;
-  ACE_Auto_Event* m_txEvent;
+  do {                         \
+    if (!(x)) {                \
+      failed_ = true;          \
+      error_ = y;              \
+      return;                  \
+    }                          \
+  } while (0)
 
+class SuspendTransactionThread {
  public:
-  SuspendTransactionThread(bool sleep, ACE_Auto_Event* txEvent)
-      : m_suspendedTransaction(nullptr), m_sleep(sleep), m_txEvent(txEvent) {}
+  SuspendTransactionThread(bool sleep, binary_semaphore& event)
+      : sleep_{sleep}, tx_{nullptr}, sem_(event) {}
 
-  int svc(void) {
-    char buf[1024];
-    sprintf(buf, " In SuspendTransactionThread");
-    LOG(buf);
+  void run() {
+    LOG(" In SuspendTransactionThread");
 
     auto txManager = getHelper()->getCache()->getCacheTransactionManager();
 
     txManager->begin();
 
     createEntry(regionNames[0], keys[4], vals[4]);
-    createEntry(regionNames[1], keys[5], vals[5]);
 
-    m_suspendedTransaction = &txManager->getTransactionId();
+    tx_ = &txManager->getTransactionId();
 
-    if (m_sleep) {
-      m_txEvent->wait();
-      ACE_OS::sleep(5);
+    if (sleep_) {
+      sem_.acquire();
+      std::this_thread::sleep_for(std::chrono::seconds{5});
     }
 
-    m_suspendedTransaction = &txManager->suspend();
-    sprintf(buf, " Out SuspendTransactionThread");
-    LOG(buf);
+    tx_ = &txManager->suspend();
+    LOG(" Out SuspendTransactionThread");
 
     getHelper()
         ->getCache()
         ->getPoolManager()
         .find("__TESTPOOL1_")
         ->releaseThreadLocalConnection();
+  }
 
-    return 0;
+  void start() {
+    thread_ = std::thread{[this]() { run(); }};
   }
-  void start() { activate(); }
-  void stop() { wait(); }
-  TransactionId& getSuspendedTx() {
-    return *m_suspendedTransaction;
+
+  void stop() {
+    if (thread_.joinable()) {
+      thread_.join();
+    }
   }
+
+  TransactionId& getSuspendedTx() { return *tx_; }
+
+ protected:
+  bool sleep_;
+  TransactionId* tx_;
+  std::thread thread_;
+  binary_semaphore& sem_;
 };
-class ResumeTransactionThread : public ACE_Task_Base {
- private:
-  TransactionId& m_suspendedTransaction;
-  bool m_commit;
-  bool m_tryResumeWithSleep;
-  bool m_isFailed;
-  char m_error[256];
-  ACE_Auto_Event* m_txEvent;
 
+class ResumeTransactionThread {
  public:
-  ResumeTransactionThread(TransactionId& suspendedTransaction,
-                          bool commit, bool tryResumeWithSleep,
-                          ACE_Auto_Event* txEvent)
-      : m_suspendedTransaction(suspendedTransaction),
-        m_commit(commit),
-        m_tryResumeWithSleep(tryResumeWithSleep),
-        m_isFailed(false),
-        m_txEvent(txEvent) {}
+  ResumeTransactionThread(TransactionId& suspendedTransaction, bool commit,
+                          bool tryResumeWithSleep, binary_semaphore& event)
+      : commit_{commit},
+        sleep_{tryResumeWithSleep},
+        failed_{false},
+        tx_{suspendedTransaction},
+        sem_{event} {}
 
-  int svc(void) {
-    char buf[1024];
-    sprintf(buf, "In ResumeTransactionThread");
-    LOG(buf);
+  void run() {
+    LOG("In ResumeTransactionThread");
 
     auto regPtr0 = getHelper()->getRegion(regionNames[0]);
     THREADERRORCHECK(regPtr0 != nullptr,
@@ -446,103 +433,57 @@ class ResumeTransactionThread : public ACE_Task_Base {
     auto keyPtr5 = CacheableKey::create(keys[5]);
     auto keyPtr6 = CacheableKey::create(keys[6]);
 
-    auto regPtr1 = getHelper()->getRegion(regionNames[1]);
-    THREADERRORCHECK(regPtr1 != nullptr,
-                     "In ResumeTransactionThread - Region not found.");
-
     THREADERRORCHECK(!regPtr0->containsKeyOnServer(keyPtr4),
                      "In ResumeTransactionThread - Key should not have been "
                      "found in region.");
 
-    THREADERRORCHECK(!regPtr1->containsKeyOnServer(keyPtr5),
-                     "In ResumeTransactionThread - Key should not have been "
-                     "found in region.");
-
     auto txManager = getHelper()->getCache()->getCacheTransactionManager();
-    if (m_tryResumeWithSleep) {
-      THREADERRORCHECK(!txManager->isSuspended(m_suspendedTransaction),
+    if (sleep_) {
+      THREADERRORCHECK(!txManager->isSuspended(tx_),
                        "In ResumeTransactionThread - the transaction should "
                        "NOT be in suspended state");
     } else {
-      THREADERRORCHECK(txManager->isSuspended(m_suspendedTransaction),
+      THREADERRORCHECK(txManager->isSuspended(tx_),
                        "In ResumeTransactionThread - the transaction should be "
                        "in suspended state");
     }
 
     THREADERRORCHECK(
-        txManager->exists(m_suspendedTransaction),
+        txManager->exists(tx_),
         "In ResumeTransactionThread - the transaction should exist");
 
-    if (m_tryResumeWithSleep) {
-      m_txEvent->signal();
-      txManager->tryResume(m_suspendedTransaction, std::chrono::seconds(30));
+    if (sleep_) {
+      sem_.release();
+      txManager->tryResume(tx_, std::chrono::seconds{30});
     } else {
-      txManager->resume(m_suspendedTransaction);
+      txManager->resume(tx_);
     }
 
     THREADERRORCHECK(
         regPtr0->containsKeyOnServer(keyPtr4),
         "In ResumeTransactionThread - Key should have been found in region.");
-    THREADERRORCHECK(
-        regPtr1->containsKeyOnServer(keyPtr5),
-        "In ResumeTransactionThread - Key should have been found in region.");
 
-    createEntry(regionNames[1], keys[6], vals[6]);
-
-    if (m_commit) {
+    if (commit_) {
       txManager->prepare();
       txManager->commit();
       THREADERRORCHECK(
           regPtr0->containsKeyOnServer(keyPtr4),
           "In ResumeTransactionThread - Key should have been found in region.");
-      THREADERRORCHECK(
-          regPtr1->containsKeyOnServer(keyPtr5),
-          "In ResumeTransactionThread - Key should have been found in region.");
-      THREADERRORCHECK(
-          regPtr1->containsKeyOnServer(keyPtr6),
-          "In ResumeTransactionThread - Key should have been found in region.");
-
     } else {
       txManager->prepare();
       txManager->rollback();
       THREADERRORCHECK(!regPtr0->containsKeyOnServer(keyPtr4),
                        "In ResumeTransactionThread - Key should not have been "
                        "found in region.");
-      THREADERRORCHECK(!regPtr1->containsKeyOnServer(keyPtr5),
-                       "In ResumeTransactionThread - Key should not have been "
-                       "found in region.");
-      THREADERRORCHECK(!regPtr1->containsKeyOnServer(keyPtr6),
-                       "In ResumeTransactionThread - Key should not have been "
-                       "found in region.");
     }
 
-    if (m_commit) {
-      regPtr1->destroy(keyPtr6);
-      regPtr1->destroy(keyPtr5);
+    if (commit_) {
       regPtr0->destroy(keyPtr4);
 
-      THREADERRORCHECK(!regPtr1->containsKeyOnServer(keyPtr6),
-                       "In ResumeTransactionThread - Key should not have been "
-                       "found in region.");
-      THREADERRORCHECK(!regPtr1->containsKeyOnServer(keyPtr5),
-                       "In ResumeTransactionThread - Key should not have been "
-                       "found in region.");
       THREADERRORCHECK(!regPtr0->containsKeyOnServer(keyPtr4),
                        "In ResumeTransactionThread - Key should not have been "
                        "found in region.");
     } else {
-      try {
-        regPtr1->destroy(keyPtr6);
-        FAIL("Should have got EntryNotFoundException for keyPtr6");
-      } catch (EntryNotFoundException& /*ex*/) {
-        LOG("Got expected EntryNotFoundException for keyPtr6");
-      }
-      try {
-        regPtr1->destroy(keyPtr5);
-        FAIL("Should have got EntryNotFoundException for keyPtr5");
-      } catch (EntryNotFoundException& /*ex*/) {
-        LOG("Got expected EntryNotFoundException for keyPtr5");
-      }
       try {
         regPtr0->destroy(keyPtr4);
         FAIL("Should have got EntryNotFoundException for keyPtr4");
@@ -550,19 +491,36 @@ class ResumeTransactionThread : public ACE_Task_Base {
         LOG("Got expected EntryNotFoundException for keyPtr4");
       }
     }
+
     getHelper()
         ->getCache()
         ->getPoolManager()
         .find("__TESTPOOL1_")
         ->releaseThreadLocalConnection();
-    sprintf(buf, " Out ResumeTransactionThread");
-    LOG(buf);
-    return 0;
+    LOG("Out ResumeTransactionThread");
   }
-  void start() { activate(); }
-  void stop() { wait(); }
-  bool isFailed() { return m_isFailed; }
-  char* getError() { return m_error; }
+
+  void start() {
+    thread_ = std::thread{[this]() { run(); }};
+  }
+
+  void stop() {
+    if (thread_.joinable()) {
+      thread_.join();
+    }
+  }
+
+  bool isFailed() { return failed_; }
+  const std::string& getError() { return error_; }
+
+ protected:
+  bool commit_;
+  bool sleep_;
+  bool failed_;
+  std::string error_;
+  TransactionId& tx_;
+  std::thread thread_;
+  binary_semaphore& sem_;
 };
 
 DUNIT_TASK_DEFINITION(SERVER1, CreateServer1)
@@ -577,23 +535,18 @@ DUNIT_TASK_DEFINITION(CLIENT1, SuspendResumeCommit)
     auto txManager = getHelper()->getCache()->getCacheTransactionManager();
     auto regPtr0 = getHelper()->getRegion(regionNames[0]);
     ASSERT(regPtr0 != nullptr, "In SuspendResumeCommit - Region not found.");
-    auto regPtr1 = getHelper()->getRegion(regionNames[1]);
-    ASSERT(regPtr1 != nullptr, "In SuspendResumeCommit - Region not found.");
+
     auto keyPtr4 = CacheableKey::create(keys[4]);
     auto keyPtr5 = CacheableKey::create(keys[5]);
     auto keyPtr6 = CacheableKey::create(keys[6]);
 
     txManager->begin();
     createEntry(regionNames[0], keys[4], vals[4]);
-    createEntry(regionNames[1], keys[5], vals[5]);
     auto& m_suspendedTransaction = txManager->suspend();
 
     ASSERT(
         !regPtr0->containsKeyOnServer(keyPtr4),
         "In SuspendResumeCommit - Key should not have been found in region.");
-    ASSERT(
-        !regPtr1->containsKeyOnServer(keyPtr5),
-        "In SuspendResumeCommit - Key should not have been found in region.");
 
     ASSERT(txManager->isSuspended(m_suspendedTransaction),
            "In SuspendResumeCommit - the transaction should be in suspended "
@@ -608,22 +561,12 @@ DUNIT_TASK_DEFINITION(CLIENT1, SuspendResumeCommit)
         "SuspendResumeRollback: Transaction shouldnt have been resumed again");
     ASSERT(regPtr0->containsKeyOnServer(keyPtr4),
            "In SuspendResumeCommit - Key should have been found in region.");
-    ASSERT(regPtr1->containsKeyOnServer(keyPtr5),
-           "In SuspendResumeCommit - Key should have been found in region.");
-
-    createEntry(regionNames[1], keys[6], vals[6]);
 
     txManager->prepare();
     txManager->commit();
     ASSERT(regPtr0->containsKeyOnServer(keyPtr4),
            "In SuspendResumeCommit - Key should have been found in region.");
-    ASSERT(regPtr1->containsKeyOnServer(keyPtr5),
-           "In SuspendResumeCommit - Key should have been found in region.");
-    ASSERT(regPtr1->containsKeyOnServer(keyPtr6),
-           "In SuspendResumeCommit - Key should have been found in region.");
 
-    regPtr1->destroy(keyPtr6);
-    regPtr1->destroy(keyPtr5);
     regPtr0->destroy(keyPtr4);
 
     ASSERT(!txManager->isSuspended(m_suspendedTransaction),
@@ -687,7 +630,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, SuspendTimeOut)
     ASSERT(!regPtr0->containsKeyOnServer(keyPtr5),
            "In SuspendTimeOut - Key should not have been found in region.");
 
-    ACE_OS::sleep(65);
+    std::this_thread::sleep_for(std::chrono::seconds(65));
     ASSERT(!txManager->tryResume(tid2),
            "In SuspendTimeOut - the transaction should NOT have been resumed");
     ASSERT(!txManager->isSuspended(tid2),
@@ -706,20 +649,14 @@ DUNIT_TASK_DEFINITION(CLIENT1, SuspendResumeRollback)
 
     auto regPtr0 = getHelper()->getRegion(regionNames[0]);
     ASSERT(regPtr0 != nullptr, "In SuspendResumeRollback - Region not found.");
-    auto regPtr1 = getHelper()->getRegion(regionNames[1]);
-    ASSERT(regPtr1 != nullptr, "In SuspendResumeRollback - Region not found.");
 
     txManager->begin();
     createEntry(regionNames[0], keys[4], vals[4]);
-    createEntry(regionNames[1], keys[5], vals[5]);
     auto& m_suspendedTransaction = txManager->suspend();
 
     ASSERT(
         !regPtr0->containsKeyOnServer(keyPtr4),
         "In SuspendResumeRollback - Key should not have been found in region.");
-    ASSERT(
-        !regPtr1->containsKeyOnServer(keyPtr5),
-        "In SuspendResumeRollback - Key should not have been found in region.");
 
     ASSERT(txManager->isSuspended(m_suspendedTransaction),
            "In SuspendResumeRollback the transaction should be in suspended "
@@ -731,35 +668,13 @@ DUNIT_TASK_DEFINITION(CLIENT1, SuspendResumeRollback)
 
     ASSERT(regPtr0->containsKeyOnServer(keyPtr4),
            "In SuspendResumeRollback - Key should have been found in region.");
-    ASSERT(regPtr1->containsKeyOnServer(keyPtr5),
-           "In SuspendResumeRollback - Key should have been found in region.");
-
-    createEntry(regionNames[1], keys[6], vals[6]);
 
     txManager->prepare();
     txManager->rollback();
     ASSERT(
         !regPtr0->containsKeyOnServer(keyPtr4),
         "In SuspendResumeRollback - Key should not have been found in region.");
-    ASSERT(
-        !regPtr1->containsKeyOnServer(keyPtr5),
-        "In SuspendResumeRollback - Key should not have been found in region.");
-    ASSERT(
-        !regPtr1->containsKeyOnServer(keyPtr6),
-        "In SuspendResumeRollback - Key should not have been found in region.");
 
-    try {
-      regPtr1->destroy(keyPtr6);
-      FAIL("Should have got EntryNotFoundException for keyPtr6");
-    } catch (EntryNotFoundException& /*ex*/) {
-      LOG("Got expected EntryNotFoundException for keyPtr6");
-    }
-    try {
-      regPtr1->destroy(keyPtr5);
-      FAIL("Should have got EntryNotFoundException for keyPtr5");
-    } catch (EntryNotFoundException& /*ex*/) {
-      LOG("Got expected EntryNotFoundException for keyPtr5");
-    }
     try {
       regPtr0->destroy(keyPtr4);
       FAIL("Should have got EntryNotFoundException for keyPtr4");
@@ -787,82 +702,71 @@ DUNIT_TASK_DEFINITION(CLIENT1, SuspendResumeRollback)
 END_TASK_DEFINITION
 DUNIT_TASK_DEFINITION(CLIENT1, SuspendResumeInThread)
   {
-    // start suspend thread  and resume thread and rollback immedidately
-    char buf[1024];
-    sprintf(
-        buf,
-        "start suspend thread  and resume thread and rollback immedidately");
-    LOG(buf);
-    ACE_Auto_Event txEvent;
+    LOG("Start suspend thread  and resume thread and rollback immediately");
+    {
+      binary_semaphore event{0};
+      SuspendTransactionThread suspend{false, event};
 
-    SuspendTransactionThread* suspendTh =
-        new SuspendTransactionThread(false, &txEvent);
-    suspendTh->activate();
-    ACE_OS::sleep(2);
-    ResumeTransactionThread* resumeTh = new ResumeTransactionThread(
-        suspendTh->getSuspendedTx(), false, false, &txEvent);
-    resumeTh->activate();
+      suspend.start();
+      std::this_thread::sleep_for(std::chrono::seconds{2});
 
-    suspendTh->wait();
-    delete suspendTh;
-    resumeTh->wait();
-    delete resumeTh;
+      ResumeTransactionThread resume{suspend.getSuspendedTx(), false, false,
+                                     event};
+      resume.start();
 
-    // start suspend thread  and resume thread and commit immedidately
-    sprintf(buf,
-            "start suspend thread  and resume thread and commit immedidately");
-    LOG(buf);
-    suspendTh = new SuspendTransactionThread(false, &txEvent);
-    suspendTh->activate();
-    ACE_OS::sleep(2);
-    resumeTh = new ResumeTransactionThread(suspendTh->getSuspendedTx(), true,
-                                           false, &txEvent);
-    resumeTh->activate();
+      suspend.stop();
+      resume.stop();
+    }
 
-    suspendTh->wait();
-    delete suspendTh;
-    resumeTh->wait();
-    delete resumeTh;
+    LOG("Start suspend thread  and resume thread and commit immediately");
+    {
+      binary_semaphore event{0};
+      SuspendTransactionThread suspend{false, event};
 
-    // start suspend thread  and tryresume thread with rollback. make tryResume
-    // to
-    // sleep
-    sprintf(buf,
-            "start suspend thread  and tryresume thread with rollback. make "
-            "tryResume to sleep");
-    LOG(buf);
-    suspendTh = new SuspendTransactionThread(true, &txEvent);
-    suspendTh->activate();
-    ACE_OS::sleep(2);
-    resumeTh = new ResumeTransactionThread(suspendTh->getSuspendedTx(), false,
-                                           true, &txEvent);
-    resumeTh->activate();
+      suspend.start();
+      std::this_thread::sleep_for(std::chrono::seconds{2});
 
-    suspendTh->wait();
-    delete suspendTh;
-    resumeTh->wait();
-    delete resumeTh;
+      ResumeTransactionThread resume{suspend.getSuspendedTx(), true, false,
+                                     event};
+      resume.start();
 
-    // start suspend thread  and tryresume thread with commit. make tryResume to
-    // sleep
-    sprintf(buf,
-            "start suspend thread  and tryresume thread with commit. make "
-            "tryResume to sleep");
-    LOG(buf);
-    suspendTh = new SuspendTransactionThread(true, &txEvent);
-    suspendTh->activate();
-    ACE_OS::sleep(2);
-    sprintf(buf, "suspendTh->activate();");
-    LOG(buf);
+      suspend.stop();
+      resume.stop();
+    }
 
-    resumeTh = new ResumeTransactionThread(suspendTh->getSuspendedTx(), true,
-                                           true, &txEvent);
-    resumeTh->activate();
+    LOG("Start suspend thread  and tryresume thread with rollback. make "
+        "tryResume to sleep");
+    {
+      binary_semaphore event{0};
+      SuspendTransactionThread suspend{true, event};
 
-    suspendTh->wait();
-    delete suspendTh;
-    resumeTh->wait();
-    delete resumeTh;
+      suspend.start();
+      std::this_thread::sleep_for(std::chrono::seconds{2});
+
+      ResumeTransactionThread resume{suspend.getSuspendedTx(), false, true,
+                                     event};
+      resume.start();
+
+      suspend.stop();
+      resume.stop();
+    }
+
+    LOG("Start suspend thread  and tryresume thread with commit. make "
+        "tryResume to sleep");
+    {
+      binary_semaphore event{0};
+      SuspendTransactionThread suspend{true, event};
+
+      suspend.start();
+      std::this_thread::sleep_for(std::chrono::seconds{2});
+
+      ResumeTransactionThread resume{suspend.getSuspendedTx(), true, true,
+                                     event};
+      resume.start();
+
+      suspend.stop();
+      resume.stop();
+    }
   }
 END_TASK_DEFINITION
 
@@ -875,10 +779,9 @@ DUNIT_TASK_DEFINITION(CLIENT1, CreateNonexistentServerRegion_Pooled_Locator)
       FAIL(
           "Expected exception when doing operations on a non-existent region.");
     } catch (const CacheServerException& ex) {
-      printf(
-          "Got expected CacheServerException when performing operation "
-          "on a non-existent region: %s\n",
-          ex.what());
+      std::cout << "Got expected CacheServerException when performing "
+                   "operation on a non-existent region: "
+                << ex.what() << "\n";
     }
   }
 END_TASK_DEFINITION
@@ -893,10 +796,9 @@ DUNIT_TASK_DEFINITION(CLIENT1,
       FAIL(
           "Expected exception when doing operations on a non-existent region.");
     } catch (const CacheServerException& ex) {
-      printf(
-          "Got expected CacheServerException when performing operation "
-          "on a non-existent region: %s\n",
-          ex.what());
+      std::cout << "Got expected CacheServerException when performing "
+                   "operation on a non-existent region: "
+                << ex.what() << "\n";
     }
   }
 END_TASK_DEFINITION
@@ -904,7 +806,6 @@ END_TASK_DEFINITION
 DUNIT_TASK_DEFINITION(CLIENT1, StepOne_Pooled_Locator)
   {
     createPooledRegion(regionNames[0], USE_ACK, locatorsG, "__TESTPOOL1_");
-    createPooledRegion(regionNames[1], NO_ACK, locatorsG, "__TESTPOOL1_");
     LOG("StepOne_Pooled complete.");
   }
 END_TASK_DEFINITION
@@ -913,7 +814,6 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepOne_Pooled_Locator_Sticky)
   {
     createPooledRegionSticky(regionNames[0], USE_ACK, locatorsG,
                              "__TESTPOOL1_");
-    createPooledRegionSticky(regionNames[1], NO_ACK, locatorsG, "__TESTPOOL1_");
     LOG("StepOne_Pooled_Locator_Sticky complete.");
   }
 END_TASK_DEFINITION
@@ -922,7 +822,6 @@ DUNIT_TASK_DEFINITION(CLIENT2, StepTwo_Pooled_Locator)
   {
     initClient(true);
     createPooledRegion(regionNames[0], USE_ACK, locatorsG, "__TESTPOOL1_");
-    createPooledRegion(regionNames[1], NO_ACK, locatorsG, "__TESTPOOL1_");
     LOG("StepTwo complete.");
   }
 END_TASK_DEFINITION
@@ -932,7 +831,6 @@ DUNIT_TASK_DEFINITION(CLIENT2, StepTwo_Pooled_Locator_Sticky)
     initClient(true);
     createPooledRegionSticky(regionNames[0], USE_ACK, locatorsG,
                              "__TESTPOOL1_");
-    createPooledRegionSticky(regionNames[1], NO_ACK, locatorsG, "__TESTPOOL1_");
     LOG("StepTwo complete.");
   }
 END_TASK_DEFINITION
@@ -942,7 +840,6 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepThree)
     auto txManager = getHelper()->getCache()->getCacheTransactionManager();
     txManager->begin();
     createEntry(regionNames[0], keys[0], vals[0]);
-    createEntry(regionNames[1], keys[2], vals[2]);
     txManager->prepare();
     txManager->commit();
     LOG("StepThree complete.");
@@ -952,26 +849,20 @@ END_TASK_DEFINITION
 DUNIT_TASK_DEFINITION(CLIENT2, StepFour)
   {
     doNetsearch(regionNames[0], keys[0], vals[0]);
-    doNetsearch(regionNames[1], keys[2], vals[2]);
     auto txManager = getHelper()->getCache()->getCacheTransactionManager();
     txManager->begin();
     createEntry(regionNames[0], keys[1], vals[1]);
-    createEntry(regionNames[1], keys[3], vals[3]);
     txManager->prepare();
     txManager->commit();
     verifyEntry(regionNames[0], keys[1], vals[1]);
-    verifyEntry(regionNames[1], keys[3], vals[3]);
     LOG("StepFour complete.");
   }
 END_TASK_DEFINITION
 DUNIT_TASK_DEFINITION(CLIENT1, StepFive)
   {
     auto reg0 = getHelper()->getRegion(regionNames[0]);
-    auto reg1 = getHelper()->getRegion(regionNames[1]);
     auto vec0 = reg0->serverKeys();
-    auto vec1 = reg1->serverKeys();
     ASSERT(vec0.size() == 2, "Should have 2 keys in first region.");
-    ASSERT(vec1.size() == 2, "Should have 2 keys in second region.");
     std::string key0, key1;
     key0 = vec0[0]->toString().c_str();
     key1 = vec0[1]->toString().c_str();
@@ -981,29 +872,17 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFive)
     ASSERT(key1 == keys[0] || key1 == keys[1],
            "Unexpected key in first region.");
 
-    key0 = vec1[0]->toString().c_str();
-    key1 = vec1[1]->toString().c_str();
-    ASSERT(key0 != key1, "The two keys should be different in second region.");
-    ASSERT(key0 == keys[2] || key0 == keys[3],
-           "Unexpected key in second region.");
-    ASSERT(key1 == keys[2] || key1 == keys[3],
-           "Unexpected key in second region.");
-
     doNetsearch(regionNames[0], keys[1], vals[1]);
-    doNetsearch(regionNames[1], keys[3], vals[3]);
     updateEntry(regionNames[0], keys[0], nvals[0]);
-    updateEntry(regionNames[1], keys[2], nvals[2]);
     LOG("StepFive complete.");
   }
 END_TASK_DEFINITION
 DUNIT_TASK_DEFINITION(CLIENT2, StepSix)
   {
     doNetsearch(regionNames[0], keys[0], vals[0]);
-    doNetsearch(regionNames[1], keys[2], vals[2]);
     auto txManager = getHelper()->getCache()->getCacheTransactionManager();
     txManager->begin();
     updateEntry(regionNames[0], keys[1], nvals[1]);
-    updateEntry(regionNames[1], keys[3], nvals[3]);
     txManager->prepare();
     txManager->commit();
     LOG("StepSix complete.");
@@ -1013,75 +892,6 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepSeven)
   { createEntryTwice(regionNames[0], CREATE_TWICE_KEY, CREATE_TWICE_VALUE); }
 END_TASK_DEFINITION
 
-DUNIT_TASK_DEFINITION(CLIENT1, StepEight_Pool)
-  {
-    createPooledRegion(regionNames[2], NO_ACK, locatorsG, "__TESTPOOL1_", false,
-                       false);
-    auto reg = getHelper()->getRegion(regionNames[2]);
-    LOG("REGION Created with Caching Enabled false");
-    auto keyPtr = CacheableKey::create(CREATE_TWICE_KEY);
-    auto valPtr = CacheableString::create(CREATE_TWICE_VALUE);
-    try {
-      reg->create(keyPtr, valPtr);
-      char message[200];
-      sprintf(message, "First create on Key %s ", CREATE_TWICE_KEY);
-      LOG(message);
-      reg->create(keyPtr, valPtr);
-      sprintf(message, "Second create on Key %s ", CREATE_TWICE_KEY);
-      LOG(message);
-      reg->create(keyPtr, valPtr);
-      sprintf(message, "Third create on Key %s ", CREATE_TWICE_KEY);
-      LOG(message);
-    } catch (const EntryExistsException& geodeExcp) {
-      LOG(geodeExcp.what());
-      ASSERT(false,
-             "Creating KEY Twice on a caching-enabled false region should be "
-             "allowed.");
-    }
-  }
-END_TASK_DEFINITION
-
-DUNIT_TASK_DEFINITION(CLIENT1, StepEight_Pool_Sticky)
-  {
-    createPooledRegionSticky(regionNames[2], NO_ACK, locatorsG, "__TESTPOOL1_",
-                             false, false);
-    auto reg = getHelper()->getRegion(regionNames[2]);
-    LOG("REGION Created with Caching Enabled false");
-    auto keyPtr = CacheableKey::create(CREATE_TWICE_KEY);
-    auto valPtr = CacheableString::create(CREATE_TWICE_VALUE);
-
-    auto reg0 = getHelper()->getRegion(regionNames[0]);
-    auto reg1 = getHelper()->getRegion(regionNames[1]);
-    reg0->localInvalidate(CacheableKey::create(keys[1]));
-    reg1->localInvalidate(CacheableKey::create(keys[3]));
-    auto pool = getHelper()->getCache()->getPoolManager().find("__TESTPOOL1_");
-    ASSERT(pool != nullptr, "Pool Should have been found");
-    doNetsearch(regionNames[0], keys[1], nvals[1]);
-    doNetsearch(regionNames[1], keys[3], nvals[3]);
-    pool->releaseThreadLocalConnection();
-    updateEntry(regionNames[0], keys[0], nvals[0]);
-    updateEntry(regionNames[1], keys[2], nvals[2]);
-    pool->releaseThreadLocalConnection();
-    try {
-      reg->create(keyPtr, valPtr);
-      char message[200];
-      sprintf(message, "First create on Key %s ", CREATE_TWICE_KEY);
-      LOG(message);
-      reg->create(keyPtr, valPtr);
-      sprintf(message, "Second create on Key %s ", CREATE_TWICE_KEY);
-      LOG(message);
-      reg->create(keyPtr, valPtr);
-      sprintf(message, "Third create on Key %s ", CREATE_TWICE_KEY);
-      LOG(message);
-    } catch (const EntryExistsException& geodeExcp) {
-      LOG(geodeExcp.what());
-      ASSERT(false,
-             "Creating KEY Twice on a caching-enabled false region should be "
-             "allowed.");
-    }
-  }
-END_TASK_DEFINITION
-
 DUNIT_TASK_DEFINITION(CLIENT1, CloseCache1)
   { cleanProc(); }
 END_TASK_DEFINITION
@@ -1099,30 +909,19 @@ DUNIT_TASK_DEFINITION(SERVER1, CloseServer1)
   }
 END_TASK_DEFINITION
 
-void runTransactionOps(bool isSticky = false) {
+void runTransactionOps() {
   CALL_TASK(CreateLocator1);
   CALL_TASK(CreateServer1_With_Locator);
 
-  if (isSticky) {
-    CALL_TASK(CreateNonexistentServerRegion_Pooled_Locator_Sticky);
-    CALL_TASK(StepOne_Pooled_Locator_Sticky);
-    CALL_TASK(StepTwo_Pooled_Locator_Sticky);
-  } else {
-    CALL_TASK(CreateNonexistentServerRegion_Pooled_Locator);
-    CALL_TASK(StepOne_Pooled_Locator);
-    CALL_TASK(StepTwo_Pooled_Locator);
-  }
+  CALL_TASK(CreateNonexistentServerRegion_Pooled_Locator);
+  CALL_TASK(StepOne_Pooled_Locator);
+  CALL_TASK(StepTwo_Pooled_Locator);
 
   CALL_TASK(StepThree);
   CALL_TASK(StepFour);
   CALL_TASK(StepFive);
   CALL_TASK(StepSix);
   CALL_TASK(StepSeven);
-  if (isSticky) {
-    CALL_TASK(StepEight_Pool_Sticky);
-  } else {
-    CALL_TASK(StepEight_Pool);
-  }
 
   CALL_TASK(SuspendResumeInThread);
   CALL_TASK(SuspendResumeCommit);
