@@ -32,10 +32,10 @@
 
 // This is the test for tracking work. bug#304
 
-putThread *thread1 = nullptr;
-putThread *thread2 = nullptr;
-putThread *thread3 = nullptr;
-putThread *thread4 = nullptr;
+PutThread* thread1 = nullptr;
+PutThread* thread2 = nullptr;
+PutThread* thread3 = nullptr;
+PutThread* thread4 = nullptr;
 
 const char *regNames[] = {"DistRegionAck", "DistRegionNoAck"};
 const char *group1 = "A";
@@ -47,7 +47,7 @@ std::string gfendpoints2 = "localhost:";
 bool isLocalServer1 = false;
 
 static bool isLocator1 = false;
-const char *locatorsG =
+const std::string locatorsG =
     CacheHelper::getLocatorHostPort(isLocator1, isLocalServer1, 1);
 std::shared_ptr<CacheableString> c1v11;
 std::shared_ptr<CacheableString> c1v12;
@@ -125,9 +125,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, StartClient1)
     // TOOD::check for poolwithendpoints or locators
 
     // By default poolwithendpoints
-    // char tmp1[100];
-    // sprintf( tmp1, "%d", CacheHelper::staticHostPort1 );
-    // gfendpoints1 += tmp1;
+    // gfendpoints1 += std::to_string(CacheHelper::staticHostPort1);
 
     // initClientWithPool(true/*isthinClient*/, nullptr/*poolName*/,
     // nullptr/*locators*/,serverGroup1, nullptr/*servers*/,
@@ -158,11 +156,9 @@ DUNIT_TASK_DEFINITION(CLIENT2, StartClient2)
     // TOOD::check for poolwithendpoints or locators
     /*	LOG( "Client-2 Init -1" );
     //By default poolwithendpoints
-          char tmp2[100];
           LOG( "Client-2 Init -2" );
-          sprintf( tmp2, "%d", CacheHelper::staticHostPort2 );
           LOG( "Client-2 Init -3" );
-          gfendpoints2 += tmp2;
+          gfendpoints2 += std::to_string(CacheHelper::staticHostPort2);
           LOG( "Client-2 Init -4" );
     initClientWithPool(true, nullptr, nullptr, serverGroup2,
     gfendpoints2.c_str(), nullptr, 0, true, -1, 5, 60000); LOG( "Client-2 Init
@@ -189,7 +185,7 @@ END_TASK_DEFINITION
 DUNIT_TASK_DEFINITION(CLIENT1, threadPutonClient1)
   {
     auto rptr = getHelper()->getRegion(regNames[0]);
-    thread4 = new putThread(rptr, false);
+    thread4 = new PutThread(rptr, false);
     thread4->setParams(0, 10, 1, true, false, 0);
     thread4->start();
     LOG("Task: threadPutonClient1 Done");
@@ -313,7 +309,7 @@ END_TASK_DEFINITION
 DUNIT_TASK_DEFINITION(CLIENT1, PutOnClient1)
   {
     auto rptr = getHelper()->getRegion(regNames[0]);
-    thread1 = new putThread(rptr, false);
+    thread1 = new PutThread(rptr, false);
     thread1->setParams(0, 5, 1, true, false, 1);
     thread1->start();
     LOG("PUT ops done on client 1");
@@ -323,7 +319,7 @@ END_TASK_DEFINITION
 DUNIT_TASK_DEFINITION(CLIENT2, PutOnClient2)
   {
     auto rptr = getHelper()->getRegion(regNames[0]);
-    thread2 = new putThread(rptr, false);
+    thread2 = new PutThread(rptr, false);
     thread2->setParams(0, 5, 1, false, false, 0);  // 0, 5, 1, false, false, 0
     thread2->start();
     LOG("PUT ops done on client 2");
@@ -333,7 +329,7 @@ END_TASK_DEFINITION
 DUNIT_TASK_DEFINITION(CLIENT1, testServerGC)
   {
     auto rptr = getHelper()->getRegion(regNames[0]);
-    thread3 = new putThread(rptr, false);
+    thread3 = new PutThread(rptr, false);
     thread3->setParams(0, 5000, 1, true, false, 0);  // 0, 5, 1, false, false, 0
     thread3->start();
     LOG("5000 PUT ops done on client 1");
