@@ -20,14 +20,14 @@
 #ifndef GEODE_INTEGRATION_TEST_LOCATOR_GLOBALS_H_
 #define GEODE_INTEGRATION_TEST_LOCATOR_GLOBALS_H_
 
-namespace { // NOLINT(google-build-namespaces)
+namespace {  // NOLINT(google-build-namespaces)
 
 using apache::geode::client::CacheHelper;
 
 static int numberOfLocators = 1;
 bool isLocalServer = false;
 bool isLocator = false;
-const char* locatorsG =
+const std::string locatorsG =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, numberOfLocators);
 
 }  // namespace
