@@ -20,18 +20,23 @@
 #include "fw_dunit.hpp"
 
 int getWorkerTest() {
-  return dunit::globals()->getIntValue("test_alive_workers");
+  auto expected = dunit::globals().find<int>("test_alive_workers").first;
+  ASSERT(expected != nullptr, "test_alive_workers is nullptr");
+  return *expected;
 }
 
 // while this itself isn't thread/process safe, there shouldn't be concurrency
 // in a dunit test anyway.
 void incrementWorkerTest() {
-  dunit::globals()->rebind("test_alive_workers", getWorkerTest() + 1);
+  auto value = dunit::globals().find<int>("test_alive_workers").first;
+  ASSERT(value != nullptr, "test_alive_workers is nullptr");
+  ++*value;
 }
 
 DUNIT_TASK(s1p1, One)
   {
-    dunit::globals()->rebind("from1", 100);
+    dunit::globals().construct<int>("test_alive_workers")(0);
+    dunit::globals().construct<int>("from1")(100);
     LOG("bound from1 = 100");
     incrementWorkerTest();
   }
@@ -39,7 +44,9 @@ END_TASK(One)
 
 DUNIT_TASK(s1p2, Two)
   {
-    ASSERT(dunit::globals()->getIntValue("from1") == 100, "expected 100");
+    auto expected = dunit::globals().find<int>("from1").first;
+    ASSERT(expected != nullptr, "from1 is nullptr");
+    ASSERT(*expected == 100, "expected 100");
     LOG("looked up from1, found 100");
     incrementWorkerTest();
   }
@@ -77,6 +84,5 @@ DUNIT_TASK(s1p1, TestA)
     std::cout << "WorkerTest = " << getWorkerTest() << std::endl;
     ASSERT(getWorkerTest() == 8,
            "a previous worker must have failed undetected.");
-    dunit::globals()->dump();
   }
 END_TASK(TestA)
