@@ -18,7 +18,8 @@
 #include <string>
 #include <iostream>
 
-#include <ace/OS.h>
+#include <boost/asio.hpp>
+#include <boost/process.hpp>
 
 #include <geode/RegionShortcut.hpp>
 #include <geode/RegionFactory.hpp>
@@ -28,6 +29,8 @@
 #include <CacheRegionHelper.hpp>
 #include <MapEntry.hpp>
 
+#include "CacheImpl.hpp"
+
 #include "fw_helper.hpp"
 
 using apache::geode::client::Cache;
@@ -50,16 +53,16 @@ using apache::geode::client::RegionShortcut;
 uint32_t numOfEnt;
 std::string sqlite_dir = "SqLiteRegionData";
 
-static constexpr char const *MAX_PAGE_COUNT = "MaxPageCount";
-static constexpr char const *PAGE_SIZE = "PageSize";
-static constexpr char const *PERSISTENCE_DIR = "PersistenceDirectory";
+static constexpr char const *kMaxPageCountStr = "MaxPageCount";
+static constexpr char const *kPageSizeStr = "PageSize";
+static constexpr char const *kPersistenceDirStr = "PersistenceDirectory";
 
 // Return the number of keys and values in entries map.
 void getNumOfEntries(std::shared_ptr<Region> &regionPtr, uint32_t num) {
   auto v = regionPtr->keys();
   auto vecValues = regionPtr->values();
-  printf("Values vector size is %zd\n", vecValues.size());
-  printf("Num is %d\n", num);
+  std::cout << "Values vector size is " << vecValues.size() << "\n";
+  std::cout << "Num is " << num << "\n";
   ASSERT(vecValues.size() == num, "size of value vec and num not equal");
 }
 
@@ -135,7 +138,7 @@ void checkOverflowToken(std::shared_ptr<Region> &regionPtr, uint32_t lruLimit) {
   int normalCount = 0;
   int overflowCount = 0;
   int invalidCount = 0;
-  int destoyedCount = 0;
+  int destroyedCount = 0;
   int tombstoneCount = 0;
   for (uint32_t i = 0; i < static_cast<uint32_t>(v.size()); i++) {
     keyPtr = v.at(i);
@@ -148,19 +151,19 @@ void checkOverflowToken(std::shared_ptr<Region> &regionPtr, uint32_t lruLimit) {
     } else if (CacheableToken::isInvalid(valuePtr)) {
       invalidCount++;
     } else if (CacheableToken::isDestroyed(valuePtr)) {
-      destoyedCount++;
+      destroyedCount++;
     } else if (valuePtr != nullptr) {
       normalCount++;
     }
     valuePtr = nullptr;
   }
-  printf("Keys vector size is %zd\n", v.size());
-  printf("Normal entries count is %d\n", normalCount);
-  printf("Overflow entries count is %d\n", overflowCount);
-  printf("Invalid entries count is %d\n", invalidCount);
-  printf("Destoyed entries count is %d\n", destoyedCount);
-  printf("Tombstone entries count is %d\n", tombstoneCount);
-  printf("LRU entries limit is %d\n", lruLimit);
+  std::cout << "Keys vector size is " << v.size() << "\n";
+  std::cout << "Normal entries count is " << normalCount << "\n";
+  std::cout << "Overflow entries count is " << overflowCount << "\n";
+  std::cout << "Invalid entries count is " << invalidCount << "\n";
+  std::cout << "Destoyed entries count is " << destroyedCount << "\n";
+  std::cout << "Tombstone entries count is " << tombstoneCount << "\n";
+  std::cout << "LRU entries limit is " << lruLimit << "\n";
   ASSERT(normalCount <= static_cast<int>(lruLimit),
          "Normal entries count should not exceed LRU entries limit.");
 }
@@ -168,53 +171,20 @@ void checkOverflowToken(std::shared_ptr<Region> &regionPtr, uint32_t lruLimit) {
 // Testing for put operation
 void doNput(std::shared_ptr<Region> &regionPtr, uint32_t num,
             uint32_t start = 0) {
-  char keybuf[100];
   // Put 1 KB of data locally for each entry
-  char *text = new char[1024];
+  char text[1024];
   memset(text, 'A', 1023);
   text[1023] = '\0';
   auto valuePtr = CacheableString::create(text);
 
   for (uint32_t i = start; i < num; i++) {
-    sprintf(keybuf, "key-%d", i);
-    auto key = CacheableKey::create(keybuf);
-    printf("Putting key = %s\n", keybuf);
+    auto keyname = std::string("key-") + std::to_string(i);
+    auto key = CacheableKey::create(keyname);
+    std::cout << "Putting key = " << keyname << "\n";
     regionPtr->put(key, valuePtr);
   }
 }
 
-void doNputLargeData(std::shared_ptr<Region> &regionPtr, int num) {
-  // Put 1 MB of data locally for each entry
-  char *text = new char[1024 * 1024 /* 1 MB */];
-  memset(text, 'A', 1024 * 1024 - 1);
-  text[1024 * 1024 - 1] = '\0';
-  auto valuePtr = CacheableString::create(text);
-  for (int item = 0; item < num; item++) {
-    regionPtr->put(CacheableKey::create(item), valuePtr);
-  }
-
-  LOGINFO("Put data locally");
-}
-
-// Testing for get operation
-uint32_t doNgetLargeData(std::shared_ptr<Region> &regionPtr, int num) {
-  uint32_t countFound = 0;
-  uint32_t countNotFound = 0;
-
-  for (int i = 0; i < num; i++) {
-    printf("Getting key = %d\n", i);
-    auto valuePtr =
-        std::dynamic_pointer_cast<CacheableString>(regionPtr->get(i));
-    if (valuePtr == nullptr) {
-      countNotFound++;
-    } else {
-      countFound++;
-    }
-  }
-  LOGINFO("found:%d and Not found: %d", countFound, countNotFound);
-  return countFound;
-}
-
 // Testing for get operation
 uint32_t doNget(std::shared_ptr<Region> &regionPtr, uint32_t num,
                 uint32_t start = 0) {
@@ -222,20 +192,19 @@ uint32_t doNget(std::shared_ptr<Region> &regionPtr, uint32_t num,
   uint32_t countNotFound = 0;
 
   for (uint32_t i = start; i < num; i++) {
-    char keybuf[100];
-    sprintf(keybuf, "key-%d", i);
+    auto keyname = std::string("key-") + std::to_string(i);
     auto valuePtr =
-        std::dynamic_pointer_cast<CacheableString>(regionPtr->get(keybuf));
-    printf("Getting key = %s\n", keybuf);
+        std::dynamic_pointer_cast<CacheableString>(regionPtr->get(keyname));
+    std::cout << "Getting key = " << keyname << "\n";
     if (valuePtr == nullptr) {
       countNotFound++;
     } else {
       countFound++;
     }
   }
-  printf("completed doNget");
-  printf("count found %d", countFound);
-  printf("num found %d", num);
+  std::cout << "completed doNget";
+  std::cout << "count found " << countFound;
+  std::cout << "num found " << num;
   ASSERT(countFound == (num - start),
          "Number of entries found and put should match");
   LOGINFO("found:%d and Not found: %d", countFound, countNotFound);
@@ -278,28 +247,34 @@ void testEntryInvalidate(std::shared_ptr<Region> &regionPtr, uint32_t num) {
   ASSERT(v.size() == num, "size of key vec not equal");
 }
 
-class PutThread : public ACE_Task_Base {
- private:
-  std::shared_ptr<Region> m_regPtr;
-  int m_min;
-  int m_max;
-
+class PutThread {
  public:
-  PutThread(std::shared_ptr<Region> &regPtr, int min, int max)
-      : m_regPtr(regPtr), m_min(min), m_max(max) {}
+  PutThread(std::shared_ptr<Region> region, int min, int max)
+      : min_{min}, max_{max}, region_{region} {}
 
-  int svc(void) {
+  void run() {
     /** put some values into the cache. */
-    doNput(m_regPtr, m_max, m_min);
+    doNput(region_, max_, min_);
     /** do some gets... printing what we find in the cache. */
-    doNget(m_regPtr, m_max, m_min);
+    doNget(region_, max_, min_);
     LOG("Completed doNget");
-    return 0;
   }
 
-  void start() { activate(); }
+  void start() {
+    thread_ = std::thread{[this]() { run(); }};
+  }
 
-  void stop() { wait(); }
+  void stop() {
+    if (thread_.joinable()) {
+      thread_.join();
+    }
+  }
+
+ protected:
+  int min_;
+  int max_;
+  std::thread thread_;
+  std::shared_ptr<Region> region_;
 };
 
 void verifyGetAll(std::shared_ptr<Region> region, int startIndex) {
@@ -342,26 +317,25 @@ void setSqLiteProperties(std::shared_ptr<Properties> &sqliteProperties,
                          int maxPageCount = 1073741823, int pageSize = 65536,
                          std::string pDir = sqlite_dir) {
   sqliteProperties = Properties::create();
-  sqliteProperties->insert(MAX_PAGE_COUNT, maxPageCount);
-  sqliteProperties->insert(PAGE_SIZE, pageSize);
-  sqliteProperties->insert(PERSISTENCE_DIR, pDir.c_str());
+  sqliteProperties->insert(kMaxPageCountStr, maxPageCount);
+  sqliteProperties->insert(kPageSizeStr, pageSize);
+  sqliteProperties->insert(kPersistenceDirStr, pDir.c_str());
   ASSERT(sqliteProperties != nullptr,
          "Expected sqlite properties to be NON-nullptr");
 }
 // creation of subregion.
 
 void createSubRegion(std::shared_ptr<Region> &regionPtr,
-                     std::shared_ptr<Region> &subRegion, const char *regionName,
+                     std::shared_ptr<Region> &subRegion,
+                     const std::string &regionName,
                      std::string pDir = sqlite_dir) {
   RegionAttributes regionAttributesPtr;
   setAttributes(regionAttributesPtr, pDir);
   subRegion = regionPtr->createSubregion(regionName, regionAttributesPtr);
   ASSERT(subRegion != nullptr, "Expected region to be NON-nullptr");
-  char fileName[512];
-  sprintf(fileName, "%s/%s/%s.db", pDir.c_str(), regionName, regionName);
-  ACE_stat fileStat;
-  ASSERT(ACE_OS::stat(fileName, &fileStat) == 0,
-         "persistence file not present");
+
+  std::string fileName = pDir + '/' + regionName + '/' + regionName + ".db";
+  ASSERT(boost::filesystem::exists(fileName), "persistence file not present");
   doNput(subRegion, 50);
   doNget(subRegion, 50);
 }
@@ -409,15 +383,12 @@ BEGIN_TEST(OverFlowTest)
       subRegion->destroyRegion();
       ASSERT(subRegion->isDestroyed(), "Expected region is not destroyed ");
       subRegion = nullptr;
-      ACE_TCHAR hname[MAXHOSTNAMELEN];
-      ACE_OS::hostname(hname, sizeof(hname) - 1);
-      char sqliteDirSubRgn[512];
-      sprintf(sqliteDirSubRgn, "%s/%s_%u/_%s_SubRegion/file_0.db",
-              sqlite_dir.c_str(), hname, ACE_OS::getpid(),
-              regionPtr->getName().c_str());
 
-      ACE_stat fileStat;
-      ASSERT(ACE_OS::stat(sqliteDirSubRgn, &fileStat) == -1,
+      std::string sqliteDirSubRgn =
+          sqlite_dir + "/" + boost::asio::ip::host_name() + '_' +
+          std::to_string(boost::this_process::get_id()) + "/_" +
+          regionPtr->getName() + "_SubRegion/file_0.db";
+      ASSERT(!boost::filesystem::exists(sqliteDirSubRgn),
              "persistence file still present");
     }
     // cache close
@@ -428,11 +399,10 @@ END_TEST(OverFlowTest)
 BEGIN_TEST(OverFlowTest_absPath)
   {
     std::shared_ptr<RegionAttributes> attrsPtr;
-    char currWDPath[512];
-    char *wdPath = ACE_OS::getcwd(currWDPath, 512);
-    ASSERT(wdPath != nullptr,
-           "Expected current Working Directory to be NON-nullptr");
-    std::string absPersistenceDir = std::string(wdPath) + "/absSqLite";
+    auto wdPath = boost::filesystem::current_path().string();
+    ASSERT(!wdPath.empty(),
+           "Expected current Working Directory to be not empty");
+    std::string absPersistenceDir = wdPath + "/absSqLite";
 
     /** Creating a cache to manage regions. */
     std::shared_ptr<Properties> sqliteProperties;
@@ -473,11 +443,9 @@ BEGIN_TEST(OverFlowTest_absPath)
       subRegion->destroyRegion();
       ASSERT(subRegion->isDestroyed(), "Expected region is not destroyed ");
       subRegion = nullptr;
-      char fileName[512];
-      sprintf(fileName, "%s/%s/%s.db", absPersistenceDir.c_str(), "SubRegion",
-              "SubRegion");
-      ACE_stat fileStat;
-      ASSERT(ACE_OS::stat(fileName, &fileStat) == -1,
+
+      std::string fileName = absPersistenceDir + "/SubRegion/SubRegion.db";
+      ASSERT(!boost::filesystem::exists(fileName),
              "persistence file still present");
     }
     // cache close
@@ -512,10 +480,8 @@ BEGIN_TEST(OverFlowTest_SqLiteFull)
                  &ex) {  // expected sqlite full exception
                          // catching generic message as we dont
                          // have any specific sqlitefull exception
-      char buffer[1024];
-      sprintf(buffer, "Got expected exception %s: msg = %s",
-              ex.getName().c_str(), ex.what());
-      LOG(buffer);
+      LOG(std::string("Got expected exception ") + ex.getName() +
+          "; msg = " + ex.what());
     }
 
     // cache close
@@ -569,18 +535,16 @@ BEGIN_TEST(OverFlowTest_HeapLRU)
       setAttributes(regionAttributes);
       subRegion = regionPtr->createSubregion("SubRegion", regionAttributes);
       ASSERT(subRegion != nullptr, "Expected region to be NON-nullptr");
-      char fileName[512];
-      sprintf(fileName, "%s/%s/%s.db", sqlite_dir.c_str(), "SubRegion",
-              "SubRegion");
-      ACE_stat fileStat;
-      ASSERT(ACE_OS::stat(fileName, &fileStat) == 0,
+
+      std::string fileName = sqlite_dir + "/SubRegion/SubRegion.db";
+      ASSERT(boost::filesystem::exists(fileName),
              "persistence file not present");
       doNput(subRegion, 50);
       doNget(subRegion, 50);
       subRegion->destroyRegion();
       ASSERT(subRegion->isDestroyed(), "Expected region is not destroyed ");
       subRegion = nullptr;
-      ASSERT(ACE_OS::stat(fileName, &fileStat) == -1,
+      ASSERT(!boost::filesystem::exists(fileName),
              "persistence file still present");
     }
     // cache close
