@@ -18,8 +18,6 @@
 #include "BuiltinCacheableWrappers.hpp"
 #include "Utils.hpp"
 #include <geode/FixedPartitionResolver.hpp>
-#include <ace/OS.h>
-#include <ace/High_Res_Timer.h>
 
 #include <string>
 
@@ -183,7 +181,7 @@ auto cptr3 = std::make_shared<CustomFixedPartitionResolver3>();
 bool isLocalServer = false;
 
 static bool isLocator = false;
-const char *locatorsG =
+const std::string locatorsG =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, 1);
 
 std::vector<char *> storeEndPoints(const char *points) {
