@@ -15,8 +15,6 @@
  * limitations under the License.
  */
 #include "fw_dunit.hpp"
-#include <ace/OS.h>
-#include <ace/High_Res_Timer.h>
 
 #include <string>
 
@@ -39,7 +37,7 @@ CacheHelper *cacheHelper = nullptr;
 bool isLocalServer = false;
 
 static bool isLocator = false;
-const char *locatorsG =
+const std::string locatorsG =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, 1);
 #include "LocatorHelper.hpp"
 static int clientWithRedundancy = 0;
@@ -91,20 +89,18 @@ void _verifyEntry(const char *name, const char *key, const char *val,
                   bool noKey) {
   // Verify key and value exist in this region, in this process.
   const char *value = val ? val : "";
-  char *buf =
-      reinterpret_cast<char *>(malloc(1024 + strlen(key) + strlen(value)));
-  ASSERT(buf, "Unable to malloc buffer for logging.");
+  std::string msg;
   if (noKey) {
-    sprintf(buf, "Verify key %s does not exist in region %s", key, name);
+    msg =
+        std::string("Verify key ") + key + " does not exist in region " + name;
   } else if (!val) {
-    sprintf(buf, "Verify value for key %s does not exist in region %s", key,
-            name);
+    msg = std::string("Verify value for key ") + key +
+          " does not exist in region " + name;
   } else {
-    sprintf(buf, "Verify value for key %s is: %s in region %s", key, value,
-            name);
+    msg = std::string("Verify value for key ") + key + " is: " + value +
+          " in region " + name;
   }
-  LOG(buf);
-  free(buf);
+  LOG(msg);
 
   auto regPtr = getHelper()->getRegion(name);
   ASSERT(regPtr != nullptr, "Region not found.");
@@ -163,9 +159,8 @@ void _verifyEntry(const char *name, const char *key, const char *val,
 }
 
 void _verifyInvalid(const char *name, const char *key, int line) {
-  char logmsg[1024];
-  sprintf(logmsg, "verifyInvalid() called from %d.\n", line);
-  LOG(logmsg);
+  LOG(std::string("verifyInvalid() called from ") + std::to_string(line) +
+      "\n");
   _verifyEntry(name, key, nullptr, false);
   LOG("Entry invalidated.");
 }
@@ -173,9 +168,8 @@ void _verifyInvalid(const char *name, const char *key, int line) {
 #define verifyDestroyed(x, y) _verifyDestroyed(x, y, __LINE__)
 
 void _verifyDestroyed(const char *name, const char *key, int line) {
-  char logmsg[1024];
-  sprintf(logmsg, "verifyDestroyed() called from %d.\n", line);
-  LOG(logmsg);
+  LOG(std::string("verifyDestroyed() called from ") + std::to_string(line) +
+      "\n");
   _verifyEntry(name, key, nullptr, true);
   LOG("Entry destroyed.");
 }
@@ -184,17 +178,16 @@ void _verifyDestroyed(const char *name, const char *key, int line) {
 
 void _verifyEntry(const char *name, const char *key, const char *val,
                   int line) {
-  char logmsg[1024];
-  sprintf(logmsg, "verifyEntry() called from %d.\n", line);
-  LOG(logmsg);
+  LOG(std::string("verifyEntry() called from ") + std::to_string(line) + "\n");
   _verifyEntry(name, key, val, false);
   LOG("Entry verified.");
 }
 
 void destroyEntry(const char *name, const char *key) {
   LOG("destroyEntry() entered.");
-  fprintf(stdout, "Destroying entry -- key: %s  in region %s\n", key, name);
-  fflush(stdout);
+  std::cout << "Destroying entry -- key: " << key << " in region " << name
+            << "\n"
+            << std::flush;
   // Destroy entry, verify entry is destroyed
   auto keyPtr = CacheableKey::create(key);
 
@@ -213,8 +206,9 @@ void destroyEntry(const char *name, const char *key) {
 void createRegion(const char *name, bool ackMode,
                   bool clientNotificationEnabled = false) {
   LOG("createRegion() entered.");
-  fprintf(stdout, "Creating region --  %s  ackMode is %d\n", name, ackMode);
-  fflush(stdout);
+  std::cout << "Creating region --  " << name << " ackMode is " << ackMode
+            << "\n"
+            << std::flush;
   char *endpoints = nullptr;
   auto regPtr = getHelper()->createRegion(name, ackMode, true, nullptr,
                                           endpoints, clientNotificationEnabled);
@@ -227,8 +221,9 @@ void createPooledRegion(const char *name, bool ackMode, const char *locators,
                         bool clientNotificationEnabled = false,
                         bool cachingEnable = true) {
   LOG("createRegion_Pool() entered.");
-  fprintf(stdout, "Creating region --  %s  ackMode is %d\n", name, ackMode);
-  fflush(stdout);
+  std::cout << "Creating region --  " << name << " ackMode is " << ackMode
+            << "\n"
+            << std::flush;
   auto poolPtr = getHelper()->createPool(
       poolname, locators, nullptr, reduendency, clientNotificationEnabled);
   auto regPtr = getHelper()->createRegionAndAttachPool(name, ackMode, poolname,
@@ -238,9 +233,9 @@ void createPooledRegion(const char *name, bool ackMode, const char *locators,
 }
 void createEntry(const char *name, const char *key, const char *value) {
   LOG("createEntry() entered.");
-  fprintf(stdout, "Creating entry -- key: %s  value: %s in region %s\n", key,
-          value, name);
-  fflush(stdout);
+  std::cout << "Creating entry -- key: " << key << " value: " << value
+            << " in region " << name << "\n"
+            << std::flush;
   // Create entry, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
   auto valPtr = CacheableString::create(value);
@@ -263,9 +258,9 @@ void createEntry(const char *name, const char *key, const char *value) {
 
 void updateEntry(const char *name, const char *key, const char *value) {
   LOG("updateEntry() entered.");
-  fprintf(stdout, "Updating entry -- key: %s  value: %s in region %s\n", key,
-          value, name);
-  fflush(stdout);
+  std::cout << "Creating entry -- key: " << key << " value: " << value
+            << " in region " << name << "\n"
+            << std::flush;
   // Update entry, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
   auto valPtr = CacheableString::create(value);
@@ -286,16 +281,14 @@ void updateEntry(const char *name, const char *key, const char *value) {
 
 void doGetAgain(const char *name, const char *key, const char *value) {
   LOG("doGetAgain() entered.");
-  fprintf(stdout,
-          "get for entry -- key: %s  expecting value: %s in region %s\n", key,
-          value, name);
-  fflush(stdout);
+  std::cout << "get for entry -- key: " << key << " expecting value: " << value
+            << " in region " << name << "\n"
+            << std::flush;
   // Get entry created in Process A, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
 
   auto regPtr = getHelper()->getRegion(name);
-  fprintf(stdout, "get  region name%s\n", regPtr->getName().c_str());
-  fflush(stdout);
+  std::cout << "get  region name " << regPtr->getName() << "\n" << std::flush;
   ASSERT(regPtr != nullptr, "Region not found.");
 
   auto checkPtr = std::dynamic_pointer_cast<CacheableString>(
@@ -303,10 +296,8 @@ void doGetAgain(const char *name, const char *key, const char *value) {
 
   if (checkPtr != nullptr) {
     LOG("checkPtr is not null");
-    char buf[1024];
-    sprintf(buf, "In doGetAgain, get returned %s for key %s",
-            checkPtr->value().c_str(), key);
-    LOG(buf);
+    LOG(std::string("In doGetAgain, get returned ") + checkPtr->value() +
+        " for key  " + key);
   } else {
     LOG("checkPtr is nullptr");
   }
@@ -316,18 +307,15 @@ void doGetAgain(const char *name, const char *key, const char *value) {
 
 void doNetsearch(const char *name, const char *key, const char *value) {
   LOG("doNetsearch() entered.");
-  fprintf(
-      stdout,
-      "Netsearching for entry -- key: %s  expecting value: %s in region %s\n",
-      key, value, name);
-  fflush(stdout);
+  std::cout << "Netsearching for entry -- key: " << key
+            << " expecting value: " << value << " in region " << name << "\n"
+            << std::flush;
   static int count = 0;
   // Get entry created in Process A, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
 
   auto regPtr = getHelper()->getRegion(name);
-  fprintf(stdout, "netsearch  region %s\n", regPtr->getName().c_str());
-  fflush(stdout);
+  std::cout << "netsearch region " << regPtr->getName() << "\n" << std::flush;
   ASSERT(regPtr != nullptr, "Region not found.");
 
   if (count == 0) {
@@ -342,10 +330,8 @@ void doNetsearch(const char *name, const char *key, const char *value) {
 
   if (checkPtr != nullptr) {
     LOG("checkPtr is not null");
-    char buf[1024];
-    sprintf(buf, "In net search, get returned %s for key %s",
-            checkPtr->value().c_str(), key);
-    LOG(buf);
+    LOG(std::string("In net search, get returned ") + checkPtr->value() +
+        " for key  " + key);
   } else {
     LOG("checkPtr is nullptr");
   }
@@ -358,7 +344,7 @@ const char *vals[] = {"Value-1", "Value-2", "Value-3", "Value-4"};
 const char *nvals[] = {"New Value-1", "New Value-2", "New Value-3",
                        "New Value-4"};
 
-const char *regionNames[] = {"DistRegionAck", "DistRegionNoAck"};
+const char *regionName = "DistRegionAck";
 
 const bool USE_ACK = true;
 const bool NO_ACK = false;
@@ -375,17 +361,10 @@ DUNIT_TASK_DEFINITION(CLIENT1, CreateClient1PoolAndRegions)
   {
     getHelper()->createPoolWithLocators("__TESTPOOL1_", locatorsG, true, 1);
 
-    getHelper()->createRegionAndAttachPool(regionNames[0], USE_ACK,
-                                           "__TESTPOOL1_", true);
-    getHelper()->createRegionAndAttachPool(regionNames[1], NO_ACK,
-                                           "__TESTPOOL1_", true);
-    /* createPooledRegion( regionNames[0], USE_ACK, locatorsG,
-     "__TESTPOOL1_" );
-     createPooledRegion( regionNames[1], NO_ACK, locatorsG, "__TESTPOOL2_"
-     );*/
+    getHelper()->createRegionAndAttachPool(regionName, USE_ACK, "__TESTPOOL1_",
+                                           true);
 
-    createEntry(regionNames[0], keys[0], vals[0]);
-    createEntry(regionNames[1], keys[2], vals[2]);
+    createEntry(regionName, keys[0], vals[0]);
 
     LOG("CreateClient1PoolAndRegions complete.");
   }
@@ -395,18 +374,10 @@ DUNIT_TASK_DEFINITION(CLIENT2, CreateClient2PoolAndRegions)
   {
     getHelper()->createPoolWithLocators("__TESTPOOL1_", locatorsG, true, 1);
 
-    getHelper()->createRegionAndAttachPool(regionNames[0], USE_ACK,
-                                           "__TESTPOOL1_", true);
-    getHelper()->createRegionAndAttachPool(regionNames[1], NO_ACK,
-                                           "__TESTPOOL1_", true);
+    getHelper()->createRegionAndAttachPool(regionName, USE_ACK, "__TESTPOOL1_",
+                                           true);
 
-    /* createPooledRegion( regionNames[0], USE_ACK,  locatorsG,
-     "__TESTPOOL1_" );
-     createPooledRegion( regionNames[1], NO_ACK,  locatorsG, "__TESTPOOL2_"
-     );*/
-
-    createEntry(regionNames[0], keys[1], vals[1]);
-    createEntry(regionNames[1], keys[3], vals[3]);
+    createEntry(regionName, keys[1], vals[1]);
 
     LOG("CreateClient2PoolAndRegions complete.");
   }
@@ -414,12 +385,9 @@ END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT1, RegisterClient1Keys)
   {
-    auto reg0 = getHelper()->getRegion(regionNames[0]);
-    auto reg1 = getHelper()->getRegion(regionNames[1]);
+    auto reg0 = getHelper()->getRegion(regionName);
     auto vec0 = reg0->serverKeys();
-    auto vec1 = reg1->serverKeys();
     ASSERT(vec0.size() == 2, "Should have 2 keys in first region.");
-    ASSERT(vec1.size() == 2, "Should have 2 keys in second region.");
     std::string key0, key1;
     key0 = vec0[0]->toString().c_str();
     key1 = vec0[1]->toString().c_str();
@@ -429,76 +397,54 @@ DUNIT_TASK_DEFINITION(CLIENT1, RegisterClient1Keys)
     ASSERT(key1 == keys[0] || key1 == keys[1],
            "Unexpected key in first region.");
 
-    key0 = vec1[0]->toString().c_str();
-    key1 = vec1[1]->toString().c_str();
-    ASSERT(key0 != key1, "The two keys should be different in second region.");
-    ASSERT(key0 == keys[2] || key0 == keys[3],
-           "Unexpected key in second region.");
-    ASSERT(key1 == keys[2] || key1 == keys[3],
-           "Unexpected key in second region.");
-
-    doNetsearch(regionNames[0], keys[1], vals[1]);
-    doNetsearch(regionNames[1], keys[3], vals[3]);
+    doNetsearch(regionName, keys[1], vals[1]);
 
     auto keyPtr1 = CacheableKey::create(keys[1]);
-    auto keyPtr3 = CacheableKey::create(keys[3]);
 
-    auto regPtr0 = getHelper()->getRegion(regionNames[0]);
-    auto regPtr1 = getHelper()->getRegion(regionNames[1]);
+    auto regPtr0 = getHelper()->getRegion(regionName);
 
     std::vector<std::shared_ptr<CacheableKey>> keys0, keys1;
     keys0.push_back(keyPtr1);
-    keys1.push_back(keyPtr3);
     regPtr0->registerKeys(keys0);
-    regPtr1->registerKeys(keys1);
     LOG("RegisterClient1Keys complete.");
   }
 END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT2, RegisterClient2Keys)
   {
-    doNetsearch(regionNames[0], keys[0], vals[0]);
-    doNetsearch(regionNames[1], keys[2], vals[2]);
+    doNetsearch(regionName, keys[0], vals[0]);
 
     auto keyPtr0 = CacheableKey::create(keys[0]);
     auto keyPtr2 = CacheableKey::create(keys[2]);
 
-    auto regPtr0 = getHelper()->getRegion(regionNames[0]);
-    auto regPtr1 = getHelper()->getRegion(regionNames[1]);
+    auto regPtr0 = getHelper()->getRegion(regionName);
 
     std::vector<std::shared_ptr<CacheableKey>> keys0, keys1;
     keys0.push_back(keyPtr0);
     keys1.push_back(keyPtr2);
     regPtr0->registerKeys(keys0);
-    regPtr1->registerKeys(keys1);
     LOG("RegisterClient2Keys complete.");
   }
 END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT1, UpdateClient1Entries)
   {
-    updateEntry(regionNames[0], keys[0], nvals[0]);
-    updateEntry(regionNames[1], keys[2], nvals[2]);
+    updateEntry(regionName, keys[0], nvals[0]);
     LOG("UpdateClient1Entries complete.");
   }
 END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT2, VerifyAndUpdateClient2Entries)
   {
-    verifyEntry(regionNames[0], keys[0], nvals[0]);
-    verifyEntry(regionNames[1], keys[2], nvals[2]);
+    verifyEntry(regionName, keys[0], nvals[0]);
 
-    updateEntry(regionNames[0], keys[1], nvals[1]);
-    updateEntry(regionNames[1], keys[3], nvals[3]);
+    updateEntry(regionName, keys[1], nvals[1]);
     LOG("VerifyAndUpdateClient2Entries complete.");
   }
 END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT1, VerifyClient1Entries)
-  {
-    verifyEntry(regionNames[0], keys[1], nvals[1]);
-    verifyEntry(regionNames[1], keys[3], nvals[3]);
-  }
+  { verifyEntry(regionName, keys[1], nvals[1]); }
 END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT2, DoAbsolutelyNothing)
@@ -507,10 +453,8 @@ END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT2, DestroyAllKeys)
   {
-    destroyEntry(regionNames[0], keys[0]);
-    destroyEntry(regionNames[0], keys[1]);
-    destroyEntry(regionNames[1], keys[2]);
-    destroyEntry(regionNames[1], keys[3]);
+    destroyEntry(regionName, keys[0]);
+    destroyEntry(regionName, keys[1]);
   }
 END_TASK_DEFINITION
 
