@@ -20,9 +20,6 @@
 #include <thread>
 #include <chrono>
 
-#include <ace/High_Res_Timer.h>
-#include <ace/OS.h>
-
 #include <geode/EntryEvent.hpp>
 
 #define ROOT_NAME "testThinClientHAEventIDMap"
@@ -93,7 +90,7 @@ static bool isLocalServer = false;
 static bool isLocator = false;
 static int numberOfLocators = 1;
 
-const char *locatorsG =
+const std::string locatorsG =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, numberOfLocators);
 int g_redundancyLevel = 0;
 
@@ -124,22 +121,21 @@ void _verifyEntry(const char *name, const char *key, const char *val,
                   bool noKey, bool isCreated = false) {
   // Verify key and value exist in this region, in this process.
   const char *value = val ? val : "";
-  char *buf =
-      reinterpret_cast<char *>(malloc(1024 + strlen(key) + strlen(value)));
-  ASSERT(buf, "Unable to malloc buffer for logging.");
+  std::string msg;
+
   if (!isCreated) {
     if (noKey) {
-      sprintf(buf, "Verify key %s does not exist in region %s", key, name);
+      msg = std::string("Verify key ") + key + " does not exist in region " +
+            name;
     } else if (!val) {
-      sprintf(buf, "Verify value for key %s does not exist in region %s", key,
-              name);
+      msg = std::string("Verify value for key ") + key +
+            " does not exist in region " + name;
     } else {
-      sprintf(buf, "Verify value for key %s is: %s in region %s", key, value,
-              name);
+      msg = std::string("Verify value for key ") + key + " is: " + value +
+            " in region " + name;
     }
-    LOG(buf);
+    LOG(msg);
   }
-  free(buf);
 
   auto regPtr = getHelper()->getRegion(name);
   ASSERT(regPtr != nullptr, "Region not found.");
@@ -214,21 +210,20 @@ void _verifyIntEntry(const char *name, const char *key, const int val,
                      bool noKey, bool isCreated = false) {
   // Verify key and value exist in this region, in this process.
   int value = val;
-  char *buf = reinterpret_cast<char *>(malloc(1024 + strlen(key) + 20));
-  ASSERT(buf, "Unable to malloc buffer for logging.");
+  std::string msg;
   if (!isCreated) {
     if (noKey) {
-      sprintf(buf, "Verify key %s does not exist in region %s", key, name);
-    } else if (val == 0) {
-      sprintf(buf, "Verify value for key %s does not exist in region %s", key,
-              name);
+      msg = std::string("Verify key ") + key + " does not exist in region " +
+            name;
+    } else if (!val) {
+      msg = std::string("Verify value for key ") + key +
+            " does not exist in region " + name;
     } else {
-      sprintf(buf, "Verify value for key %s is: %d in region %s", key, value,
-              name);
+      msg = std::string("Verify value for key ") + key +
+            " is: " + std::to_string(value) + " in region " + name;
     }
-    LOG(buf);
+    LOG(msg);
   }
-  free(buf);
 
   auto regPtr = getHelper()->getRegion(name);
   ASSERT(regPtr != nullptr, "Region not found.");
@@ -305,8 +300,7 @@ void _verifyIntEntry(const char *name, const char *key, const int val,
 void _verifyEntry(const char *name, const char *key, const char *val,
                   int line) {
   char logmsg[1024];
-  sprintf(logmsg, "verifyEntry() called from %d.\n", line);
-  LOG(logmsg);
+  LOG(std::string("verifyEntry() called from ") + std::to_string(line) + "\n");
   _verifyEntry(name, key, val, false);
   LOG("Entry verified.");
 }
@@ -315,17 +309,15 @@ void _verifyEntry(const char *name, const char *key, const char *val,
 
 void _verifyIntEntry(const char *name, const char *key, const int val,
                      int line) {
-  char logmsg[1024];
-  sprintf(logmsg, "verifyIntEntry() called from %d.\n", line);
-  LOG(logmsg);
+  LOG(std::string("verifyIntEntry() called from ") + std::to_string(line) +
+      "\n");
   _verifyIntEntry(name, key, val, false);
   LOG("Entry verified.");
 }
 
 void _verifyCreated(const char *name, const char *key, int line) {
-  char logmsg[1024];
-  sprintf(logmsg, "verifyCreated() called from %d.\n", line);
-  LOG(logmsg);
+  LOG(std::string("verifyCreated() called from ") + std::to_string(line) +
+      "\n");
   _verifyEntry(name, key, nullptr, false, true);
   LOG("Entry created.");
 }
@@ -333,8 +325,9 @@ void _verifyCreated(const char *name, const char *key, int line) {
 void createRegion(const char *name, bool ackMode,
                   bool clientNotificationEnabled = true) {
   LOG("createRegion() entered.");
-  fprintf(stdout, "Creating region --  %s  ackMode is %d\n", name, ackMode);
-  fflush(stdout);
+  std::cout << "Creating region --  " << name << " ackMode is " << ackMode
+            << "\n"
+            << std::flush;
   char *endpoints = nullptr;
   // ack, caching
   auto regPtr = getHelper()->createRegion(name, ackMode, true, nullptr,
@@ -345,9 +338,9 @@ void createRegion(const char *name, bool ackMode,
 
 void createEntry(const char *name, const char *key, const char *value) {
   LOG("createEntry() entered.");
-  fprintf(stdout, "Creating entry -- key: %s  value: %s in region %s\n", key,
-          value, name);
-  fflush(stdout);
+  std::cout << "Creating entry -- key: " << key << " value: " << value
+            << " in region " << name << "\n"
+            << std::flush;
   // Create entry, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
   auto valPtr = CacheableString::create(value);
@@ -370,9 +363,9 @@ void createEntry(const char *name, const char *key, const char *value) {
 
 void createIntEntry(const char *name, const char *key, const int value) {
   LOG("createEntry() entered.");
-  fprintf(stdout, "Creating entry -- key: %s  value: %d in region %s\n", key,
-          value, name);
-  fflush(stdout);
+  std::cout << "Creating entry -- key: " << key << " value: " << value
+            << " in region " << name << "\n"
+            << std::flush;
   // Create entry, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
   auto valPtr = CacheableInt32::create(value);
@@ -405,12 +398,11 @@ const char *vals[] = {"Value-1", "Value-2", "Value-3", "Value-4"};
 const char *nvals[] = {"New Value-1", "New Value-2", "New Value-3",
                        "New Value-4"};
 
-const char *regionNames[] = {"DistRegionAck", "DistRegionNoAck"};
+const char *regionName = "DistRegionAck";
 
 const bool USE_ACK = true;
 const bool NO_ACK = false;
 std::shared_ptr<DupChecker> checker1;
-std::shared_ptr<DupChecker> checker2;
 
 void initClientAndRegion(int redundancy,
                          bool clientNotificationEnabled = true) {
@@ -418,9 +410,7 @@ void initClientAndRegion(int redundancy,
   getHelper()->createPoolWithLocators("__TESTPOOL1_", locatorsG,
                                       clientNotificationEnabled, redundancy);
 
-  getHelper()->createRegionAndAttachPool(regionNames[0], USE_ACK,
-                                         "__TESTPOOL1_", true);
-  getHelper()->createRegionAndAttachPool(regionNames[1], NO_ACK, "__TESTPOOL1_",
+  getHelper()->createRegionAndAttachPool(regionName, USE_ACK, "__TESTPOOL1_",
                                          true);
 }
 
@@ -451,18 +441,11 @@ DUNIT_TASK_DEFINITION(CLIENT2, InitClient2)
     LOG("Initialized client with redundancy level 1.");
 
     checker1 = std::make_shared<DupChecker>();
-    checker2 = std::make_shared<DupChecker>();
 
-    setCacheListener(regionNames[0], checker1);
-    setCacheListener(regionNames[1], checker2);
+    setCacheListener(regionName, checker1);
 
     try {
-      getHelper()->getRegion(regionNames[0])->registerAllKeys();
-    } catch (...) {
-    }
-
-    try {
-      getHelper()->getRegion(regionNames[1])->registerAllKeys();
+      getHelper()->getRegion(regionName)->registerAllKeys();
     } catch (...) {
     }
 
@@ -482,21 +465,13 @@ END_TASK_DEFINITION
 DUNIT_TASK_DEFINITION(CLIENT1, CreateEntries)
   {
     for (int value = 1; value <= 100; value++) {
-      createIntEntry(regionNames[0], keys[0], value);
+      createIntEntry(regionName, keys[0], value);
       std::this_thread::sleep_for(std::chrono::milliseconds(10));
-      createIntEntry(regionNames[0], keys[1], value);
+      createIntEntry(regionName, keys[1], value);
       std::this_thread::sleep_for(std::chrono::milliseconds(10));
-      createIntEntry(regionNames[0], keys[2], value);
+      createIntEntry(regionName, keys[2], value);
       std::this_thread::sleep_for(std::chrono::milliseconds(10));
-      createIntEntry(regionNames[0], keys[3], value);
-      std::this_thread::sleep_for(std::chrono::milliseconds(10));
-      createIntEntry(regionNames[1], keys[0], value);
-      std::this_thread::sleep_for(std::chrono::milliseconds(10));
-      createIntEntry(regionNames[1], keys[1], value);
-      std::this_thread::sleep_for(std::chrono::milliseconds(10));
-      createIntEntry(regionNames[1], keys[2], value);
-      std::this_thread::sleep_for(std::chrono::milliseconds(10));
-      createIntEntry(regionNames[1], keys[3], value);
+      createIntEntry(regionName, keys[3], value);
       std::this_thread::sleep_for(std::chrono::milliseconds(10));
     }
   }
@@ -516,19 +491,13 @@ DUNIT_TASK_DEFINITION(CLIENT2, VerifyClient2Entries)
     // wait 30 sec for notifications to complete
     std::this_thread::sleep_for(std::chrono::seconds(30));
 
-    verifyIntEntry(regionNames[0], keys[0], 100);
-    verifyIntEntry(regionNames[0], keys[1], 100);
-    verifyIntEntry(regionNames[0], keys[2], 100);
-    verifyIntEntry(regionNames[0], keys[3], 100);
-    verifyIntEntry(regionNames[1], keys[0], 100);
-    verifyIntEntry(regionNames[1], keys[1], 100);
-    verifyIntEntry(regionNames[1], keys[2], 100);
-    verifyIntEntry(regionNames[1], keys[3], 100);
+    verifyIntEntry(regionName, keys[0], 100);
+    verifyIntEntry(regionName, keys[1], 100);
+    verifyIntEntry(regionName, keys[2], 100);
+    verifyIntEntry(regionName, keys[3], 100);
 
     LOG("Validating checker1 cachelistener");
     checker1->validate();
-    LOG("Validating checker2 cachelistener");
-    checker2->validate();
 
     LOG("VerifyClient2Entries complete.");
   }
