@@ -15,9 +15,7 @@
  * limitations under the License.
  */
 #include "fw_dunit.hpp"
-#include <ace/High_Res_Timer.h>
 
-#include <ace/OS.h>
 #include <string>
 
 #define ROOT_NAME "testThinClientHAFailoverRegex"
@@ -42,7 +40,7 @@ volatile int g_redundancyLevel = 0;
 
 static bool isLocator = false;
 static int numberOfLocators = 1;
-const char *locatorsG =
+const std::string locatorsG =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, numberOfLocators);
 
 void initClient() {
@@ -68,22 +66,20 @@ void _verifyEntry(const char *name, const char *key, const char *val,
                   bool noKey, bool isCreated = false) {
   // Verify key and value exist in this region, in this process.
   const char *value = val ? val : "";
-  char *buf =
-      reinterpret_cast<char *>(malloc(1024 + strlen(key) + strlen(value)));
-  ASSERT(buf, "Unable to malloc buffer for logging.");
+  std::string msg;
   if (!isCreated) {
     if (noKey) {
-      sprintf(buf, "Verify key %s does not exist in region %s", key, name);
+      msg = std::string("Verify key ") + key + " does not exist in region " +
+            name;
     } else if (!val) {
-      sprintf(buf, "Verify value for key %s does not exist in region %s", key,
-              name);
+      msg = std::string("Verify value for key ") + key +
+            " does not exist in region " + name;
     } else {
-      sprintf(buf, "Verify value for key %s is: %s in region %s", key, value,
-              name);
+      msg = std::string("Verify value for key ") + key + " is: " + value +
+            " in region " + name;
     }
-    LOG(buf);
+    LOG(msg);
   }
-  free(buf);
 
   auto regPtr = getHelper()->getRegion(name);
   ASSERT(regPtr != nullptr, "Region not found.");
@@ -158,9 +154,7 @@ void _verifyEntry(const char *name, const char *key, const char *val,
 
 void _verifyEntry(const char *name, const char *key, const char *val,
                   int line) {
-  char logmsg[1024];
-  sprintf(logmsg, "verifyEntry() called from %d.\n", line);
-  LOG(logmsg);
+  LOG(std::string("verifyEntry() called from ") + std::to_string(line) + "\n");
   _verifyEntry(name, key, val, false);
   LOG("Entry verified.");
 }
@@ -168,9 +162,8 @@ void _verifyEntry(const char *name, const char *key, const char *val,
 #define verifyCreated(x, y) _verifyCreated(x, y, __LINE__)
 
 void _verifyCreated(const char *name, const char *key, int line) {
-  char logmsg[1024];
-  sprintf(logmsg, "verifyCreated() called from %d.\n", line);
-  LOG(logmsg);
+  LOG(std::string("verifyCreated() called from ") + std::to_string(line) +
+      "\n");
   _verifyEntry(name, key, nullptr, false, true);
   LOG("Entry created.");
 }
@@ -178,8 +171,9 @@ void _verifyCreated(const char *name, const char *key, int line) {
 void createRegion(const char *name, bool ackMode,
                   bool clientNotificationEnabled = false) {
   LOG("createRegion() entered.");
-  fprintf(stdout, "Creating region --  %s  ackMode is %d\n", name, ackMode);
-  fflush(stdout);
+  std::cout << "Creating region --  " << name << " ackMode is " << ackMode
+            << "\n"
+            << std::flush;
   // ack, caching
   auto regPtr = getHelper()->createRegion(name, ackMode, true, nullptr,
                                           clientNotificationEnabled);
@@ -189,9 +183,9 @@ void createRegion(const char *name, bool ackMode,
 
 void createEntry(const char *name, const char *key, const char *value) {
   LOG("createEntry() entered.");
-  fprintf(stdout, "Creating entry -- key: %s  value: %s in region %s\n", key,
-          value, name);
-  fflush(stdout);
+  std::cout << "Creating entry -- key: " << key << " value: " << value
+            << " in region " << name << "\n"
+            << std::flush;
   // Create entry, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
   auto valPtr = CacheableString::create(value);
@@ -214,9 +208,9 @@ void createEntry(const char *name, const char *key, const char *value) {
 
 void updateEntry(const char *name, const char *key, const char *value) {
   LOG("updateEntry() entered.");
-  fprintf(stdout, "Updating entry -- key: %s  value: %s in region %s\n", key,
-          value, name);
-  fflush(stdout);
+  std::cout << "Updating entry -- key: " << key << " value: " << value
+            << " in region " << name << "\n"
+            << std::flush;
   // Update entry, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
   auto valPtr = CacheableString::create(value);
@@ -237,17 +231,14 @@ void updateEntry(const char *name, const char *key, const char *value) {
 
 void doNetsearch(const char *name, const char *key, const char *value) {
   LOG("doNetsearch() entered.");
-  fprintf(
-      stdout,
-      "Netsearching for entry -- key: %s  expecting value: %s in region %s\n",
-      key, value, name);
-  fflush(stdout);
+  std::cout << "Netsearching for entry -- key: " << key << " value: " << value
+            << " in region " << name << "\n"
+            << std::flush;
   // Get entry created in Process A, verify entry is correct
   auto keyPtr = CacheableKey::create(key);
 
   auto regPtr = getHelper()->getRegion(name);
-  fprintf(stdout, "netsearch  region %s\n", regPtr->getName().c_str());
-  fflush(stdout);
+  std::cout << "netsearch  region " << regPtr->getName() << "\n" << std::flush;
   ASSERT(regPtr != nullptr, "Region not found.");
 
   // ASSERT( !regPtr->containsKey( keyPtr ), "Key should not have been found in
@@ -260,10 +251,8 @@ void doNetsearch(const char *name, const char *key, const char *value) {
 
   if (checkPtr != nullptr) {
     LOG("checkPtr is not null");
-    char buf[1024];
-    sprintf(buf, "In net search, get returned %s for key %s",
-            checkPtr->value().c_str(), key);
-    LOG(buf);
+    LOG(std::string("In net search, get returned ") + checkPtr->value() +
+        " for key " + key);
   } else {
     LOG("checkPtr is nullptr");
   }
@@ -277,7 +266,7 @@ const char *vals[] = {"Value-1", "Value-2", "Value-3", "Value-4"};
 const char *nvals[] = {"New Value-1", "New Value-2", "New Value-3",
                        "New Value-4"};
 
-const char *regionNames[] = {"DistRegionAck", "DistRegionNoAck"};
+const char *regionName = "DistRegionAck";
 
 const bool USE_ACK = true;
 void initClientAndRegion(int redundancy) {
@@ -285,10 +274,8 @@ void initClientAndRegion(int redundancy) {
   auto pp = Properties::create();
   getHelper()->createPoolWithLocators("__TESTPOOL1_", locatorsG, true,
                                       redundancy);
-  getHelper()->createRegionAndAttachPool(regionNames[0], USE_ACK,
-                                         "__TESTPOOL1_", true);
-  getHelper()->createRegionAndAttachPool(regionNames[1], USE_ACK,
-                                         "__TESTPOOL1_", true);
+  getHelper()->createRegionAndAttachPool(regionName, USE_ACK, "__TESTPOOL1_",
+                                         true);
 }
 //#include "ThinClientDurableInit.hpp"
 #include "LocatorHelper.hpp"
@@ -336,7 +323,7 @@ END_TASK_DEFINITION
 
 /*DUNIT_TASK_DEFINITION( CLIENT1, StepOne )
 {
-  createRegion( regionNames[0], USE_ACK, false );
+  createRegion( regionName, USE_ACK, false );
   createRegion( regionNames[1], NO_ACK, false );
   LOG( "StepOne complete." );
 }
@@ -344,7 +331,7 @@ END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION( CLIENT2, StepTwo )
 {
-  createRegion( regionNames[0], USE_ACK, false );
+  createRegion( regionName, USE_ACK, false );
   createRegion( regionNames[1], NO_ACK, false );
 
   LOG( "StepTwo complete." );
@@ -362,37 +349,29 @@ END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT2, RegisterRegexes)
   {
-    auto regPtr0 = getHelper()->getRegion(regionNames[0]);
-    auto regPtr1 = getHelper()->getRegion(regionNames[1]);
+    auto regPtr0 = getHelper()->getRegion(regionName);
 
     if (g_redundancyLevel > 1) {
       regPtr0->registerRegex(testregex[0]);
-      regPtr1->registerRegex(testregex[2]);
     } else {
       regPtr0->registerRegex(testregex[0]);
-      regPtr1->registerRegex(testregex[2]);
     }
   }
 END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT1, StepThree)
   {
-    createEntry(regionNames[0], keys[0], vals[0]);
-    createEntry(regionNames[0], keys[1], vals[1]);
-    createEntry(regionNames[1], keys[2], vals[2]);
-    createEntry(regionNames[1], keys[3], vals[3]);
+    createEntry(regionName, keys[0], vals[0]);
+    createEntry(regionName, keys[1], vals[1]);
     LOG("StepThree complete.");
   }
 END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT2, StepFour)
   {
-    verifyCreated(regionNames[0], keys[0]);
-    verifyCreated(regionNames[1], keys[2]);
-    verifyEntry(regionNames[0], keys[0], vals[0]);
-    verifyEntry(regionNames[1], keys[2], vals[2]);
-    doNetsearch(regionNames[0], keys[1], vals[1]);
-    doNetsearch(regionNames[1], keys[3], vals[3]);
+    verifyCreated(regionName, keys[0]);
+    verifyEntry(regionName, keys[0], vals[0]);
+    doNetsearch(regionName, keys[1], vals[1]);
     LOG("StepFour complete.");
   }
 END_TASK_DEFINITION
@@ -409,10 +388,8 @@ END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT1, StepFive)
   {
-    updateEntry(regionNames[0], keys[0], nvals[0]);
-    updateEntry(regionNames[0], keys[1], nvals[1]);
-    updateEntry(regionNames[1], keys[2], nvals[2]);
-    updateEntry(regionNames[1], keys[3], nvals[3]);
+    updateEntry(regionName, keys[0], nvals[0]);
+    updateEntry(regionName, keys[1], nvals[1]);
     SLEEP(1000);
     LOG("StepFive complete.");
   }
@@ -420,12 +397,9 @@ END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT2, StepSix)
   {
-    auto reg0 = getHelper()->getRegion(regionNames[0]);
-    auto reg1 = getHelper()->getRegion(regionNames[1]);
+    auto reg0 = getHelper()->getRegion(regionName);
     auto vec0 = reg0->serverKeys();
-    auto vec1 = reg1->serverKeys();
     ASSERT(vec0.size() == 2, "Should have 2 keys in first region.");
-    ASSERT(vec1.size() == 2, "Should have 2 keys in second region.");
     std::string key0, key1;
     key0 = vec0[0]->toString().c_str();
     key1 = vec0[1]->toString().c_str();
@@ -435,18 +409,8 @@ DUNIT_TASK_DEFINITION(CLIENT2, StepSix)
     ASSERT(key1 == keys[0] || key1 == keys[1],
            "Unexpected key in first region.");
 
-    key0 = vec1[0]->toString().c_str();
-    key1 = vec1[1]->toString().c_str();
-    ASSERT(key0 != key1, "The two keys should be different in second region.");
-    ASSERT(key0 == keys[2] || key0 == keys[3],
-           "Unexpected key in second region.");
-    ASSERT(key1 == keys[2] || key1 == keys[3],
-           "Unexpected key in second region.");
-
-    verifyEntry(regionNames[0], keys[0], nvals[0]);
-    verifyEntry(regionNames[0], keys[1], vals[1]);
-    verifyEntry(regionNames[1], keys[2], nvals[2]);
-    verifyEntry(regionNames[1], keys[3], vals[3]);
+    verifyEntry(regionName, keys[0], nvals[0]);
+    verifyEntry(regionName, keys[1], vals[1]);
     LOG("StepSix complete.");
   }
 END_TASK_DEFINITION
@@ -485,10 +449,8 @@ END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT1, StepSeven)
   {
-    updateEntry(regionNames[0], keys[0], vals[0]);
-    updateEntry(regionNames[0], keys[1], vals[1]);
-    updateEntry(regionNames[1], keys[2], vals[2]);
-    updateEntry(regionNames[1], keys[3], vals[3]);
+    updateEntry(regionName, keys[0], vals[0]);
+    updateEntry(regionName, keys[1], vals[1]);
     SLEEP(1000);
     LOG("StepSeven complete.");
   }
@@ -496,13 +458,8 @@ END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT2, StepEight)
   {
-    verifyEntry(regionNames[0], keys[0], vals[0]);
-    verifyEntry(regionNames[0], keys[1], vals[1]);
-    verifyEntry(regionNames[1], keys[2], vals[2]);
-    verifyEntry(regionNames[1], keys[3], vals[3]);
-
-    auto regPtr1 = getHelper()->getRegion(regionNames[1]);
-    regPtr1->unregisterRegex(testregex[2]);
+    verifyEntry(regionName, keys[0], vals[0]);
+    verifyEntry(regionName, keys[1], vals[1]);
 
     LOG("StepEight complete.");
   }
@@ -531,10 +488,8 @@ END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT1, StepNine)
   {
-    updateEntry(regionNames[0], keys[0], nvals[0]);
-    updateEntry(regionNames[0], keys[1], nvals[1]);
-    updateEntry(regionNames[1], keys[2], nvals[2]);
-    updateEntry(regionNames[1], keys[3], nvals[3]);
+    updateEntry(regionName, keys[0], nvals[0]);
+    updateEntry(regionName, keys[1], nvals[1]);
     SLEEP(1000);
     LOG("StepNine complete.");
   }
@@ -542,10 +497,8 @@ END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT2, StepTen)
   {
-    verifyEntry(regionNames[0], keys[0], nvals[0]);
-    verifyEntry(regionNames[0], keys[1], vals[1]);
-    verifyEntry(regionNames[1], keys[2], vals[2]);
-    verifyEntry(regionNames[1], keys[3], vals[3]);
+    verifyEntry(regionName, keys[0], nvals[0]);
+    verifyEntry(regionName, keys[1], vals[1]);
     LOG("StepTen complete.");
   }
 END_TASK_DEFINITION
@@ -562,10 +515,8 @@ END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT1, StepEleven)
   {
-    updateEntry(regionNames[0], keys[0], vals[0]);
-    updateEntry(regionNames[0], keys[1], vals[1]);
-    updateEntry(regionNames[1], keys[2], vals[2]);
-    updateEntry(regionNames[1], keys[3], vals[3]);
+    updateEntry(regionName, keys[0], vals[0]);
+    updateEntry(regionName, keys[1], vals[1]);
     SLEEP(1000);
     LOG("StepEleven complete.");
   }
@@ -573,10 +524,8 @@ END_TASK_DEFINITION
 
 DUNIT_TASK_DEFINITION(CLIENT2, StepTwelve)
   {
-    verifyEntry(regionNames[0], keys[0], vals[0]);
-    verifyEntry(regionNames[0], keys[1], vals[1]);
-    verifyEntry(regionNames[1], keys[2], vals[2]);
-    verifyEntry(regionNames[1], keys[3], vals[3]);
+    verifyEntry(regionName, keys[0], vals[0]);
+    verifyEntry(regionName, keys[1], vals[1]);
     LOG("StepTwelve complete.");
   }
 END_TASK_DEFINITION
