@@ -19,9 +19,6 @@
 
 #include <string>
 
-#include <ace/OS.h>
-#include <ace/High_Res_Timer.h>
-
 #include <geode/internal/chrono/duration.hpp>
 
 #define ROOT_NAME "testThinClientLRUExpiration"
@@ -51,7 +48,7 @@ CacheHelper *cacheHelper = nullptr;
 bool isLocalServer = false;
 
 static bool isLocator = false;
-const char *locatorsG =
+const std::string locatorsG =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, 1);
 
 const char *regionNames[] = {"DistRegionAck1", "DistRegionAck2",
@@ -82,32 +79,32 @@ CacheHelper *getHelper() {
 void printAttribute(RegionAttributes attr) {
   using apache::geode::internal::chrono::duration::to_string;
 
-  printf("CachingEnable: %s\n",
-         attr.getCachingEnabled() ? "enabled" : "disabled");
-  printf("InitialCapacity: %d\n", attr.getInitialCapacity());
-  printf("LoadFactor: %f\n", attr.getLoadFactor());
-  printf("ConcurencyLevel: %d\n", attr.getConcurrencyLevel());
-  printf("RegionTimeToLive: %s\n",
-         to_string(attr.getRegionTimeToLive()).c_str());
-  printf("RegionIdleTimeout: %s\n",
-         to_string(attr.getRegionIdleTimeout()).c_str());
-  printf("EntryTimeToLive: %s\n", to_string(attr.getEntryTimeToLive()).c_str());
-  printf("EntryIdleTimeout: %s\n",
-         to_string(attr.getEntryIdleTimeout()).c_str());
-  printf("getLruEntriesLimit: %d\n", attr.getLruEntriesLimit());
-  printf("RegionTimeToLiveAction: %d\n",
-         static_cast<int>(attr.getRegionTimeToLiveAction()));
-  printf("RegionIdleTimeoutAction: %d\n",
-         static_cast<int>(attr.getRegionIdleTimeoutAction()));
-  printf("EntryTimeToLiveAction: %d\n",
-         static_cast<int>(attr.getEntryTimeToLiveAction()));
-  printf("EntryIdleTimeoutAction: %d\n",
-         static_cast<int>(attr.getEntryIdleTimeoutAction()));
-  printf("LruEvictionAction: %d\n",
-         static_cast<int>(attr.getLruEvictionAction()));
-  printf("ClientNotification: %s\n",
-         attr.getClientNotificationEnabled() ? "true" : "false");
-  // printf("getEndPoint: %s\n",attr.getEndpoints());
+  std::cout << "CachingEnable: "
+            << (attr.getCachingEnabled() ? "enabled" : "disabled") << "\n";
+  std::cout << "InitialCapacity: " << attr.getInitialCapacity() << "\n";
+  std::cout << "LoadFactor: " << attr.getLoadFactor() << "\n";
+  std::cout << "ConcurencyLevel: " << attr.getConcurrencyLevel() << "\n";
+  std::cout << "RegionTimeToLive: " << to_string(attr.getRegionTimeToLive())
+            << "\n";
+  std::cout << "RegionIdleTimeout: " << to_string(attr.getRegionIdleTimeout())
+            << "\n";
+  std::cout << "EntryTimeToLive: " << to_string(attr.getEntryTimeToLive())
+            << "\n";
+  std::cout << "EntryIdleTimeout: " << to_string(attr.getEntryIdleTimeout())
+            << "\n";
+  std::cout << "getLruEntriesLimit: " << attr.getLruEntriesLimit() << "\n";
+  std::cout << "RegionTimeToLiveAction: "
+            << static_cast<int>(attr.getRegionTimeToLiveAction()) << "\n";
+  std::cout << "RegionIdleTimeoutAction: "
+            << static_cast<int>(attr.getRegionIdleTimeoutAction()) << "\n";
+  std::cout << "EntryTimeToLiveAction: "
+            << static_cast<int>(attr.getEntryTimeToLiveAction()) << "\n";
+  std::cout << "EntryIdleTimeoutAction: "
+            << static_cast<int>(attr.getEntryIdleTimeoutAction()) << "\n";
+  std::cout << "LruEvictionAction: "
+            << static_cast<int>(attr.getLruEvictionAction()) << "\n";
+  std::cout << "ClientNotification: "
+            << (attr.getClientNotificationEnabled() ? "true" : "false") << "\n";
 }
 
 void setCacheListener(const char *regName,
@@ -139,15 +136,11 @@ void ValidateDestroyRegion(const char *name) {
     rptr->put(1, 2);
     FAIL("Put should not be happened");
   } catch (RegionDestroyedException &ex) {
-    char buffer[1024];
-    sprintf(buffer, "Got expected exception %s: msg = %s", ex.getName().c_str(),
-            ex.what());
-    LOG(buffer);
+    LOG(std::string("Got expected exception ") + ex.getName() +
+        ": msg = " + ex.what());
   } catch (Exception &ex) {
-    char buffer[1024];
-    sprintf(buffer, "Got unexpected exception %s: msg = %s",
-            ex.getName().c_str(), ex.what());
-    FAIL(buffer);
+    FAIL(std::string("Got expected exception ") + ex.getName() +
+         ": msg = " + ex.what());
   }
 }
 
@@ -157,8 +150,9 @@ void createRegion(const char *name, bool ackMode,
                   const std::chrono::seconds &rttl,
                   const std::chrono::seconds &rit, int lel,
                   ExpirationAction action = ExpirationAction::DESTROY) {
-  fprintf(stdout, "Creating region --  %s  ackMode is %d\n", name, ackMode);
-  fflush(stdout);
+  std::cout << "Creating region --  " << name << " ackMode is " << ackMode
+            << "\n"
+            << std::flush;
   auto
       regPtr =  // getHelper()->createRegion( name, ackMode, true,
                 // ettl,eit,rttl,rit,lel,action,endpoints,clientNotificationEnabled
@@ -172,19 +166,15 @@ void createRegion(const char *name, bool ackMode,
 
 void doRgnOperations(const char *name, int n, int rgnOpt = 0) {
   std::shared_ptr<CacheableString> value;
-  char buf[16];
   if (rgnOpt == 0) {
-    memset(buf, 'A', 15);
-    buf[15] = '\0';
-    memcpy(buf, "Value - ", 8);
-    value = CacheableString::create(buf);
+    value = CacheableString::create("Value - AAAAAAA");
     ASSERT(value != nullptr, "Failed to create value.");
   }
   auto rptr = getHelper()->getRegion(name);
   ASSERT(rptr != nullptr, "Region not found.");
   for (int i = 0; i < n; i++) {
-    sprintf(buf, "KeyA - %d", i + 1);
-    auto key = CacheableKey::create(buf);
+    auto keyStr = std::string("KeyA - ") + std::to_string(i + 1);
+    auto key = CacheableKey::create(keyStr);
     switch (rgnOpt) {
       case 0:
         rptr->put(key, value);
@@ -210,11 +200,12 @@ void doRgnOperations(const char *name, int n, int rgnOpt = 0) {
 
 void dumpCounters(const char *regName) {
   auto rptr = getHelper()->getRegion(regName);
-  printf("Region size: %d\n", rptr->size());
+  std::cout << "Region size: " << rptr->size() << "\n";
   if (regListener != nullptr) {
-    printf("counts:: creates: %d, updates: %d, invalidates: %d, destroys: %d\n",
-           regListener->getCreates(), regListener->getUpdates(),
-           regListener->getInvalidates(), regListener->getDestroys());
+    std::cout << "counts:: creates: " << regListener->getCreates()
+              << ", updates: " << regListener->getUpdates()
+              << ", invalidates: " << regListener->getInvalidates()
+              << ", destroys: " << regListener->getDestroys() << "\n";
   }
 }
 
@@ -226,11 +217,11 @@ size_t getNumOfEntries(const char *regName, bool isValue = false) {
   auto rptr = getHelper()->getRegion(regName);
   if (isValue) {
     auto v = rptr->values();
-    printf("Region value size: %zd\n", v.size());
+    std::cout << "Region value size: " << v.size() << "\n";
     return v.size();
   } else if (!useRegionSize) {
     auto v = rptr->keys();
-    printf("Region key size: %zd\n", v.size());
+    std::cout << "Region key size: " << v.size() << "\n";
     return v.size();
   } else {
     return rptr->size();
@@ -255,10 +246,8 @@ void createThinClientRegion(
     try {
       doRgnOperations(regionName, noOfEntry, rgnOpt);
     } catch (EntryNotFoundException &ex) {
-      char buffer[1024];
-      sprintf(buffer, "Got expected exception %s: msg = %s",
-              ex.getName().c_str(), ex.what());
-      LOG(buffer);
+      LOG(std::string("Got expected exception ") + ex.getName() +
+          ": msg = " + ex.what());
     }
     localDestroyRegion(regionName);
   }
@@ -303,7 +292,7 @@ END_TASK(StepTwoCase1)
 DUNIT_TASK(CLIENT1, StepThreeCase1)
   {
     doRgnOperations(regionNames[0], 100);
-    ACE_OS::sleep(1);
+    std::this_thread::sleep_for(std::chrono::seconds(1));
     auto n = getNumOfEntries(regionNames[0]);
     ASSERT(n == 100, "Expected 100 entries");
     LOG("StepThree complete.");
@@ -320,7 +309,7 @@ END_TASK(StepFourCase1)
 DUNIT_TASK(CLIENT1, StepFiveCase1)
   {
     // wair 5 sec so all enteries gone
-    ACE_OS::sleep(5);
+    std::this_thread::sleep_for(std::chrono::seconds(5));
     auto n = getNumOfEntries(regionNames[0]);
     ASSERT(n == 0, "Expected 0 entries");
     LOG("StepFive complete.");
@@ -328,7 +317,7 @@ DUNIT_TASK(CLIENT1, StepFiveCase1)
 END_TASK(StepFiveCase1)
 DUNIT_TASK(CLIENT2, StepSixCase1)
   {
-    ACE_OS::sleep(5);
+    std::this_thread::sleep_for(std::chrono::seconds(5));
     // all enteris has been deleted
     // int n = getNumOfEntries(regionNames[0],true);
     auto n = getNumOfEntries(regionNames[0]);
@@ -384,10 +373,10 @@ DUNIT_TASK(CLIENT2, StepFourCase2)
 END_TASK(StepFourCase2)
 DUNIT_TASK(CLIENT1, StepFiveCase2)
   {
-    ACE_OS::sleep(2);
+    std::this_thread::sleep_for(std::chrono::seconds(2));
     auto n = getNumOfEntries(regionNames[0]);
     ASSERT(n == 100, "Expected 100 entries");
-    ACE_OS::sleep(5);
+    std::this_thread::sleep_for(std::chrono::seconds(5));
     // value should be invalidate as passing true
     n = getNumOfEntries(regionNames[0], true);
     ASSERT(n == 0, "Expected 0 entries");
@@ -396,7 +385,7 @@ DUNIT_TASK(CLIENT1, StepFiveCase2)
 END_TASK(StepFiveCase2)
 DUNIT_TASK(CLIENT2, StepSixCase2)
   {
-    ACE_OS::sleep(2);
+    std::this_thread::sleep_for(std::chrono::seconds(2));
     auto n = getNumOfEntries(regionNames[0], true);
     ASSERT(n == 100, "Expected 100 entries");
     LOG("StepSixCase2 complete.");
@@ -455,7 +444,7 @@ DUNIT_TASK(CLIENT1, StepFiveCase3)
 END_TASK(StepFiveCase3)
 DUNIT_TASK(CLIENT2, StepSixCase3)
   {
-    ACE_OS::sleep(2);
+    std::this_thread::sleep_for(std::chrono::seconds(2));
     auto n = getNumOfEntries(regionNames[0]);
     ASSERT(n == 10, "Expected 10 entries");
     n = getNumOfEntries(regionNames[0], true);
@@ -512,12 +501,12 @@ DUNIT_TASK(CLIENT2, StepFourCase4)
 END_TASK(StepFourCase4)
 DUNIT_TASK(CLIENT1, StepFiveCase4)
   {
-    ACE_OS::sleep(2);
+    std::this_thread::sleep_for(std::chrono::seconds(2));
     auto n = getNumOfEntries(regionNames[0]);
     ASSERT(n == 5, "Expected 5 entries");
     n = getNumOfEntries(regionNames[0], true);
     ASSERT(n == 5, "Expected 5 entries");
-    ACE_OS::sleep(4);
+    std::this_thread::sleep_for(std::chrono::seconds(4));
     n = getNumOfEntries(regionNames[0]);
     ASSERT(n == 5, "Expected 5 entries");
     LOG("StepFiveCase4 "
@@ -526,7 +515,7 @@ DUNIT_TASK(CLIENT1, StepFiveCase4)
 END_TASK(StepFiveCase4)
 DUNIT_TASK(CLIENT2, StepSixCase4)
   {
-    ACE_OS::sleep(1);
+    std::this_thread::sleep_for(std::chrono::seconds(1));
     auto n = getNumOfEntries(regionNames[0]);
     ASSERT(n == 10, "Expected 10 entries");
     n = getNumOfEntries(regionNames[0], true);
@@ -596,7 +585,7 @@ DUNIT_TASK(CLIENT2, StepFourCase5)
 END_TASK(StepFourCase5)
 DUNIT_TASK(CLIENT1, StepFiveCase5)
   {
-    ACE_OS::sleep(2);
+    std::this_thread::sleep_for(std::chrono::seconds(2));
     auto n = getNumOfEntries(regionNames[0]);
     ASSERT(n == 5,
            "Expected "
@@ -607,7 +596,7 @@ DUNIT_TASK(CLIENT1, StepFiveCase5)
            "Expected "
            "5 "
            "entries");
-    ACE_OS::sleep(4);
+    std::this_thread::sleep_for(std::chrono::seconds(4));
     n = getNumOfEntries(regionNames[0]);
     ASSERT(n == 0,
            "Expected "
@@ -620,7 +609,7 @@ DUNIT_TASK(CLIENT1, StepFiveCase5)
 END_TASK(StepFiveCase5)
 DUNIT_TASK(CLIENT2, StepSixCase5)
   {
-    ACE_OS::sleep(2);
+    std::this_thread::sleep_for(std::chrono::seconds(2));
     auto n = getNumOfEntries(regionNames[0]);
     ASSERT(n == 5,
            "Expecte"
@@ -711,12 +700,12 @@ DUNIT_TASK(CLIENT2, StepFourCase6)
 END_TASK(StepFourCase6)
 DUNIT_TASK(CLIENT1, StepFiveCase6)
   {
-    ACE_OS::sleep(2);
+    std::this_thread::sleep_for(std::chrono::seconds(2));
     auto n = getNumOfEntries(regionNames[0]);
     ASSERT(n == 5, "Expected 5 entries");
     n = getNumOfEntries(regionNames[0], true);
     ASSERT(n == 5, "Expected 5 entries");
-    ACE_OS::sleep(4);
+    std::this_thread::sleep_for(std::chrono::seconds(4));
     n = getNumOfEntries(regionNames[0]);
     ASSERT(n == 5, "Expected 5 entries");
     LOG("StepFiveCase6 complete.");
@@ -724,7 +713,7 @@ DUNIT_TASK(CLIENT1, StepFiveCase6)
 END_TASK(StepFiveCase6)
 DUNIT_TASK(CLIENT2, StepSixCase6)
   {
-    ACE_OS::sleep(1);
+    std::this_thread::sleep_for(std::chrono::seconds(1));
     auto n = getNumOfEntries(regionNames[0]);
     ASSERT(n == 10, "Expected 10 entries");
     n = getNumOfEntries(regionNames[0], true);
@@ -771,21 +760,21 @@ DUNIT_TASK(CLIENT2, StepFourCase7)
 END_TASK(StepFourCase7)
 DUNIT_TASK(CLIENT1, StepFiveCase7)
   {
-    ACE_OS::sleep(15);
+    std::this_thread::sleep_for(std::chrono::seconds(15));
     ValidateDestroyRegion(regionNames[0]);
     LOG("StepFiveCase7 complete.");
   }
 END_TASK(StepFiveCase7)
 DUNIT_TASK(CLIENT2, StepSixCase7)
   {
-    ACE_OS::sleep(3);
+    std::this_thread::sleep_for(std::chrono::seconds(3));
     ValidateDestroyRegion(regionNames[0]);
     LOG("StepSixCase7 complete.");
   }
 END_TASK(StepSixCase7)
 DUNIT_TASK(CLIENT1, StepOneCase8)
   {
-    ACE_OS::sleep(10);
+    std::this_thread::sleep_for(std::chrono::seconds(10));
     // regionName, ettl, eit , rttl, rit,lel,endpoints,noOfEntry,rgnOpetation -
     // [put-0/get-5/destroy-3] ,destroyRgn - [true/false]
     // ,clientNotificationEnabled - [true/false] ,ExpirationAction
@@ -823,17 +812,17 @@ DUNIT_TASK(CLIENT2, StepFourCase8)
 END_TASK(StepFourCase8)
 DUNIT_TASK(CLIENT1, StepFiveCase8)
   {
-    ACE_OS::sleep(5);
+    std::this_thread::sleep_for(std::chrono::seconds(5));
     auto n = getNumOfEntries(regionNames[1]);
     ASSERT(n == 10, "Expected 0 entries");
-    ACE_OS::sleep(10);
+    std::this_thread::sleep_for(std::chrono::seconds(10));
     ValidateDestroyRegion(regionNames[1]);
     LOG("StepFiveCase8 complete.");
   }
 END_TASK(StepFiveCase8)
 DUNIT_TASK(CLIENT2, StepSixCase8)
   {
-    ACE_OS::sleep(2);
+    std::this_thread::sleep_for(std::chrono::seconds(2));
     ValidateDestroyRegion(regionNames[1]);
     LOG("StepSixCase8 complete.");
   }
@@ -861,7 +850,7 @@ DUNIT_TASK(CLIENT2, StepTwoCase9)
 END_TASK(StepTwoCase9)
 DUNIT_TASK(CLIENT1, StepThreeCase9)
   {
-    ACE_OS::sleep(2);
+    std::this_thread::sleep_for(std::chrono::seconds(2));
     doRgnOperations(regionNames[2], 10);
     auto n = getNumOfEntries(regionNames[2]);
     ASSERT(n == 5, "Expected 5 entries");
@@ -878,17 +867,17 @@ DUNIT_TASK(CLIENT2, StepFourCase9)
 END_TASK(StepFourCase9)
 DUNIT_TASK(CLIENT1, StepFiveCase9)
   {
-    ACE_OS::sleep(5);
+    std::this_thread::sleep_for(std::chrono::seconds(5));
     auto n = getNumOfEntries(regionNames[2]);
     ASSERT(n == 0, "Expected 0 entries");
-    ACE_OS::sleep(8);
+    std::this_thread::sleep_for(std::chrono::seconds(8));
     ValidateDestroyRegion(regionNames[2]);
     LOG("StepFiveCase9 complete.");
   }
 END_TASK(StepFiveCase9)
 DUNIT_TASK(CLIENT2, StepSixCase9)
   {
-    ACE_OS::sleep(3);
+    std::this_thread::sleep_for(std::chrono::seconds(3));
     ValidateDestroyRegion(regionNames[2]);
     LOG("StepSixCase9 complete.");
   }
@@ -932,17 +921,17 @@ DUNIT_TASK(CLIENT2, StepFourCase10)
 END_TASK(StepFourCase10)
 DUNIT_TASK(CLIENT1, StepFiveCase10)
   {
-    ACE_OS::sleep(5);
+    std::this_thread::sleep_for(std::chrono::seconds(5));
     auto n = getNumOfEntries(regionNames[3]);
     ASSERT(n == 0, "Expected 0 entries");
-    ACE_OS::sleep(10);
+    std::this_thread::sleep_for(std::chrono::seconds(10));
     ValidateDestroyRegion(regionNames[3]);
     LOG("StepFiveCase10 complete.");
   }
 END_TASK(StepFiveCase10)
 DUNIT_TASK(CLIENT2, StepSixCase10)
   {
-    ACE_OS::sleep(3);
+    std::this_thread::sleep_for(std::chrono::seconds(3));
     ValidateDestroyRegion(regionNames[3]);
     LOG("StepSixCase10 complete.");
   }
@@ -1021,7 +1010,7 @@ DUNIT_TASK(CLIENT2, StepFourCase11)
 END_TASK(StepFourCase11)
 DUNIT_TASK(CLIENT1, StepFiveCase11)
   {
-    ACE_OS::sleep(5);
+    std::this_thread::sleep_for(std::chrono::seconds(5));
     auto n = getNumOfEntries(regionNames[4]);
 
     ASSERT(regWriter->isWriterInvoked() == true, "Writer Should be invoked");
@@ -1058,7 +1047,7 @@ DUNIT_TASK(CLIENT2, StepSixCase11)
       so expect 5 entries instead of 0 earlier. */
     ASSERT(n == 5, "Expected 5 entries");
 
-    ACE_OS::sleep(3);
+    std::this_thread::sleep_for(std::chrono::seconds(3));
     LOG("StepSixCase11 complete.");
   }
 END_TASK(StepSixCase11)
@@ -1149,7 +1138,7 @@ DUNIT_TASK(CLIENT2, StepFourCase12)
 END_TASK(StepFourCase12)
 DUNIT_TASK(CLIENT1, StepFiveCase12)
   {
-    ACE_OS::sleep(5);
+    std::this_thread::sleep_for(std::chrono::seconds(5));
     auto n = getNumOfEntries(regionNames[5]);
 
     ASSERT(regWriter->isWriterInvoked() == true, "Writer Should be invoked");
@@ -1168,7 +1157,7 @@ DUNIT_TASK(CLIENT1, StepFiveCase12)
 END_TASK(StepFiveCase12)
 DUNIT_TASK(CLIENT2, StepSixCase12)
   {
-    ACE_OS::sleep(3);
+    std::this_thread::sleep_for(std::chrono::seconds(3));
     auto n = getNumOfEntries(regionNames[5]);
     ASSERT(regWriter->isWriterInvoked() == false,
            "Writer Should not be invoked");
@@ -1262,7 +1251,7 @@ DUNIT_TASK(CLIENT2, StepFourCase13)
 END_TASK(StepFourCase13)
 DUNIT_TASK(CLIENT1, StepFiveCase13)
   {
-    ACE_OS::sleep(5);
+    std::this_thread::sleep_for(std::chrono::seconds(5));
     auto n = getNumOfEntries(regionNames[5]);
 
     ASSERT(regWriter->isWriterInvoked() == true, "Writer Should be invoked");
@@ -1281,7 +1270,7 @@ DUNIT_TASK(CLIENT1, StepFiveCase13)
 END_TASK(StepFiveCase13)
 DUNIT_TASK(CLIENT2, StepSixCase13)
   {
-    ACE_OS::sleep(3);
+    std::this_thread::sleep_for(std::chrono::seconds(3));
     auto n = getNumOfEntries(regionNames[5]);
     ASSERT(regWriter->isWriterInvoked() == false,
            "Writer Should not be invoked");
