@@ -22,8 +22,6 @@
 #include "BuiltinCacheableWrappers.hpp"
 #include "Utils.hpp"
 
-#include <ace/OS.h>
-#include <ace/High_Res_Timer.h>
 #include "TallyListener.hpp"
 #include <string>
 #include "CacheHelper.hpp"
@@ -47,7 +45,7 @@ using apache::geode::client::testing::TallyListener;
 std::shared_ptr<TallyListener> reg1Listener1;
 bool isLocalServer = false;
 static bool isLocator = false;
-const char *locatorsG =
+const std::string locatorsG =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, 1);
 
 void setCacheListener(const char *regName,
@@ -82,8 +80,6 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepOne_Pooled_Locator_Client1)
     getHelper()->createPoolWithLocators("__TEST_POOL1__", locatorsG);
     getHelper()->createRegionAndAttachPool(regionNames[0], USE_ACK,
                                            "__TEST_POOL1__");
-    getHelper()->createRegionAndAttachPool(regionNames[1], NO_ACK,
-                                           "__TEST_POOL1__");
 
     reg1Listener1 = std::make_shared<TallyListener>();
     setCacheListener(regionNames[0], reg1Listener1);
@@ -98,8 +94,6 @@ DUNIT_TASK_DEFINITION(CLIENT2, StepOne_Pooled_Locator_Client2)
     getHelper()->createPoolWithLocators("__TEST_POOL1__", locatorsG, true, 2);
     getHelper()->createRegionAndAttachPool(regionNames[0], USE_ACK,
                                            "__TEST_POOL1__");
-    getHelper()->createRegionAndAttachPool(regionNames[1], NO_ACK,
-                                           "__TEST_POOL1__");
 
     reg1Listener1 = std::make_shared<TallyListener>();
     setCacheListener(regionNames[0], reg1Listener1);
@@ -111,8 +105,6 @@ DUNIT_TASK_DEFINITION(CLIENT2, StepTwo_RegisterAllKeys)
   {
     auto regPtr0 = getHelper()->getRegion(regionNames[0]);
     regPtr0->registerAllKeys();
-    auto regPtr1 = getHelper()->getRegion(regionNames[1]);
-    regPtr1->registerAllKeys();
     LOG("StepTwo_Pooled_EndPoint_RegisterAllKeys complete.");
   }
 END_TASK_DEFINITION
@@ -123,18 +115,16 @@ DUNIT_TASK_DEFINITION(CLIENT1, PutAllOneTask)
     auto dataReg = getHelper()->getRegion(regionNames[0]);
     HashMapOfCacheable entryMap;
     entryMap.clear();
-    char key[256];
-    char value[256];
     for (int32_t item = 0; item < 1000; item++) {
-      sprintf(key, "key-%d", item);
-      sprintf(value, "%d", item);
-      entryMap.emplace(CacheableKey::create(key),
-                       CacheableString::create(value));
+      auto key =
+          CacheableKey::create(std::string("key-") + std::to_string(item));
+      auto value = CacheableString::create(std::to_string(item));
+      entryMap.emplace(key, value);
       LOGDEBUG(
           "CPPTEST:PutAllOneTask Doing PutAll on key using key: = %s: & value: "
           "= "
           "%s",
-          key, value);
+          key->toString().c_str(), value->value().c_str());
     }
     try {
       dataReg->putAll(entryMap);
@@ -156,18 +146,16 @@ DUNIT_TASK_DEFINITION(CLIENT1, PutAllTwoTask)
     auto dataReg = getHelper()->getRegion(regionNames[0]);
     HashMapOfCacheable entryMap;
     entryMap.clear();
-    char key[256];
-    char value[256];
     for (int32_t item = 1000; item < 2000; item++) {
-      sprintf(key, "key-%d", item);
-      sprintf(value, "%d", item);
+      auto key =
+          CacheableKey::create(std::string("key-") + std::to_string(item));
+      auto value = CacheableString::create(std::to_string(item));
       LOGDEBUG(
           "CPPTEST:PutAllTwoTask Doing PutAll on key using key: = %s: & value: "
           "= "
           "%s",
-          key, value);
-      entryMap.emplace(CacheableKey::create(key),
-                       CacheableString::create(value));
+          key->toString().c_str(), value->value().c_str());
+      entryMap.emplace(key, value);
     }
     try {
       dataReg->putAll(entryMap);
@@ -189,18 +177,16 @@ DUNIT_TASK_DEFINITION(CLIENT1, PutAllThreeTask)
     auto dataReg = getHelper()->getRegion(regionNames[0]);
     HashMapOfCacheable entryMap;
     entryMap.clear();
-    char key[256];
-    char value[256];
     for (int32_t item = 2000; item < 3000; item++) {
-      sprintf(key, "key-%d", item);
-      sprintf(value, "%d", item);
+      auto key =
+          CacheableKey::create(std::string("key-") + std::to_string(item));
+      auto value = CacheableString::create(std::to_string(item));
       LOGDEBUG(
           "CPPTEST:PutAllThreeTask Doing PutAll on key using key: = %s: & "
           "value: "
           "= %s",
-          key, value);
-      entryMap.emplace(CacheableKey::create(key),
-                       CacheableString::create(value));
+          key->toString().c_str(), value->value().c_str());
+      entryMap.emplace(key, value);
     }
     try {
       dataReg->putAll(entryMap);
@@ -222,18 +208,16 @@ DUNIT_TASK_DEFINITION(CLIENT1, PutAllFourTask)
     auto dataReg = getHelper()->getRegion(regionNames[0]);
     HashMapOfCacheable entryMap;
     entryMap.clear();
-    char key[256];
-    char value[256];
     for (int32_t item = 3000; item < 4000; item++) {
-      sprintf(key, "key-%d", item);
-      sprintf(value, "%d", item);
+      auto key =
+          CacheableKey::create(std::string("key-") + std::to_string(item));
+      auto value = CacheableString::create(std::to_string(item));
       LOGDEBUG(
           "CPPTEST:PutAllFourTask Doing PutAll on key using key: = %s: & "
           "value: "
           "= %s",
-          key, value);
-      entryMap.emplace(CacheableKey::create(key),
-                       CacheableString::create(value));
+          key->toString().c_str(), value->value().c_str());
+      entryMap.emplace(key, value);
     }
     try {
       dataReg->putAll(entryMap);
@@ -261,15 +245,14 @@ DUNIT_TASK_DEFINITION(CLIENT2, VerifyAllPutAllTask)
            "Got wrong number of creation events.");
 
     ASSERT(dataReg->size() == 4000, "Expected 4000 entries in region");
-    char key[256];
-    char value[256];
     for (int32_t item = 0; item < 4000; item++) {
-      sprintf(key, "key-%d", item);
-      sprintf(value, "%d", item);
+      auto key =
+          CacheableKey::create(std::string("key-") + std::to_string(item));
+      auto value = CacheableString::create(std::to_string(item));
       LOGDEBUG("CPPTEST:VerifyAllPutAllTask Doing get on key using: = %s: ",
-               key);
-      auto checkPtr = std::dynamic_pointer_cast<CacheableString>(
-          dataReg->get(CacheableKey::create(key)));
+               key->toString().c_str());
+      auto checkPtr =
+          std::dynamic_pointer_cast<CacheableString>(dataReg->get(key));
       ASSERT(checkPtr != nullptr, "Value Ptr should not be null.");
       LOGDEBUG("CPPTEST:VerifyAllPutAllTask value is: = %s: ",
                checkPtr->value().c_str());
@@ -286,18 +269,16 @@ DUNIT_TASK_DEFINITION(CLIENT1, RemoveAllOneTask)
     HashMapOfCacheable entryMap;
     std::vector<std::shared_ptr<CacheableKey>> keysVector;
     entryMap.clear();
-    char key[256];
-    char value[256];
     for (int32_t item = 0; item < 1000; item++) {
-      sprintf(key, "key-%d", item);
-      sprintf(value, "%d", item);
-      entryMap.emplace(CacheableKey::create(key),
-                       CacheableString::create(value));
-      keysVector.push_back(CacheableKey::create(key));
+      auto key =
+          CacheableKey::create(std::string("key-") + std::to_string(item));
+      auto value = CacheableString::create(std::to_string(item));
+      entryMap.emplace(key, value);
+      keysVector.push_back(key);
       LOGDEBUG(
           "CPPTEST:RemoveAllOneTask Doing PutAll on key using key: = %s: & "
           "value: = %s",
-          key, value);
+          key->toString().c_str(), value->value().c_str());
     }
     try {
       dataReg->putAll(entryMap);
@@ -321,18 +302,16 @@ DUNIT_TASK_DEFINITION(CLIENT1, RemoveAllTwoTask)
     HashMapOfCacheable entryMap;
     std::vector<std::shared_ptr<CacheableKey>> keysVector;
     entryMap.clear();
-    char key[256];
-    char value[256];
     for (int32_t item = 1000; item < 2000; item++) {
-      sprintf(key, "key-%d", item);
-      sprintf(value, "%d", item);
-      entryMap.emplace(CacheableKey::create(key),
-                       CacheableString::create(value));
-      keysVector.push_back(CacheableKey::create(key));
+      auto key =
+          CacheableKey::create(std::string("key-") + std::to_string(item));
+      auto value = CacheableString::create(std::to_string(item));
+      entryMap.emplace(key, value);
+      keysVector.push_back(key);
       LOGDEBUG(
           "CPPTEST:RemoveAllTwoTask Doing RemoveAll on key using key: = %s: & "
           "value: = %s",
-          key, value);
+          key->toString().c_str(), value->value().c_str());
     }
     try {
       dataReg->putAll(entryMap);
@@ -356,19 +335,17 @@ DUNIT_TASK_DEFINITION(CLIENT1, RemoveAllThreeTask)
     HashMapOfCacheable entryMap;
     std::vector<std::shared_ptr<CacheableKey>> keysVector;
     entryMap.clear();
-    char key[256];
-    char value[256];
     for (int32_t item = 2000; item < 3000; item++) {
-      sprintf(key, "key-%d", item);
-      sprintf(value, "%d", item);
-      entryMap.emplace(CacheableKey::create(key),
-                       CacheableString::create(value));
-      keysVector.push_back(CacheableKey::create(key));
+      auto key =
+          CacheableKey::create(std::string("key-") + std::to_string(item));
+      auto value = CacheableString::create(std::to_string(item));
+      entryMap.emplace(key, value);
+      keysVector.push_back(key);
       LOGDEBUG(
           "CPPTEST:RemoveAllThreeTask Doing RemoveAll on key using key: = %s: "
           "& "
           "value: = %s",
-          key, value);
+          key->toString().c_str(), value->value().c_str());
     }
     try {
       dataReg->putAll(entryMap);
@@ -393,18 +370,16 @@ DUNIT_TASK_DEFINITION(CLIENT1, RemoveAllFourTask)
     HashMapOfCacheable entryMap;
     std::vector<std::shared_ptr<CacheableKey>> keysVector;
     entryMap.clear();
-    char key[256];
-    char value[256];
     for (int32_t item = 3000; item < 4000; item++) {
-      sprintf(key, "key-%d", item);
-      sprintf(value, "%d", item);
-      entryMap.emplace(CacheableKey::create(key),
-                       CacheableString::create(value));
-      keysVector.push_back(CacheableKey::create(key));
+      auto key =
+          CacheableKey::create(std::string("key-") + std::to_string(item));
+      auto value = CacheableString::create(std::to_string(item));
+      entryMap.emplace(key, value);
+      keysVector.push_back(key);
       LOGDEBUG(
           "CPPTEST:RemoveAllFourTask Doing RemoveAll on key using key: = %s: & "
           "value: = %s",
-          key, value);
+          key->toString().c_str(), value->value().c_str());
     }
     try {
       dataReg->putAll(entryMap);
