@@ -35,7 +35,7 @@ using apache::geode::client::IllegalStateException;
 bool isLocalServer = false;
 bool isLocator = false;
 
-const char *locHostPort =
+const std::string locHostPort =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, 1);
 const char *poolRegNames[] = {"PoolRegion1"};
 const char *poolName = "__TEST_POOL1__";
@@ -44,17 +44,16 @@ const char *poolName1 = "clientPool";
 const char *serverGroup = "ServerGroup1";
 std::shared_ptr<Cache> cachePtr;
 
-class putThread : public ACE_Task_Base {
- private:
-  std::shared_ptr<Region> regPtr;
-
+class PutThread {
  public:
-  explicit putThread(const char *name) : regPtr(getHelper()->getRegion(name)) {}
+  explicit PutThread() : regPtr{nullptr} {}
+  explicit PutThread(const std::string &name)
+      : regPtr{getHelper()->getRegion(name)} {}
 
-  int svc(void) {
+  void run() {
     // TODO: No. of connection should be = minConnection
 
-    for (int i = 0; i < 10000; i++) {
+    for (auto i = 0; i < 10000; ++i) {
       try {
         regPtr->put(keys[i % 5], vals[i % 6]);
       } catch (const Exception &) {
@@ -64,11 +63,23 @@ class putThread : public ACE_Task_Base {
       }
       // TODO: Check no. of connection > minConnetion
     }
-    // LOG(" Incremented 100 times by thread.");
-    return 0;
   }
-  void start() { activate(); }
+
+  void start() {
+    thread_ = std::thread{[this]() { run(); }};
+  }
+
+  void wait() {
+    if (thread_.joinable()) {
+      thread_.join();
+    }
+  }
+
   void stop() { wait(); }
+
+ protected:
+  std::shared_ptr<Region> regPtr;
+  std::thread thread_;
 };
 
 void doAttrTestingAndCreatePool(const char *poolNameToUse) {
@@ -227,9 +238,8 @@ END_TASK(StartC1)
 DUNIT_TASK(CLIENT2, StartC2)
   {
     auto props = Properties::create();
-    std::string path = "cacheserver_pool_client.xml";
-    std::string duplicateFile;
-    CacheHelper::createDuplicateXMLFile(duplicateFile, path);
+    auto duplicateFile =
+        CacheHelper::createDuplicateXMLFile("cacheserver_pool_client.xml");
 
     props->insert("cache-xml-file", duplicateFile.c_str());
 
@@ -238,10 +248,10 @@ DUNIT_TASK(CLIENT2, StartC2)
       initClient(true, props);
       LOG(" started client");
       ASSERT(getHelper()
-                     ->getCache()
-                     ->getPoolManager()
-                     .find("clientPoolMultiUser")
-                     ->getMultiuserAuthentication() == true,
+                 ->getCache()
+                 ->getPoolManager()
+                 .find("clientPoolMultiUser")
+                 ->getMultiuserAuthentication(),
              "MultiUser secure mode should be true for Pool");
     } catch (const Exception &excp) {
       LOG("Exception during client 2 XML creation");
@@ -267,15 +277,14 @@ DUNIT_TASK(CLIENT1, ClientOp)
                   ->getPoolManager()
                   .find(poolNameString.c_str())
                   ->getMinConnections();
-    char logmsg[100] = {0};
-    sprintf(logmsg, "Pool level not equal to min level. Expected %d, actual %d",
-            min, level);
-    ASSERT(level == min, logmsg);
+    ASSERT(level == min,
+           std::string("Pool level not equal to min level. Expected ") +
+               std::to_string(min) + ", actual " + std::to_string(level));
 
-    putThread *threads[25];
+    PutThread threads[25];
     for (int thdIdx = 0; thdIdx < 10; thdIdx++) {
-      threads[thdIdx] = new putThread(poolRegNames[0]);
-      threads[thdIdx]->start();
+      threads[thdIdx] = PutThread(poolRegNames[0]);
+      threads[thdIdx].start();
     }
 
     SLEEP(5000);  // wait for threads to become active
@@ -288,12 +297,12 @@ DUNIT_TASK(CLIENT1, ClientOp)
                   ->getPoolManager()
                   .find(poolNameString.c_str())
                   ->getMaxConnections();
-    sprintf(logmsg, "Pool level not equal to max level. Expected %d, actual %d",
-            max, level);
-    ASSERT(level == max, logmsg);
+    ASSERT(level == max,
+           std::string("Pool level not equal to max level. Expected ") +
+               std::to_string(max) + ", actual " + std::to_string(level));
 
     for (int thdIdx = 0; thdIdx < 10; thdIdx++) {
-      threads[thdIdx]->stop();
+      threads[thdIdx].stop();
     }
 
     // Milli second sleep: IdleTimeout is 5 sec, load conditioning
@@ -308,22 +317,21 @@ DUNIT_TASK(CLIENT1, ClientOp)
               ->getPoolManager()
               .find(poolNameString.c_str())
               ->getMinConnections();
-    sprintf(logmsg,
-            "Pool level not equal to min level after idle timeout. "
-            "Expected %d, actual %d",
-            min, level);
-    ASSERT(level == min, logmsg);
+    ASSERT(
+        level == min,
+        std::string(
+            "Pool level not equal to min level after idle timeout. Expected ") +
+            std::to_string(min) + ", actual " + std::to_string(level));
 
     LOG("Waiting 1 minute for load conditioning to kick in");
     SLEEP(60000);
 
     level = TestUtils::getCacheImpl(getHelper()->cachePtr)
                 ->getPoolSize(poolNameString);
-    sprintf(logmsg,
-            "Pool level not equal to min level after load "
-            "conditioning. Expected %d, actual %d",
-            min, level);
-    ASSERT(level == min, logmsg);
+    ASSERT(level == min, std::string("Pool level not equal to min level after "
+                                     "load conditioning. Expected ") +
+                             std::to_string(min) + ", actual " +
+                             std::to_string(level));
   }
 END_TASK(ClientOp)
 
