@@ -26,7 +26,7 @@
 #include "fw_dunit.hpp"
 #include "CacheHelper.hpp"
 #include "ThinClientHelper.hpp"
-#include <ace/Process.h>
+
 #include <string>
 
 #include "ThinClientSecurity.hpp"
@@ -36,7 +36,7 @@ using apache::geode::client::HashMapOfCacheable;
 using apache::geode::client::HashMapOfException;
 using apache::geode::client::NotAuthorizedException;
 
-const char *locHostPort =
+const std::string locHostPort =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, 1);
 
 #define HANDLE_NO_NOT_AUTHORIZED_EXCEPTION                 \
@@ -79,8 +79,7 @@ void initClientAuth(char userType, int clientNum = 1) {
       break;
     }
     case 'R': {
-      char clientStr[32];
-      sprintf(clientStr, "geode%d", clientNum);
+      auto clientStr = std::string("geode") + std::to_string(clientNum);
       config->insert("security-username", clientStr);
       config->insert("security-password", clientStr);
       break;
@@ -90,7 +89,9 @@ void initClientAuth(char userType, int clientNum = 1) {
       config->insert("security-password", "geode1");
       break;
     }
-    default: { break; }
+    default: {
+      break;
+    }
   }
   initClient(true, config);
 }
@@ -108,17 +109,17 @@ const char *getServerSecurityParams() {
         "org.apache.geode.internal.security.FilterPostAuthorization.create "
         "log-level=fine security-log-level=finest";
 
-    char *ldapSrv = ACE_OS::getenv("LDAP_SERVER");
+    char *ldapSrv = std::getenv("LDAP_SERVER");
     serverSecurityParams += std::string(" security-ldap-server=") +
                             (ldapSrv != nullptr ? ldapSrv : "ldap");
 
-    char *ldapRoot = ACE_OS::getenv("LDAP_BASEDN");
+    char *ldapRoot = std::getenv("LDAP_BASEDN");
     serverSecurityParams +=
         std::string(" security-ldap-basedn=") +
         (ldapRoot != nullptr ? ldapRoot
                              : "ou=ldapTesting,dc=ldap,dc=apache,dc=org");
 
-    char *ldapSSL = ACE_OS::getenv("LDAP_USESSL");
+    char *ldapSSL = std::getenv("LDAP_USESSL");
     serverSecurityParams += std::string(" security-ldap-usessl=") +
                             (ldapSSL != nullptr ? ldapSSL : "false");
   }
@@ -146,8 +147,8 @@ void checkValuesMap(HashMapOfCacheable &values, int clientNum, int numKeys) {
     expectedVal = CacheableString::create(nvals[index]);
     ASSERT(*val == *expectedVal, "unexpected value in values map");
   }
-  printf("Expected number of values: %zd; got values: %zd", expectedNum,
-         values.size());
+  std::cout << "Expected number of values: " << expectedNum
+            << "; got values: " << values.size() << "\n";
   ASSERT(values.size() == expectedNum, "unexpected number of values");
 }
 
@@ -164,11 +165,12 @@ void checkExceptionsMap(HashMapOfException &exceptions, int clientNum,
       ASSERT(std::dynamic_pointer_cast<std::shared_ptr<NotAuthorizedException>>(
                  iter->second),
              "unexpected exception type in exception map");
-      printf("Got expected NotAuthorizedException: %s", iter->second->what());
+      std::cout << "Got expected NotAuthorizedException: "
+                << iter->second->what() << "\n";
     }
   }
-  printf("Expected number of exceptions: %zd; got exceptions: %zd", expectedNum,
-         exceptions.size());
+  std::cout << "Expected number of exceptions: " << expectedNum
+            << "; got exceptions: " << exceptions.size() << "\n";
   ASSERT(exceptions.size() == expectedNum, "unexpected number of exceptions");
 }
 
