@@ -17,45 +17,38 @@
 
 #include "Cluster.h"
 
-#include <signal.h>
-
+#include <algorithm>
 #include <future>
 
 #include <boost/filesystem.hpp>
 
 Locator::Locator(Cluster &cluster, std::vector<Locator> &locators,
-                 std::string name, uint16_t jmxManagerPort, bool useIPv6)
+                 std::string name, uint16_t jmxManagerPort)
     : cluster_(cluster),
       name_(std::move(name)),
       locators_(locators),
       jmxManagerPort_(jmxManagerPort) {
-  auto hostname = "localhost";
-  if (useIPv6) {
-    hostname = "ip6-localhost";
-  }
-
-  auto port = Framework::getAvailablePort();
-
-  locatorAddress_ = LocatorAddress{hostname, port};
+  locatorAddress_ = LocatorAddress{"localhost", Framework::getAvailablePort()};
 }
 
 Locator::Locator(Cluster &cluster, std::vector<Locator> &locators,
-                 std::string name, uint16_t jmxManagerPort, bool useIPv6,
-                 uint16_t port, std::vector<uint16_t> &remotePorts,
-                 uint16_t distributedSystemId)
+                 std::string name, uint16_t jmxManagerPort,
+                 LocatorAddress locatorAddress,
+                 std::vector<LocatorAddress> remoteLocators,
+                 int16_t distributedSystemId)
     : cluster_(cluster),
       name_(std::move(name)),
       locators_(locators),
       jmxManagerPort_(jmxManagerPort),
-      distributedSystemId_(distributedSystemId){
-  auto hostname = "localhost";
-  if (useIPv6) {
-    hostname = "ip6-localhost";
+      locatorAddress_(locatorAddress),
+      remoteLocators_(remoteLocators),
+      distributedSystemId_(distributedSystemId) {
+  if (locatorAddress_.address.empty()) {
+    locatorAddress_.address = "localhost";
   }
-  locatorAddress_ = LocatorAddress{hostname, port};
 
-  for (uint16_t remotePort : remotePorts){
-    remoteLocatorsPorts_.push_back(remotePort);
+  if (0 == locatorAddress_.port) {
+    locatorAddress_.port = Framework::getAvailablePort();
   }
 }
 
@@ -72,17 +65,15 @@ Locator::Locator(Locator &&move)
     : cluster_(move.cluster_),
       name_(move.name_),
       locators_(move.locators_),
-      locatorAddress_(move.locatorAddress_),
-      remoteLocatorsPorts_(move.remoteLocatorsPorts_),
       jmxManagerPort_(move.jmxManagerPort_),
-      started_(move.started_),
-      distributedSystemId_(move.distributedSystemId_){
-  move.started_ = false;
-}
+      locatorAddress_(move.locatorAddress_),
+      remoteLocators_(move.remoteLocators_),
+      started_(false),
+      distributedSystemId_(move.distributedSystemId_) {}
 
 const LocatorAddress &Locator::getAddress() const { return locatorAddress_; }
 
-void Locator::start() {
+void Locator::start(bool startJmxManager) {
   if (started_) return;
 
   auto safeName = name_;
@@ -92,6 +83,16 @@ void Locator::start() {
     cluster_.getGfsh().stop().locator().withDir(name_).execute();
   }
 
+  std::vector<std::string> remoteLocators;
+  std::transform(remoteLocators_.begin(), remoteLocators_.end(),
+                 std::back_inserter(remoteLocators),
+                 [](const LocatorAddress &locatorAddress) {
+                   return locatorAddress.address.empty()
+                              ? "localhost"
+                              : locatorAddress.address + "[" +
+                                    std::to_string(locatorAddress.port) + "]";
+                 });
+
   auto locator = cluster_.getGfsh()
                      .start()
                      .locator()
@@ -100,7 +101,7 @@ void Locator::start() {
                      .withName(safeName)
                      .withBindAddress(locatorAddress_.address)
                      .withPort(locatorAddress_.port)
-                     .withRemoteLocators(remoteLocatorsPorts_)
+                     .withRemoteLocators(remoteLocators)
                      .withDistributedSystemId(distributedSystemId_)
                      .withMaxHeap("256m")
                      .withJmxManagerPort(jmxManagerPort_)
@@ -108,7 +109,7 @@ void Locator::start() {
                      .withClasspath(cluster_.getClasspath())
                      .withSecurityManager(cluster_.getSecurityManager())
                      .withPreferIPv6(cluster_.getUseIPv6())
-                     .withJmxManagerStart(true);
+                     .withJmxManagerStart(startJmxManager);
 
   if (cluster_.useSsl()) {
     locator.withConnect(false)
@@ -150,19 +151,19 @@ void Locator::stop() {
   started_ = false;
 }
 
+const ServerAddress &Server::getAddress() const { return serverAddress_; }
+
 Server::Server(Cluster &cluster, std::vector<Locator> &locators,
-               std::string name, std::string xmlFile, bool useIPv6)
+               std::string name, std::string xmlFile,
+               ServerAddress serverAddress)
     : cluster_(cluster),
       locators_(locators),
+      serverAddress_(std::move(serverAddress)),
       name_(std::move(name)),
       xmlFile_(xmlFile) {
-  auto hostname = "localhost";
-  if (useIPv6) {
-    hostname = "ip6-localhost";
+  if (serverAddress_.address.empty()) {
+    serverAddress_.address = "localhost";
   }
-
-  auto port = static_cast<uint16_t>(0);
-  serverAddress_ = ServerAddress{hostname, port};
 }
 
 std::string Server::getCacheXMLFile() { return xmlFile_; }
@@ -205,6 +206,7 @@ void Server::start() {
           .withClasspath(cluster_.getClasspath())
           .withSecurityManager(cluster_.getSecurityManager())
           .withCacheXMLFile(getCacheXMLFile())
+          .withConserveSockets(cluster_.getConserveSockets())
           .withPreferIPv6(cluster_.getUseIPv6());
 
   if (!cluster_.getUser().empty()) {
@@ -231,62 +233,62 @@ void Server::stop() {
   started_ = false;
 }
 
-Cluster::Cluster(LocatorCount initialLocators, ServerCount initialServers,
-                 std::vector<uint16_t> &locatorPorts, std::vector<uint16_t> &remoteLocatorPort,
-                 uint16_t distributedSystemId) : Cluster(
-    Name(std::string(::testing::UnitTest::GetInstance()
-                         ->current_test_info()
-                         ->test_case_name()) +
-         "/DS" + std::to_string(distributedSystemId) + "/" +
-         ::testing::UnitTest::GetInstance()->current_test_info()->name()), Classpath(""),
-         SecurityManager(""), User(""), Password(""), initialLocators, initialServers,
-         CacheXMLFiles({}), locatorPorts, remoteLocatorPort, distributedSystemId) {}
+Cluster::Cluster(InitialLocators initialLocators, InitialServers initialServers,
+                 RemoteLocators remoteLocators,
+                 DistributedSystemId distributedSystemId)
+    : Cluster(
+          Name(std::string(::testing::UnitTest::GetInstance()
+                               ->current_test_info()
+                               ->test_suite_name()) +
+               "/DS" + std::to_string(distributedSystemId.get()) + "/" +
+               ::testing::UnitTest::GetInstance()->current_test_info()->name()),
+          Classpath(""), SecurityManager(""), User(""), Password(""),
+          initialLocators, initialServers, CacheXMLFiles(), remoteLocators,
+          distributedSystemId) {}
 
 Cluster::Cluster(Name name, Classpath classpath,
                  SecurityManager securityManager, User user, Password password,
-                 LocatorCount initialLocators, ServerCount initialServers,
-                 CacheXMLFiles cacheXMLFiles, std::vector<uint16_t> &locatorPorts,
-                 std::vector<uint16_t> &remoteLocatorPort, uint16_t distributedSystemId)
+                 InitialLocators initialLocators, InitialServers initialServers,
+                 CacheXMLFiles cacheXMLFiles, RemoteLocators remoteLocators,
+                 DistributedSystemId distributedSystemId)
     : name_(name.get()),
       classpath_(classpath.get()),
       securityManager_(securityManager.get()),
       user_(user.get()),
       password_(password.get()),
+      cacheXMLFiles_(cacheXMLFiles.get()),
       initialLocators_(initialLocators.get()),
+      remoteLocators_(remoteLocators.get()),
       initialServers_(initialServers.get()),
       jmxManagerPort_(Framework::getAvailablePort()),
-      distributedSystemId_(distributedSystemId)
-      {
-  cacheXMLFiles_ = cacheXMLFiles.get();
-  useIPv6_ = false;
-
-  for(uint16_t port : locatorPorts){
-    locatorsPorts_.push_back(port);
-  }
-  for(uint16_t port : remoteLocatorPort){
-    remoteLocatorsPorts_.push_back(port);
-  }
+      distributedSystemId_(distributedSystemId.get()) {
   removeServerDirectory();
 }
 
-Cluster::Cluster(LocatorCount initialLocators, ServerCount initialServers,
-                 UseIpv6 useIPv6)
-    : Cluster(
-          Name(std::string(::testing::UnitTest::GetInstance()
-                               ->current_test_info()
-                               ->test_case_name()) +
-               "/" +
-               ::testing::UnitTest::GetInstance()->current_test_info()->name()),
-          initialLocators, initialServers, useIPv6) {}
+Cluster::Cluster(InitialLocators initialLocators, InitialServers initialServers,
+                 UseIpv6 useIpv6)
+    : name_(std::string(::testing::UnitTest::GetInstance()
+                            ->current_test_info()
+                            ->test_suite_name()) +
+            "/" +
+            ::testing::UnitTest::GetInstance()->current_test_info()->name()),
+      initialLocators_(initialLocators.get()),
+      initialServers_(initialServers.get()),
+      jmxManagerPort_(Framework::getAvailablePort()),
+      useIPv6_(useIpv6.get()) {
+  removeServerDirectory();
+}
 
 Cluster::Cluster(LocatorCount initialLocators, ServerCount initialServers)
-    : Cluster(initialLocators, initialServers, UseIpv6(false)) {}
+    : Cluster(
+          InitialLocators{std::vector<LocatorAddress>(initialLocators.get())},
+          InitialServers{std::vector<ServerAddress>(initialServers.get())}) {}
 
 Cluster::Cluster(LocatorCount initialLocators, ServerCount initialServers,
                  CacheXMLFiles cacheXMLFiles)
     : name_(std::string(::testing::UnitTest::GetInstance()
                             ->current_test_info()
-                            ->test_case_name()) +
+                            ->test_suite_name()) +
             "/" +
             ::testing::UnitTest::GetInstance()->current_test_info()->name()),
       initialLocators_(initialLocators.get()),
@@ -296,22 +298,29 @@ Cluster::Cluster(LocatorCount initialLocators, ServerCount initialServers,
   cacheXMLFiles_ = cacheXMLFiles.get();
 }
 
-Cluster::Cluster(Name name, LocatorCount initialLocators,
-                 ServerCount initialServers, UseIpv6 useIPv6)
-    : Cluster(Name(name.get()), Classpath(""), SecurityManager(""), User(""),
-              Password(""), initialLocators, initialServers, CacheXMLFiles({}),
-              useIPv6) {}
+Cluster::Cluster(LocatorCount initialLocators, ServerCount initialServers,
+                 ConserveSockets conserveSockets, CacheXMLFiles cacheXMLFiles)
+    : name_(std::string(::testing::UnitTest::GetInstance()
+                            ->current_test_info()
+                            ->test_suite_name()) +
+            "/" +
+            ::testing::UnitTest::GetInstance()->current_test_info()->name()),
+      initialLocators_(initialLocators.get()),
+      initialServers_(initialServers.get()) {
+  jmxManagerPort_ = Framework::getAvailablePort();
+  cacheXMLFiles_ = cacheXMLFiles.get();
+  conserveSockets_ = conserveSockets.get();
+}
 
 Cluster::Cluster(Name name, LocatorCount initialLocators,
                  ServerCount initialServers)
     : Cluster(Name(name.get()), Classpath(""), SecurityManager(""), User(""),
-              Password(""), initialLocators, initialServers, CacheXMLFiles({}),
-              UseIpv6(false)) {}
+              Password(""), initialLocators, initialServers, CacheXMLFiles()) {}
 
 Cluster::Cluster(Name name, Classpath classpath,
                  SecurityManager securityManager, User user, Password password,
                  LocatorCount initialLocators, ServerCount initialServers,
-                 CacheXMLFiles cacheXMLFiles, UseIpv6 useIPv6)
+                 CacheXMLFiles cacheXMLFiles)
     : name_(name.get()),
       classpath_(classpath.get()),
       securityManager_(securityManager.get()),
@@ -321,7 +330,6 @@ Cluster::Cluster(Name name, Classpath classpath,
       initialServers_(initialServers.get()) {
   jmxManagerPort_ = Framework::getAvailablePort();
   cacheXMLFiles_ = cacheXMLFiles.get();
-  useIPv6_ = useIPv6.get();
 
   removeServerDirectory();
 }
@@ -359,27 +367,28 @@ apache::geode::client::Cache Cluster::createCache() { return createCache({}); }
 
 apache::geode::client::Cache Cluster::createCache(
     const std::unordered_map<std::string, std::string> &properties) {
-  return createCache(properties, false);
+  return createCache(properties, SubscriptionState::Disabled);
 }
 
 apache::geode::client::Cache Cluster::createCache(
     const std::unordered_map<std::string, std::string> &properties,
-    bool subscriptionEnabled) {
+    SubscriptionState state) {
   using apache::geode::client::CacheFactory;
 
   CacheFactory cacheFactory;
 
+  cacheFactory.set("log-level", "none")
+      .set("statistic-sampling-enabled", "false");
+
   for (auto &&property : properties) {
     cacheFactory.set(property.first, property.second);
   }
 
-  auto cache = cacheFactory.set("log-level", "none")
-                   .set("statistic-sampling-enabled", "false")
-                   .create();
+  auto cache = cacheFactory.create();
 
   auto poolFactory =
       cache.getPoolManager().createFactory().setSubscriptionEnabled(
-          subscriptionEnabled);
+          state == SubscriptionState::Enabled);
   applyLocators(poolFactory);
   poolFactory.create("default");
 
@@ -393,6 +402,11 @@ void Cluster::applyLocators(apache::geode::client::PoolFactory &poolFactory) {
   }
 }
 
+void Cluster::applyServer(apache::geode::client::PoolFactory &poolFactory,
+                          ServerAddress oneServer) {
+  poolFactory.addServer(oneServer.address, oneServer.port);
+}
+
 Gfsh &Cluster::getGfsh() { return gfsh_; }
 
 std::vector<Server> &Cluster::getServers() { return servers_; }
@@ -411,35 +425,29 @@ std::vector<std::string> &Cluster::getCacheXMLFiles() { return cacheXMLFiles_; }
 
 bool Cluster::getUseIPv6() { return useIPv6_; }
 
+bool Cluster::getConserveSockets() { return conserveSockets_; }
+
 void Cluster::start() { start(std::function<void()>()); }
 
 void Cluster::start(std::function<void()> extraGfshCommands) {
-  locators_.reserve(initialLocators_);
-  for (size_t i = 0; i < initialLocators_; i++) {
-    uint16_t port;
-    if(locatorsPorts_.empty()){
-      port=Framework::getAvailablePort();
-    }else{
-      port=locatorsPorts_.at(i);
-    }
-
+  locators_.reserve(initialLocators_.size());
+  for (size_t i = 0; i < initialLocators_.size(); i++) {
     locators_.push_back({*this, locators_,
                          name_ + "/locator/" + std::to_string(i),
-                         jmxManagerPort_, getUseIPv6(), port,
-                         remoteLocatorsPorts_, distributedSystemId_});
+                         jmxManagerPort_, initialLocators_[i], remoteLocators_,
+                         distributedSystemId_});
   }
 
-  servers_.reserve(initialServers_);
+  servers_.reserve(initialServers_.size());
   std::string xmlFile;
-  for (size_t i = 0; i < initialServers_; i++) {
-    xmlFile = (cacheXMLFiles_.size() == 0)
-                  ? ""
-                  : cacheXMLFiles_.size() == 1 ? cacheXMLFiles_[0]
-                                               : cacheXMLFiles_[i];
+  for (size_t i = 0; i < initialServers_.size(); i++) {
+    xmlFile = (cacheXMLFiles_.size() == 0) ? ""
+              : cacheXMLFiles_.size() == 1 ? cacheXMLFiles_[0]
+                                           : cacheXMLFiles_[i];
 
     servers_.push_back({*this, locators_,
                         name_ + "/server/" + std::to_string(i), xmlFile,
-                        getUseIPv6()});
+                        initialServers_[i]});
   }
 
   startLocators();
@@ -477,8 +485,12 @@ void Cluster::startServers() {
 void Cluster::startLocators() {
   std::vector<std::future<void>> futures;
 
+  bool startJmxManager = true;
   for (auto &locator : locators_) {
-    futures.push_back(std::async(std::launch::async, [&] { locator.start(); }));
+    futures.push_back(std::async(std::launch::async, [&, startJmxManager] {
+      locator.start(startJmxManager);
+    }));
+    startJmxManager = false;
   }
 
   // TODO hack until there is a way to either tell servers to retry or wait
@@ -524,13 +536,13 @@ void Cluster::usePropertiesFile(const std::string propertiesFile) {
   propertiesFile_ = propertiesFile;
 }
 
-void Cluster::useSecurityPropertiesFile(const std::string securityPropertiesFile) {
+void Cluster::useSecurityPropertiesFile(
+    const std::string securityPropertiesFile) {
   useSecurityPropertiesFile_ = true;
   securityPropertiesFile_ = securityPropertiesFile;
 }
 
-void Cluster::useHostNameForClients(
-    const std::string hostName) {
+void Cluster::useHostNameForClients(const std::string hostName) {
   usePropertiesFile_ = true;
   hostName_ = hostName;
 }
