@@ -37,6 +37,9 @@ class Gfsh {
   class Create;
   Create create();
 
+  class Destroy;
+  Destroy destroy();
+
   class Connect;
   Connect connect();
 
@@ -46,6 +49,12 @@ class Gfsh {
   class Deploy;
   Deploy deploy();
 
+  class Rebalance;
+  Rebalance rebalance();
+
+  class ExecuteFunction;
+  ExecuteFunction executeFunction();
+
   class Verb {
    public:
    protected:
@@ -56,11 +65,14 @@ class Gfsh {
   template <class Result>
   class Command {
    public:
-    virtual Result execute(const std::string &user, const std::string &password, const std::string &keyStorePath,
-                           const std::string &trustStorePath, const std::string &keyStorePassword,
+    virtual Result execute(const std::string &user, const std::string &password,
+                           const std::string &keyStorePath,
+                           const std::string &trustStorePath,
+                           const std::string &keyStorePassword,
                            const std::string &trustStorePassword) {
-      Result{gfsh_}.parse(gfsh_.execute(command_, user, password, keyStorePath, trustStorePath,
-              keyStorePassword, trustStorePassword));
+      Result{gfsh_}.parse(gfsh_.execute(command_, user, password, keyStorePath,
+                                        trustStorePath, keyStorePassword,
+                                        trustStorePassword));
     }
     virtual Result execute() {
       Result{gfsh_}.parse(gfsh_.execute(command_, "", "", "", "", "", ""));
@@ -96,7 +108,8 @@ class Gfsh {
 
       Locator &withPort(const uint16_t &port);
 
-      Locator &withRemoteLocators(const std::vector<uint16_t> &locatorPorts);
+      Locator &withRemoteLocators(
+          const std::vector<std::string> &remoteLocators);
 
       Locator &withDistributedSystemId(const uint16_t &dsId);
 
@@ -112,8 +125,6 @@ class Gfsh {
 
       Locator &withSecurityManager(const std::string securityManager);
 
-      Locator &withConnect(const std::string connect);
-
       Locator &withPreferIPv6(bool useIPv6);
 
       Locator &withSslEnabledComponents(const std::string &components);
@@ -186,6 +197,10 @@ class Gfsh {
       Server &withSecurityPropertiesFile(const std::string file);
 
       Server &withHostNameForClients(const std::string hostName);
+
+      Server &withSystemProperty(const std::string &key,
+                                 const std::string &value);
+      Server &withConserveSockets(bool conserveSockets);
     };
 
    private:
@@ -250,6 +265,8 @@ class Gfsh {
       Region &withBuckets(const std::string &totalNumBuckets);
 
       Region &withGatewaySenderId(const std::string &gatewaySenderId);
+
+      Region &withPartitionResolver(const std::string &partitionResolver);
     };
 
     class GatewaySender : public Command<void> {
@@ -267,6 +284,23 @@ class Gfsh {
     };
   };
 
+  class Destroy : public Verb {
+   public:
+    explicit Destroy(Gfsh &gfsh);
+
+    class Region;
+    Region region();
+
+    class Region : public Command<void> {
+     public:
+      explicit Region(Gfsh &gfsh);
+
+      Region &withName(const std::string &name);
+
+      Region &ifExists();
+    };
+  };
+
   class Connect : public Command<void> {
    public:
     explicit Connect(Gfsh &gfsh);
@@ -302,17 +336,35 @@ class Gfsh {
     Deploy &jar(const std::string &jarFile);
   };
 
+  class Rebalance : public Command<void> {
+   public:
+    explicit Rebalance(Gfsh &gfsh);
+  };
+
+  class ExecuteFunction : public Command<void> {
+   public:
+    explicit ExecuteFunction(Gfsh &gfsh);
+
+    ExecuteFunction &withId(const std::string &functionName);
+    ExecuteFunction &withMember(const std::string &withMember);
+  };
+
  protected:
   virtual void execute(const std::string &command, const std::string &user,
-                       const std::string &password, const std::string &keyStorePath,
-                       const std::string &trustStorePath, const std::string &keyStorePassword,
+                       const std::string &password,
+                       const std::string &keyStorePath,
+                       const std::string &trustStorePath,
+                       const std::string &keyStorePassword,
                        const std::string &trustStorePassword) = 0;
 };
 
 template <>
-void Gfsh::Command<void>::execute(const std::string &user, const std::string &password,
-                                  const std::string &keyStorePath, const std::string &trustStorePath,
-                                  const std::string &keyStorePassword, const std::string &trustStorePassword);
+void Gfsh::Command<void>::execute(const std::string &user,
+                                  const std::string &password,
+                                  const std::string &keyStorePath,
+                                  const std::string &trustStorePath,
+                                  const std::string &keyStorePassword,
+                                  const std::string &trustStorePassword);
 
 template <>
 void Gfsh::Command<void>::execute();
