@@ -22,7 +22,6 @@
 
 #include <algorithm>
 #include <iostream>
-#include <regex>
 #include <string>
 
 #include <geode/Exception.hpp>
@@ -57,6 +56,7 @@ class GfshExecuteException : public apache::geode::client::Exception {
 
 class GfshExecute : public Gfsh {
   std::string connection_;
+  std::string maxHeap_ = "256m";
 
   void execute(const std::string &command, const std::string &user,
                const std::string &password, const std::string &keyStorePath,
@@ -80,6 +80,8 @@ class GfshExecute : public Gfsh {
  public:
   GfshExecute() = default;
   virtual ~GfshExecute() override = default;
+
+  GfshExecute &withMaxHeap(std::string maxHeap);
 };
 
 #endif  // INTEGRATION_TEST_FRAMEWORK_GFSHEXECUTE_H
