@@ -21,11 +21,10 @@
 #include <geode/FunctionService.hpp>
 #include <geode/PoolManager.hpp>
 #include <geode/RegionFactory.hpp>
-#include <geode/internal/geode_globals.hpp>
+#include <geode/SystemProperties.hpp>
 
 #include "CacheImpl.hpp"
 #include "CacheRegionHelper.hpp"
-#include "DistributedSystemImpl.hpp"
 #include "ProxyRegion.hpp"
 #include "UserAttributes.hpp"
 
