@@ -50,10 +50,8 @@ ClientMetadata::ClientMetadata(
         "%zu ",
         totalNumBuckets, fpaSet->size());
     if (!fpaSet->empty()) {
-      int totalFPABuckets = 0;
       for (int i = 0; i < static_cast<int>(fpaSet->size()); i++) {
         std::vector<int> attList;
-        totalFPABuckets += fpaSet->at(i)->getNumBuckets();
         attList.push_back(fpaSet->at(i)->getNumBuckets());
         attList.push_back(fpaSet->at(i)->getStartingBucketID());
         m_fpaMap[fpaSet->at(i)->getPartitionName()] = attList;
@@ -85,7 +83,7 @@ ClientMetadata::ClientMetadata()
     : m_partitionNames(nullptr),
       m_previousOne(nullptr),
       m_totalNumBuckets(0),
-      m_colocatedWith(nullptr),
+      m_colocatedWith(),
       m_tcrdm(nullptr) {}
 
 ClientMetadata::~ClientMetadata() {}
@@ -156,15 +154,14 @@ void ClientMetadata::getServerLocation(
     LOGFINER("returning random & m_bucketServerLocationsList size is: %zu",
              m_bucketServerLocationsList.size());
     RandGen randgen;
-    serverLocation = m_bucketServerLocationsList[bucketId].at(randgen(
-        static_cast<int>(m_bucketServerLocationsList[bucketId].size())));
+    serverLocation = m_bucketServerLocationsList[bucketId].at(
+        randgen(m_bucketServerLocationsList[bucketId].size()));
   }
   // return m_bucketServerLocationsList[bucketId].at(0);
 }
 
 void ClientMetadata::updateBucketServerLocations(
     int bucketId, BucketServerLocationsType bucketServerLocations) {
-  // WriteGuard guard( m_readWriteLock );
   checkBucketId(bucketId);
 
   auto&& serverGroup = m_tcrdm->getServerGroup();
@@ -219,11 +216,11 @@ void ClientMetadata::updateBucketServerLocations(
     RandGen randGen;
 
     if (primaries.size() > 0) {
-      std::random_shuffle(primaries.begin(), primaries.end(), randGen);
+      std::shuffle(primaries.begin(), primaries.end(), randGen);
     }
 
     if (secondaries.size() > 0) {
-      std::random_shuffle(secondaries.begin(), secondaries.end(), randGen);
+      std::shuffle(secondaries.begin(), secondaries.end(), randGen);
     }
 
     m_bucketServerLocationsList[bucketId].clear();
@@ -260,11 +257,11 @@ void ClientMetadata::updateBucketServerLocations(
     RandGen randGen;
 
     if (primaries.size() > 0) {
-      std::random_shuffle(primaries.begin(), primaries.end(), randGen);
+      std::shuffle(primaries.begin(), primaries.end(), randGen);
     }
 
     if (secondaries.size() > 0) {
-      std::random_shuffle(secondaries.begin(), secondaries.end(), randGen);
+      std::shuffle(secondaries.begin(), secondaries.end(), randGen);
     }
 
     m_bucketServerLocationsList[bucketId].clear();
