@@ -24,10 +24,9 @@
 #include <geode/ExceptionTypes.hpp>
 #include <geode/SystemProperties.hpp>
 
+#include "CacheImpl.hpp"
 #include "CqEventImpl.hpp"
 #include "CqQueryImpl.hpp"
-#include "DistributedSystem.hpp"
-#include "ReadWriteLock.hpp"
 #include "TcrConnectionManager.hpp"
 #include "ThinClientPoolDM.hpp"
 #include "util/exception.hpp"
@@ -40,8 +39,10 @@ CqService::CqService(ThinClientBaseDM* tccdm,
                      StatisticsFactory* statisticsFactory)
     : m_tccdm(tccdm),
       m_statisticsFactory(statisticsFactory),
-      m_notificationSema(1),
+      notification_semaphore_{1},
       m_stats(std::make_shared<CqServiceVsdStats>(m_statisticsFactory)) {
+  assert(nullptr != m_tccdm);
+
   m_running = true;
   LOGDEBUG("CqService Started");
 }
@@ -78,9 +79,9 @@ void CqService::updateStats() {
 
 bool CqService::checkAndAcquireLock() {
   if (m_running) {
-    m_notificationSema.acquire();
+    notification_semaphore_.acquire();
     if (m_running == false) {
-      m_notificationSema.release();
+      notification_semaphore_.release();
       return false;
     }
     return true;
@@ -99,7 +100,7 @@ std::shared_ptr<CqQuery> CqService::newCq(
 
   // Check if the subscription is enabled on the pool
   auto pool = dynamic_cast<ThinClientPoolDM*>(m_tccdm);
-  if (pool != nullptr && !pool->getSubscriptionEnabled()) {
+  if (pool && !pool->getSubscriptionEnabled()) {
     LOGERROR(
         "Cannot create CQ because subscription is not enabled on the pool.");
     throw IllegalStateException(
@@ -107,7 +108,7 @@ std::shared_ptr<CqQuery> CqService::newCq(
   }
 
   // check for durable client
-  if (isDurable) {
+  if (isDurable && m_tccdm) {
     auto&& durableID = m_tccdm->getConnectionManager()
                            .getCacheImpl()
                            ->getDistributedSystem()
@@ -174,7 +175,7 @@ std::shared_ptr<CqQuery> CqService::getCq(const std::string& cqName) {
  * Clears the CQ Query Map.
  */
 void CqService::clearCqQueryMap() {
-  Log::fine("Cleaning clearCqQueryMap.");
+  LOGFINE("Cleaning clearCqQueryMap.");
   m_cqQueryMap.clear();
 }
 
@@ -287,21 +288,22 @@ void CqService::stopCqs(query_container_type& cqs) {
         cqName = cq->getName();
         cq->stop();
       } catch (QueryException& qe) {
-        Log::fine(("Failed to stop the CQ, CqName : " + cqName +
-                   " Error : " + qe.what())
-                      .c_str());
+        LOGFINE(("Failed to stop the CQ, CqName : " + cqName +
+                 " Error : " + qe.what())
+                    .c_str());
       } catch (CqClosedException& cce) {
-        Log::fine(("Failed to stop the CQ, CqName : " + cqName +
-                   " Error : " + cce.what())
-                      .c_str());
+        LOGFINE(("Failed to stop the CQ, CqName : " + cqName +
+                 " Error : " + cce.what())
+                    .c_str());
       }
     }
   }
 }
 
 void CqService::closeCqs(query_container_type& cqs) {
-  LOGDEBUG("closeCqs() TcrMessage::isKeepAlive() = %d ",
-           TcrMessage::isKeepAlive());
+  const auto keepAlive =
+      m_tccdm->getConnectionManager().getCacheImpl()->isKeepAlive();
+  LOGDEBUG("closeCqs() keepAlive = %d ", keepAlive);
   if (!cqs.empty()) {
     std::string cqName;
     for (auto& cq : cqs) {
@@ -310,19 +312,19 @@ void CqService::closeCqs(query_container_type& cqs) {
         cqName = cqi->getName();
         LOGDEBUG("closeCqs() cqname = %s isDurable = %d ", cqName.c_str(),
                  cqi->isDurable());
-        if (!(cqi->isDurable() && TcrMessage::isKeepAlive())) {
+        if (!(cqi->isDurable() && keepAlive)) {
           cqi->close(true);
         } else {
           cqi->close(false);
         }
       } catch (QueryException& qe) {
-        Log::fine(("Failed to close the CQ, CqName : " + cqName +
-                   " Error : " + qe.what())
-                      .c_str());
+        LOGFINE(("Failed to close the CQ, CqName : " + cqName +
+                 " Error : " + qe.what())
+                    .c_str());
       } catch (CqClosedException& cce) {
-        Log::fine(("Failed to close the CQ, CqName : " + cqName +
-                   " Error : " + cce.what())
-                      .c_str());
+        LOGFINE(("Failed to close the CQ, CqName : " + cqName +
+                 " Error : " + cce.what())
+                    .c_str());
       }
     }
   }
@@ -343,17 +345,17 @@ std::shared_ptr<CqServiceStatistics> CqService::getCqServiceStatistics() {
 void CqService::closeCqService() {
   if (m_running) {
     m_running = false;
-    m_notificationSema.acquire();
+    notification_semaphore_.acquire();
     cleanup();
-    m_notificationSema.release();
+    notification_semaphore_.release();
   }
 }
 void CqService::closeAllCqs() {
-  Log::fine("closeAllCqs()");
+  LOGFINE("closeAllCqs()");
   query_container_type cqVec = getAllCqs();
-  Log::fine("closeAllCqs() 1");
+  LOGFINE("closeAllCqs() 1");
   auto&& lock = m_cqQueryMap.make_lock();
-  Log::fine("closeAllCqs() 2");
+  LOGFINE("closeAllCqs() 2");
   closeCqs(cqVec);
 }
 
@@ -361,7 +363,7 @@ void CqService::closeAllCqs() {
  * Cleans up the CqService.
  */
 void CqService::cleanup() {
-  Log::fine("Cleaning up CqService.");
+  LOGFINE("Cleaning up CqService.");
 
   // Close All the CQs.
   // Need to take care when Clients are still connected...
@@ -381,11 +383,10 @@ bool CqService::isCqExists(const std::string& cqName) {
 
   return m_cqQueryMap.find(cqName) != m_cqQueryMap.end();
 }
-void CqService::receiveNotification(TcrMessage* msg) {
-  invokeCqListeners(msg->getCqs(), msg->getMessageTypeForCq(), msg->getKey(),
-                    msg->getValue(), msg->getDeltaBytes(), msg->getEventId());
-  _GEODE_SAFE_DELETE(msg);
-  m_notificationSema.release();
+void CqService::receiveNotification(TcrMessage& msg) {
+  invokeCqListeners(msg.getCqs(), msg.getMessageTypeForCq(), msg.getKey(),
+                    msg.getValue(), msg.getDeltaBytes(), msg.getEventId());
+  notification_semaphore_.release();
 }
 
 /**
