@@ -17,6 +17,8 @@
 
 #include "DistributedSystemImpl.hpp"
 
+#include "Utils.hpp"
+
 #if defined(HAVE_PTHREAD_H)
 #include <pthread.h>
 #elif defined(_WIN32)
@@ -79,11 +81,8 @@ void DistributedSystemImpl::logSystemInformation() const {
   LOGCONFIG("Source revision: %s", PRODUCT_SOURCE_REVISION);
   LOGCONFIG("Source repository: %s", PRODUCT_SOURCE_REPOSITORY);
 
-  ACE_utsname u;
-  ACE_OS::uname(&u);
-  LOGCONFIG(
-      "Running on: SystemName=%s Machine=%s Host=%s Release=%s Version=%s",
-      u.sysname, u.machine, u.nodename, u.release, u.version);
+  auto sysinfo = Utils::getSystemInfo();
+  LOGCONFIG("Running on: %s", sysinfo.c_str());
   LOGCONFIG("Current directory: %s",
             boost::filesystem::current_path().string().c_str());
   LOGCONFIG("Current value of PATH: %s", Utils::getEnv("PATH").c_str());
@@ -144,43 +143,6 @@ void DistributedSystemImpl::unregisterCliCallback(int appdomainId) {
   }
 }
 
-void DistributedSystemImpl::setThreadName(const std::string& threadName) {
-  if (threadName.empty()) {
-    throw IllegalArgumentException("Thread name is empty.");
-  }
-
-#if defined(HAVE_pthread_setname_np)
-
-  pthread_setname_np(threadName.c_str());
-
-#elif defined(_WIN32)
-
-  const DWORD MS_VC_EXCEPTION = 0x406D1388;
-
-#pragma pack(push, 8)
-  typedef struct tagTHREADNAME_INFO {
-    DWORD dwType;      // Must be 0x1000.
-    LPCSTR szName;     // Pointer to name (in user addr space).
-    DWORD dwThreadID;  // Thread ID (-1=caller thread).
-    DWORD dwFlags;     // Reserved for future use, must be zero.
-  } THREADNAME_INFO;
-#pragma pack(pop)
-
-  THREADNAME_INFO info;
-  info.dwType = 0x1000;
-  info.szName = threadName.c_str();
-  info.dwThreadID = -1;
-  info.dwFlags = 0;
-
-  __try {
-    RaiseException(MS_VC_EXCEPTION, 0, sizeof(info) / sizeof(ULONG_PTR),
-                   (ULONG_PTR*)&info);
-  } __except (EXCEPTION_EXECUTE_HANDLER) {
-  }
-
-#endif
-}
-
 }  // namespace client
 }  // namespace geode
 }  // namespace apache
