@@ -23,6 +23,7 @@
 #include <geode/ExceptionTypes.hpp>
 #include <geode/internal/geode_globals.hpp>
 
+#include "CacheImpl.hpp"
 #include "NoResult.hpp"
 #include "TcrConnectionManager.hpp"
 #include "ThinClientPoolDM.hpp"
@@ -196,6 +197,8 @@ std::shared_ptr<ResultCollector> ExecutionImpl::execute(
                   func, m_args, m_routingObj, isHAHasResultOptimizeForWrite,
                   m_rc, (isHAHasResultOptimizeForWrite & 1) ? retryAttempts : 0,
                   timeout);
+          dynamic_cast<ThinClientRegion*>(m_region.get())
+              ->setMetaDataRefreshed(false);
           cms->enqueueForMetadataRefresh(m_region->getFullPath(), 0);
         } else {
           // convert server to bucket map to server to key map where bucket id
@@ -230,14 +233,6 @@ std::shared_ptr<ResultCollector> ExecutionImpl::execute(
                                               ? retryAttempts
                                               : 0,
                                           failedNodes, timeout);
-            } else {  // isHA = false
-              m_rc->clearResults();
-              dynamic_cast<ThinClientRegion*>(m_region.get())
-                  ->executeFunction(
-                      func, m_args, m_routingObj, isHAHasResultOptimizeForWrite,
-                      m_rc,
-                      (isHAHasResultOptimizeForWrite & 1) ? retryAttempts : 0,
-                      timeout);
             }
           }
         }
@@ -285,14 +280,6 @@ std::shared_ptr<ResultCollector> ExecutionImpl::execute(
                                                 ? retryAttempts
                                                 : 0,
                                             failedNodes, timeout);
-              } else {  // isHA = false
-                m_rc->clearResults();
-                dynamic_cast<ThinClientRegion*>(m_region.get())
-                    ->executeFunction(
-                        func, m_args, m_routingObj,
-                        isHAHasResultOptimizeForWrite, m_rc,
-                        (isHAHasResultOptimizeForWrite & 1) ? retryAttempts : 0,
-                        timeout);
               }
             }
           }
