@@ -45,94 +45,98 @@ std::shared_ptr<PdxInstance> PdxInstanceFactory::create() {
     throw IllegalStateException(
         "The PdxInstanceFactory.Create() method can only be called once.");
   }
-  auto pi = std::make_shared<PdxInstanceImpl>(
-      m_FieldVsValues, m_pdxType, m_cachePerfStats, m_pdxTypeRegistry,
-      m_cacheImpl, m_enableTimeStatistics);
+
   m_created = true;
-
-  // Forces registration of PdxType
-  auto dataOutput = m_cacheImpl.createDataOutput();
-  PdxHelper::serializePdx(dataOutput, pi);
-
-  return std::move(pi);
+  return std::make_shared<PdxInstanceImpl>(m_FieldVsValues, m_pdxType,
+                                           m_cachePerfStats, m_pdxTypeRegistry,
+                                           m_cacheImpl, m_enableTimeStatistics);
 }
+
 PdxInstanceFactory& PdxInstanceFactory::writeChar(const std::string& fieldName,
                                                   char16_t value) {
   isFieldAdded(fieldName);
   m_pdxType->addFixedLengthTypeField(fieldName, "char", PdxFieldTypes::CHAR,
-                                     PdxTypes::CHAR_SIZE);
+                                     PdxTypes::kPdxCharSize);
   auto cacheableObject = CacheableCharacter::create(value);
   m_FieldVsValues.emplace(fieldName, cacheableObject);
   return *this;
 }
+
 PdxInstanceFactory& PdxInstanceFactory::writeChar(const std::string& fieldName,
                                                   char value) {
   isFieldAdded(fieldName);
   m_pdxType->addFixedLengthTypeField(fieldName, "char", PdxFieldTypes::CHAR,
-                                     PdxTypes::CHAR_SIZE);
+                                     PdxTypes::kPdxCharSize);
   auto cacheableObject = CacheableCharacter::create(value);
   m_FieldVsValues.emplace(fieldName, cacheableObject);
   return *this;
 }
+
 PdxInstanceFactory& PdxInstanceFactory::writeBoolean(
     const std::string& fieldName, bool value) {
   isFieldAdded(fieldName);
   m_pdxType->addFixedLengthTypeField(fieldName, "bool", PdxFieldTypes::BOOLEAN,
-                                     PdxTypes::BOOLEAN_SIZE);
+                                     PdxTypes::kPdxBooleanSize);
   auto cacheableObject = CacheableBoolean::create(value);
   m_FieldVsValues.emplace(fieldName, cacheableObject);
   return *this;
 }
+
 PdxInstanceFactory& PdxInstanceFactory::writeByte(const std::string& fieldName,
                                                   int8_t value) {
   isFieldAdded(fieldName);
   m_pdxType->addFixedLengthTypeField(fieldName, "byte", PdxFieldTypes::BYTE,
-                                     PdxTypes::BYTE_SIZE);
+                                     PdxTypes::kPdxByteSize);
   auto cacheableObject = CacheableByte::create(value);
   m_FieldVsValues.emplace(fieldName, cacheableObject);
   return *this;
 }
+
 PdxInstanceFactory& PdxInstanceFactory::writeShort(const std::string& fieldName,
                                                    int16_t value) {
   isFieldAdded(fieldName);
   m_pdxType->addFixedLengthTypeField(fieldName, "short", PdxFieldTypes::SHORT,
-                                     PdxTypes::SHORT_SIZE);
+                                     PdxTypes::kPdxShortSize);
   auto cacheableObject = CacheableInt16::create(value);
   m_FieldVsValues.emplace(fieldName, cacheableObject);
   return *this;
 }
+
 PdxInstanceFactory& PdxInstanceFactory::writeInt(const std::string& fieldName,
                                                  int32_t value) {
   isFieldAdded(fieldName);
   m_pdxType->addFixedLengthTypeField(fieldName, "int", PdxFieldTypes::INT,
-                                     PdxTypes::INTEGER_SIZE);
+                                     PdxTypes::kPdxIntegerSize);
   auto cacheableObject = CacheableInt32::create(value);
   m_FieldVsValues.emplace(fieldName, cacheableObject);
   return *this;
 }
+
 PdxInstanceFactory& PdxInstanceFactory::writeLong(const std::string& fieldName,
                                                   int64_t value) {
   isFieldAdded(fieldName);
   m_pdxType->addFixedLengthTypeField(fieldName, "long", PdxFieldTypes::LONG,
-                                     PdxTypes::LONG_SIZE);
+                                     PdxTypes::kPdxLongSize);
   auto cacheableObject = CacheableInt64::create(value);
   m_FieldVsValues.emplace(fieldName, cacheableObject);
   return *this;
 }
+
 PdxInstanceFactory& PdxInstanceFactory::writeFloat(const std::string& fieldName,
                                                    float value) {
   isFieldAdded(fieldName);
   m_pdxType->addFixedLengthTypeField(fieldName, "float", PdxFieldTypes::FLOAT,
-                                     PdxTypes::FLOAT_SIZE);
+                                     PdxTypes::kPdxFloatSize);
   auto cacheableObject = CacheableFloat::create(value);
   m_FieldVsValues.emplace(fieldName, cacheableObject);
   return *this;
 }
+
 PdxInstanceFactory& PdxInstanceFactory::writeDouble(
     const std::string& fieldName, double value) {
   isFieldAdded(fieldName);
   m_pdxType->addFixedLengthTypeField(fieldName, "double", PdxFieldTypes::DOUBLE,
-                                     PdxTypes::DOUBLE_SIZE);
+                                     PdxTypes::kPdxDoubleSize);
   auto cacheableObject = CacheableDouble::create(value);
   m_FieldVsValues.emplace(fieldName, cacheableObject);
   return *this;
@@ -166,6 +170,7 @@ PdxInstanceFactory& PdxInstanceFactory::writeObject(
   m_FieldVsValues.emplace(fieldName, value);
   return *this;
 }
+
 PdxInstanceFactory& PdxInstanceFactory::writeObjectArray(
     const std::string& fieldName, std::shared_ptr<CacheableObjectArray> value) {
   isFieldAdded(fieldName);
@@ -174,6 +179,7 @@ PdxInstanceFactory& PdxInstanceFactory::writeObjectArray(
   m_FieldVsValues.emplace(fieldName, value);
   return *this;
 }
+
 PdxInstanceFactory& PdxInstanceFactory::writeBooleanArray(
     const std::string& fieldName, const std::vector<bool>& value) {
   isFieldAdded(fieldName);
@@ -203,6 +209,7 @@ PdxInstanceFactory& PdxInstanceFactory::writeByteArray(
   m_FieldVsValues.emplace(fieldName, cacheableObject);
   return *this;
 }
+
 PdxInstanceFactory& PdxInstanceFactory::writeShortArray(
     const std::string& fieldName, const std::vector<int16_t>& value) {
   isFieldAdded(fieldName);
@@ -212,6 +219,7 @@ PdxInstanceFactory& PdxInstanceFactory::writeShortArray(
   m_FieldVsValues.emplace(fieldName, cacheableObject);
   return *this;
 }
+
 PdxInstanceFactory& PdxInstanceFactory::writeIntArray(
     const std::string& fieldName, const std::vector<int32_t>& value) {
   isFieldAdded(fieldName);
@@ -221,6 +229,7 @@ PdxInstanceFactory& PdxInstanceFactory::writeIntArray(
   m_FieldVsValues.emplace(fieldName, cacheableObject);
   return *this;
 }
+
 PdxInstanceFactory& PdxInstanceFactory::writeLongArray(
     const std::string& fieldName, const std::vector<int64_t>& value) {
   isFieldAdded(fieldName);
@@ -230,6 +239,7 @@ PdxInstanceFactory& PdxInstanceFactory::writeLongArray(
   m_FieldVsValues.emplace(fieldName, cacheableObject);
   return *this;
 }
+
 PdxInstanceFactory& PdxInstanceFactory::writeFloatArray(
     const std::string& fieldName, const std::vector<float>& value) {
   isFieldAdded(fieldName);
@@ -239,6 +249,7 @@ PdxInstanceFactory& PdxInstanceFactory::writeFloatArray(
   m_FieldVsValues.emplace(fieldName, cacheableObject);
   return *this;
 }
+
 PdxInstanceFactory& PdxInstanceFactory::writeDoubleArray(
     const std::string& fieldName, const std::vector<double>& value) {
   isFieldAdded(fieldName);
@@ -270,7 +281,7 @@ PdxInstanceFactory& PdxInstanceFactory::writeDate(
     const std::string& fieldName, std::shared_ptr<CacheableDate> value) {
   isFieldAdded(fieldName);
   m_pdxType->addFixedLengthTypeField(fieldName, "Date", PdxFieldTypes::DATE,
-                                     PdxTypes::DATE_SIZE /*+ 1*/);
+                                     PdxTypes::kPdxDateSize /*+ 1*/);
   m_FieldVsValues.emplace(fieldName, value);
   return *this;
 }
@@ -290,6 +301,7 @@ PdxInstanceFactory& PdxInstanceFactory::writeArrayOfByteArrays(
   m_FieldVsValues.emplace(fieldName, cacheableObject);
   return *this;
 }
+
 PdxInstanceFactory& PdxInstanceFactory::markIdentityField(
     const std::string& fieldName) {
   auto pfType = m_pdxType->getPdxField(fieldName);
