@@ -17,10 +17,14 @@
 
 #include "PdxTypeRegistry.hpp"
 
+#include <boost/thread/lock_types.hpp>
+
 #include <geode/PoolManager.hpp>
 
 #include "CacheImpl.hpp"
 #include "CacheRegionHelper.hpp"
+#include "PreservedDataExpiryTask.hpp"
+#include "SerializationRegistry.hpp"
 #include "ThinClientPoolDM.hpp"
 
 namespace apache {
@@ -39,7 +43,7 @@ PdxTypeRegistry::PdxTypeRegistry(CacheImpl* cache)
 PdxTypeRegistry::~PdxTypeRegistry() {}
 
 size_t PdxTypeRegistry::testNumberOfPreservedData() const {
-  return preserveData_.size();
+  return preserved_data_.size();
 }
 
 int32_t PdxTypeRegistry::getPDXIdForType(const std::string& type, Pool* pool,
@@ -66,7 +70,7 @@ int32_t PdxTypeRegistry::getPDXIdForType(std::shared_ptr<PdxType> nType,
                                          Pool* pool) {
   int32_t typeId = 0;
   {
-    ReadGuard read(g_readerWriterLock_);
+    boost::shared_lock<decltype(types_mutex_)> guard{types_mutex_};
     auto&& iter = pdxTypeToTypeIdMap_.find(nType);
     if (iter != pdxTypeToTypeIdMap_.end()) {
       typeId = iter->second;
@@ -77,7 +81,7 @@ int32_t PdxTypeRegistry::getPDXIdForType(std::shared_ptr<PdxType> nType,
   }
 
   {
-    WriteGuard write(g_readerWriterLock_);
+    boost::unique_lock<decltype(types_mutex_)> guard{types_mutex_};
     auto&& iter = pdxTypeToTypeIdMap_.find(nType);
     if (iter != pdxTypeToTypeIdMap_.end()) {
       typeId = iter->second;
@@ -96,7 +100,7 @@ int32_t PdxTypeRegistry::getPDXIdForType(std::shared_ptr<PdxType> nType,
 
 void PdxTypeRegistry::clear() {
   {
-    WriteGuard guard(g_readerWriterLock_);
+    boost::unique_lock<decltype(types_mutex_)> guard{types_mutex_};
     typeIdToPdxType_.clear();
 
     remoteTypeIdToMergedPdxType_.clear();
@@ -110,19 +114,20 @@ void PdxTypeRegistry::clear() {
     pdxTypeToTypeIdMap_.clear();
   }
   {
-    WriteGuard guard(getPreservedDataLock());
-    preserveData_.clear();
+    boost::unique_lock<decltype(preserved_data_mutex_)> guard{
+        preserved_data_mutex_};
+    preserved_data_.clear();
   }
 }
 
 void PdxTypeRegistry::addPdxType(int32_t typeId,
                                  std::shared_ptr<PdxType> pdxType) {
-  WriteGuard guard(g_readerWriterLock_);
+  boost::unique_lock<decltype(types_mutex_)> guard{types_mutex_};
   typeIdToPdxType_.emplace(typeId, pdxType);
 }
 
 std::shared_ptr<PdxType> PdxTypeRegistry::getPdxType(int32_t typeId) const {
-  ReadGuard guard(g_readerWriterLock_);
+  boost::shared_lock<decltype(types_mutex_)> guard{types_mutex_};
   auto&& iter = typeIdToPdxType_.find(typeId);
   if (iter != typeIdToPdxType_.end()) {
     return iter->second;
@@ -132,13 +137,13 @@ std::shared_ptr<PdxType> PdxTypeRegistry::getPdxType(int32_t typeId) const {
 
 void PdxTypeRegistry::addLocalPdxType(const std::string& localType,
                                       std::shared_ptr<PdxType> pdxType) {
-  WriteGuard guard(g_readerWriterLock_);
+  boost::unique_lock<decltype(types_mutex_)> guard{types_mutex_};
   localTypeToPdxType_.emplace(localType, pdxType);
 }
 
 std::shared_ptr<PdxType> PdxTypeRegistry::getLocalPdxType(
     const std::string& localType) const {
-  ReadGuard guard(g_readerWriterLock_);
+  boost::shared_lock<decltype(types_mutex_)> guard{types_mutex_};
   auto&& it = localTypeToPdxType_.find(localType);
   if (it != localTypeToPdxType_.end()) {
     return it->second;
@@ -148,7 +153,7 @@ std::shared_ptr<PdxType> PdxTypeRegistry::getLocalPdxType(
 
 void PdxTypeRegistry::setMergedType(int32_t remoteTypeId,
                                     std::shared_ptr<PdxType> mergedType) {
-  WriteGuard guard(g_readerWriterLock_);
+  boost::unique_lock<decltype(types_mutex_)> guard{types_mutex_};
   remoteTypeIdToMergedPdxType_.emplace(remoteTypeId, mergedType);
 }
 
@@ -163,39 +168,42 @@ std::shared_ptr<PdxType> PdxTypeRegistry::getMergedType(
 
 void PdxTypeRegistry::setPreserveData(
     std::shared_ptr<PdxSerializable> obj,
-    std::shared_ptr<PdxRemotePreservedData> pData,
+    std::shared_ptr<PdxRemotePreservedData> data,
     ExpiryTaskManager& expiryTaskManager) {
-  WriteGuard guard(getPreservedDataLock());
-  pData->setOwner(obj);
-  if (preserveData_.find(obj) != preserveData_.end()) {
-    // reset expiry task
-    // TODO: check value for nullptr
-    auto expTaskId = preserveData_[obj]->getPreservedDataExpiryTaskId();
-    expiryTaskManager.resetTask(expTaskId, 5);
-    LOGDEBUG("PdxTypeRegistry::setPreserveData Reset expiry task Done");
-    pData->setPreservedDataExpiryTaskId(expTaskId);
-    preserveData_[obj] = pData;
+  boost::unique_lock<decltype(preserved_data_mutex_)> guard{
+      preserved_data_mutex_};
+  data->setOwner(obj);
+
+  auto&& iter = preserved_data_.find(obj);
+  if (iter != preserved_data_.end()) {
+    auto expires_at =
+        std::chrono::steady_clock::now() + std::chrono::seconds(5);
+    data->task_id(iter->second->task_id());
+    data->expires_at(expires_at);
+    iter->second = data;
   } else {
-    // schedule new expiry task
-    auto handler = new PreservedDataExpiryHandler(shared_from_this(), obj);
-    auto id = expiryTaskManager.scheduleExpiryTask(
-        handler, std::chrono::seconds(20), std::chrono::seconds::zero(), false);
-    pData->setPreservedDataExpiryTaskId(id);
+    auto task = std::make_shared<PreservedDataExpiryTask>(
+        expiryTaskManager, shared_from_this(), obj);
+    auto id =
+        expiryTaskManager.schedule(std::move(task), std::chrono::seconds(20));
+    data->task_id(id);
+
     LOGDEBUG(
-        "PdxTypeRegistry::setPreserveData Schedule new expirt task with id=%ld",
+        "PdxTypeRegistry::setPreserveData Schedule new expiry task with id=%zu",
         id);
-    preserveData_.emplace(obj, pData);
+    preserved_data_.emplace_hint(iter, std::move(obj), std::move(data));
   }
 
   LOGDEBUG(
       "PdxTypeRegistry::setPreserveData Successfully inserted new entry in "
       "preservedData");
 }
+
 std::shared_ptr<PdxRemotePreservedData> PdxTypeRegistry::getPreserveData(
     std::shared_ptr<PdxSerializable> pdxobj) const {
-  ReadGuard guard(getPreservedDataLock());
-  const auto& iter = preserveData_.find((pdxobj));
-  if (iter != preserveData_.end()) {
+  boost::shared_lock<decltype(types_mutex_)> guard{types_mutex_};
+  const auto& iter = preserved_data_.find((pdxobj));
+  if (iter != preserved_data_.end()) {
     return iter->second;
   }
   return nullptr;
@@ -211,7 +219,7 @@ int32_t PdxTypeRegistry::getEnumValue(std::shared_ptr<EnumInfo> ei) {
     return val->value();
   }
 
-  WriteGuard guard(g_readerWriterLock_);
+  boost::unique_lock<decltype(types_mutex_)> guard{types_mutex_};
   tmp = enumToInt_;
   const auto& entry2 = tmp->find(ei);
   if (entry2 != tmp->end()) {
@@ -244,7 +252,7 @@ std::shared_ptr<EnumInfo> PdxTypeRegistry::getEnum(int32_t enumVal) {
     }
   }
 
-  WriteGuard guard(g_readerWriterLock_);
+  boost::unique_lock<decltype(types_mutex_)> guard{types_mutex_};
   tmp = intToEnum_;
   {
     auto&& entry = tmp->find(enumValPtr);
