@@ -17,8 +17,7 @@
 
 #include "SerializationRegistry.hpp"
 
-#include <functional>
-#include <mutex>
+#include <limits>
 
 #include <geode/CacheableBuiltins.hpp>
 #include <geode/CacheableDate.hpp>
@@ -47,6 +46,7 @@
 #include "GetAllServersResponse.hpp"
 #include "LocatorListResponse.hpp"
 #include "PdxHelper.hpp"
+#include "PdxInstanceImpl.hpp"
 #include "QueueConnectionResponse.hpp"
 #include "ThinClientPoolDM.hpp"
 
@@ -140,6 +140,148 @@ void TheTypeMap::setup() {
   bindDataSerializableFixedId(GatewaySenderEventCallbackArgument::create);
 }
 
+void SerializationRegistry::serialize(const std::shared_ptr<Serializable>& obj,
+                                      DataOutput& output, bool isDelta) const {
+  if (obj == nullptr) {
+    output.write(static_cast<int8_t>(DSCode::NullObj));
+  } else if (auto&& pdxSerializable =
+                 std::dynamic_pointer_cast<PdxSerializable>(obj)) {
+    serialize(pdxSerializable, output);
+  } else if (const auto&& dataSerializableFixedId =
+                 std::dynamic_pointer_cast<DataSerializableFixedId>(obj)) {
+    serialize(dataSerializableFixedId, output);
+  } else if (const auto&& dataSerializablePrimitive =
+                 std::dynamic_pointer_cast<DataSerializablePrimitive>(obj)) {
+    serialize(dataSerializablePrimitive, output);
+  } else if (const auto&& dataSerializable =
+                 std::dynamic_pointer_cast<DataSerializable>(obj)) {
+    dataSerializableHandler_->serialize(dataSerializable, output, isDelta);
+  } else if (const auto&& dataSerializableInternal =
+                 std::dynamic_pointer_cast<DataSerializableInternal>(obj)) {
+    serialize(dataSerializableInternal, output);
+  } else {
+    throw UnsupportedOperationException(
+        "SerializationRegistry::serialize: Serialization type not "
+        "implemented.");
+  }
+}
+
+void SerializationRegistry::setPdxTypeHandler(PdxTypeHandler* handler) {
+  pdxTypeHandler_ = std::unique_ptr<PdxTypeHandler>(handler);
+}
+void SerializationRegistry::setDataSerializableHandler(
+    DataSerializableHandler* handler) {
+  dataSerializableHandler_ = std::unique_ptr<DataSerializableHandler>(handler);
+}
+
+TypeFactoryMethod SerializationRegistry::getDataSerializableCreationMethod(
+    int32_t objectId) {
+  TypeFactoryMethod createType;
+  theTypeMap_.findDataSerializable(objectId, createType);
+  return createType;
+}
+
+int32_t SerializationRegistry::getIdForDataSerializableType(
+    std::type_index objectType) const {
+  auto&& typeIterator = theTypeMap_.typeToClassId_.find(objectType);
+  return typeIterator->second;
+}
+
+DSCode SerializationRegistry::getSerializableDataDsCode(int32_t classId) {
+  if (classId <= std::numeric_limits<int8_t>::max() &&
+      classId >= std::numeric_limits<int8_t>::min()) {
+    return DSCode::CacheableUserData;
+  } else if (classId <= std::numeric_limits<int16_t>::max() &&
+             classId >= std::numeric_limits<int16_t>::min()) {
+    return DSCode::CacheableUserData2;
+  } else {
+    return DSCode::CacheableUserData4;
+  }
+}
+
+void SerializationRegistry::serializeWithoutHeader(
+    const std::shared_ptr<Serializable>& obj, DataOutput& output) const {
+  if (const auto&& pdxSerializable =
+          std::dynamic_pointer_cast<PdxSerializable>(obj)) {
+    serializeWithoutHeader(pdxSerializable, output);
+  } else if (const auto&& dataSerializableFixedId =
+                 std::dynamic_pointer_cast<DataSerializableFixedId>(obj)) {
+    serializeWithoutHeader(dataSerializableFixedId, output);
+  } else if (const auto&& dataSerializablePrimitive =
+                 std::dynamic_pointer_cast<DataSerializablePrimitive>(obj)) {
+    serializeWithoutHeader(dataSerializablePrimitive, output);
+  } else if (const auto&& dataSerializable =
+                 std::dynamic_pointer_cast<DataSerializable>(obj)) {
+    serializeWithoutHeader(dataSerializable, output);
+  } else if (const auto&& dataSerializableInternal =
+                 std::dynamic_pointer_cast<DataSerializableInternal>(obj)) {
+    serializeWithoutHeader(dataSerializableInternal, output);
+  } else {
+    throw UnsupportedOperationException(
+        "SerializationRegistry::serializeWithoutHeader: Serialization type "
+        "not implemented.");
+  }
+}
+
+void SerializationRegistry::serialize(
+    const std::shared_ptr<DataSerializableFixedId>& obj,
+    DataOutput& output) const {
+  auto id = static_cast<int32_t>(obj->getDSFID());
+  if (id <= std::numeric_limits<int8_t>::max() &&
+      id >= std::numeric_limits<int8_t>::min()) {
+    output.write(static_cast<int8_t>(DSCode::FixedIDByte));
+    output.write(static_cast<int8_t>(id));
+  } else if (id <= std::numeric_limits<int16_t>::max() &&
+             id >= std::numeric_limits<int16_t>::min()) {
+    output.write(static_cast<int8_t>(DSCode::FixedIDShort));
+    output.writeInt(static_cast<int16_t>(id));
+  } else {
+    output.write(static_cast<int8_t>(DSCode::FixedIDInt));
+    output.writeInt(static_cast<int32_t>(id));
+  }
+
+  serializeWithoutHeader(obj, output);
+}
+
+void SerializationRegistry::serializeWithoutHeader(
+    const std::shared_ptr<DataSerializableFixedId>& obj,
+    DataOutput& output) const {
+  obj->toData(output);
+}
+
+void SerializationRegistry::serialize(
+    const std::shared_ptr<DataSerializablePrimitive>& obj,
+    DataOutput& output) const {
+  auto id = obj->getDsCode();
+  output.write(static_cast<int8_t>(id));
+
+  serializeWithoutHeader(obj, output);
+}
+
+void SerializationRegistry::serializeWithoutHeader(
+    const std::shared_ptr<DataSerializablePrimitive>& obj,
+    DataOutput& output) const {
+  obj->toData(output);
+}
+
+void SerializationRegistry::serialize(
+    const std::shared_ptr<PdxSerializable>& obj, DataOutput& output) const {
+  output.write(static_cast<int8_t>(DSCode::PDX));
+  serializeWithoutHeader(obj, output);
+}
+
+void SerializationRegistry::serialize(
+    const std::shared_ptr<DataSerializableInternal>& obj,
+    DataOutput& output) const {
+  serializeWithoutHeader(obj, output);
+}
+
+void SerializationRegistry::serializeWithoutHeader(
+    const std::shared_ptr<DataSerializableInternal>& obj,
+    DataOutput& output) const {
+  obj->toData(output);
+}
+
 /** This starts at reading the typeid.. assumes the length has been read. */
 std::shared_ptr<Serializable> SerializationRegistry::deserialize(
     DataInput& input, int8_t typeId) const {
@@ -161,7 +303,7 @@ std::shared_ptr<Serializable> SerializationRegistry::deserialize(
     case DSCode::PDX: {
       return pdxTypeHandler_->deserialize(input);
     }
-    case DSCode::CacheableEnum: {
+    case DSCode::PDX_ENUM: {
       auto enumObject = CacheableEnum::create(" ", " ", 0);
       enumObject->fromData(input);
       return std::move(enumObject);
@@ -220,7 +362,6 @@ std::shared_ptr<Serializable> SerializationRegistry::deserialize(
     case DSCode::CacheableASCIIString:
     case DSCode::CacheableASCIIStringHuge:
     case DSCode::CacheableStringHuge:
-    case DSCode::InternalDistributedMember:
       break;
   }
 
@@ -299,12 +440,11 @@ SerializationRegistry::deserializeDataSerializableFixedId(DataInput& input,
     case DSCode::CacheableASCIIString:
     case DSCode::CacheableASCIIStringHuge:
     case DSCode::CacheableStringHuge:
-    case DSCode::InternalDistributedMember:
-    case DSCode::CacheableEnum:
-    case DSCode::ClientProxyMembershipId:
     case DSCode::CacheableUserData:
+    case DSCode::CacheableUserData2:
     case DSCode::CacheableUserData4:
     case DSCode::PDX:
+    case DSCode::PDX_ENUM:
       throw IllegalStateException("Invalid fixed ID");
   }
 
@@ -414,7 +554,12 @@ int32_t SerializationRegistry::GetPDXIdForType(
 std::shared_ptr<Serializable> SerializationRegistry::GetPDXTypeById(
     Pool* pool, int32_t typeId) const {
   if (auto poolDM = dynamic_cast<ThinClientPoolDM*>(pool)) {
-    return poolDM->GetPDXTypeById(typeId);
+    auto result = poolDM->GetPDXTypeById(typeId);
+    if (result == nullptr) {
+      throw IllegalStateException("Unknown pdx type=" + std::to_string(typeId));
+    }
+
+    return result;
   }
 
   throw IllegalStateException("Pool not found, Pdx operation failed");
@@ -428,6 +573,7 @@ int32_t SerializationRegistry::GetEnumValue(
 
   return static_cast<ThinClientPoolDM*>(pool.get())->GetEnumValue(enumInfo);
 }
+
 std::shared_ptr<Serializable> SerializationRegistry::GetEnum(
     std::shared_ptr<Pool> pool, int32_t val) const {
   if (pool == nullptr) {
@@ -592,14 +738,20 @@ void TheTypeMap::unbindPdxSerializable(const std::string& objFullName) {
 }
 
 void PdxTypeHandler::serialize(
-    const std::shared_ptr<PdxSerializable>& pdxSerializable,
+    const std::shared_ptr<PdxSerializable>& serializable,
     DataOutput& dataOutput) const {
-  PdxHelper::serializePdx(dataOutput, pdxSerializable);
+  auto instance = std::dynamic_pointer_cast<PdxInstanceImpl>(serializable);
+
+  if (instance != nullptr) {
+    PdxHelper::serializePdx(dataOutput, instance.get());
+  } else {
+    PdxHelper::serializePdx(dataOutput, serializable);
+  }
 }
 
 std::shared_ptr<PdxSerializable> PdxTypeHandler::deserialize(
     DataInput& dataInput) const {
-  return PdxHelper::deserializePdx(dataInput, false);
+  return PdxHelper::deserializePdx(dataInput);
 }
 
 void DataSerializableHandler::serialize(
@@ -669,8 +821,7 @@ void DataSerializableHandler::serialize(
     case DSCode::CacheableASCIIString:
     case DSCode::CacheableASCIIStringHuge:
     case DSCode::CacheableStringHuge:
-    case DSCode::InternalDistributedMember:
-    case DSCode::CacheableEnum:
+    case DSCode::PDX_ENUM:
     case DSCode::PDX:
       IllegalStateException("Invalid DS Code.");
   }
@@ -680,7 +831,6 @@ void DataSerializableHandler::serialize(
     ptr->toDelta(dataOutput);
   } else {
     dataSerializable->toData(dataOutput);
-    ;
   }
 }
 
@@ -746,8 +896,7 @@ std::shared_ptr<DataSerializable> DataSerializableHandler::deserialize(
     case DSCode::CacheableASCIIString:
     case DSCode::CacheableASCIIStringHuge:
     case DSCode::CacheableStringHuge:
-    case DSCode::InternalDistributedMember:
-    case DSCode::CacheableEnum:
+    case DSCode::PDX_ENUM:
     case DSCode::PDX:
       break;
   }
