@@ -24,17 +24,12 @@
 #include <geode/SystemProperties.hpp>
 
 #include "CacheImpl.hpp"
-#include "ExpiryHandler_T.hpp"
-#include "ExpiryTaskManager.hpp"
-#include "RemoteQueryService.hpp"
-#include "ServerLocation.hpp"
+#include "FunctionExpiryTask.hpp"
 #include "TcrConnection.hpp"
 #include "TcrEndpoint.hpp"
 #include "TcrHADistributionManager.hpp"
 #include "ThinClientBaseDM.hpp"
-#include "ThinClientCacheDistributionManager.hpp"
 #include "ThinClientHARegion.hpp"
-#include "ThinClientLocatorHelper.hpp"
 #include "ThinClientRedundancyManager.hpp"
 #include "ThinClientRegion.hpp"
 #include "Utils.hpp"
@@ -46,22 +41,20 @@ namespace client {
 
 volatile bool TcrConnectionManager::TEST_DURABLE_CLIENT_CRASH = false;
 
-const char *TcrConnectionManager::NC_Redundancy = "NC Redundancy";
 const char *TcrConnectionManager::NC_Failover = "NC Failover";
 const char *TcrConnectionManager::NC_CleanUp = "NC CleanUp";
 
 TcrConnectionManager::TcrConnectionManager(CacheImpl *cache)
     : m_cache(cache),
       m_initGuard(false),
-      m_failoverSema(0),
+      failover_semaphore_(0),
       m_failoverTask(nullptr),
-      m_cleanupSema(0),
+      cleanup_semaphore_(0),
       m_cleanupTask(nullptr),
-      m_pingTaskId(-1),
-      m_servermonitorTaskId(-1),
+      ping_task_id_(ExpiryTask::invalid()),
       // Create the queues with flag to not delete the objects
-      m_notifyCleanupSemaList(false),
-      m_redundancySema(0),
+      notify_cleanup_semaphore_list_(false),
+      redundancy_semaphore_(0),
       m_redundancyTask(nullptr),
       m_isDurable(false),
       m_isNetDown(false) {
@@ -69,9 +62,6 @@ TcrConnectionManager::TcrConnectionManager(CacheImpl *cache)
       new ThinClientRedundancyManager(this));
 }
 
-ExpiryTaskManager::id_type TcrConnectionManager::getPingTaskId() {
-  return m_pingTaskId;
-}
 void TcrConnectionManager::init(bool isPool) {
   if (!m_initGuard) {
     m_initGuard = true;
@@ -80,17 +70,19 @@ void TcrConnectionManager::init(bool isPool) {
   }
   auto &props = m_cache->getDistributedSystem().getSystemProperties();
   m_isDurable = !props.durableClientId().empty();
-  auto pingInterval = (props.pingInterval() / 2);
+
+  auto interval = props.pingInterval();
   if (!isPool) {
-    ACE_Event_Handler *connectionChecker =
-        new ExpiryHandler_T<TcrConnectionManager>(
-            this, &TcrConnectionManager::checkConnection);
-    m_pingTaskId = m_cache->getExpiryTaskManager().scheduleExpiryTask(
-        connectionChecker, std::chrono::seconds(10), pingInterval, false);
+    auto &expiry_manager = m_cache->getExpiryTaskManager();
+    auto task = std::make_shared<FunctionExpiryTask>(
+        expiry_manager, [this]() { ping_endpoints(); });
+
+    ping_task_id_ = expiry_manager.schedule(std::move(task),
+                                            std::chrono::seconds(10), interval);
     LOGFINE(
         "TcrConnectionManager::TcrConnectionManager Registered ping "
         "task with id = %ld, interval = %ld",
-        m_pingTaskId, pingInterval.count());
+        ping_task_id_, interval.count());
   }
 
   m_redundancyManager->m_HAenabled = false;
@@ -122,13 +114,11 @@ void TcrConnectionManager::startFailoverAndCleanupThreads(bool isPool) {
 void TcrConnectionManager::close() {
   LOGFINE("TcrConnectionManager is closing");
 
-  if (m_pingTaskId > 0) {
-    m_cache->getExpiryTaskManager().cancelTask(m_pingTaskId);
-  }
+  m_cache->getExpiryTaskManager().cancel(ping_task_id_);
 
   if (m_failoverTask != nullptr) {
     m_failoverTask->stopNoblock();
-    m_failoverSema.release();
+    failover_semaphore_.release();
     m_failoverTask->wait();
     m_failoverTask = nullptr;
   }
@@ -143,7 +133,7 @@ void TcrConnectionManager::readyForEvents() {
 TcrConnectionManager::~TcrConnectionManager() {
   if (m_cleanupTask != nullptr) {
     m_cleanupTask->stopNoblock();
-    m_cleanupSema.release();
+    cleanup_semaphore_.release();
     m_cleanupTask->wait();
     // Clean notification lists if something remains in there; see bug #250
     cleanNotificationLists();
@@ -153,16 +143,9 @@ TcrConnectionManager::~TcrConnectionManager() {
     //  cleanup of endpoints, when regions are destroyed via notification
     {
       auto &&guard = m_endpoints.make_lock();
-      auto numEndPoints = m_endpoints.size();
-      if (numEndPoints > 0) {
+      if (m_endpoints.size() > 0) {
         LOGFINE("TCCM: endpoints remain in destructor");
       }
-      for (const auto &iter : m_endpoints) {
-        auto ep = iter.second;
-        LOGFINE("TCCM: forcing endpoint delete for %s in destructor",
-                ep->name().c_str());
-        _GEODE_SAFE_DELETE(ep);
-      }
     }
   }
   TcrConnectionManager::TEST_DURABLE_CLIENT_CRASH = false;
@@ -189,7 +172,7 @@ void TcrConnectionManager::connect(
             "TCCM 2: incremented region reference count for endpoint %s "
             "to %d",
             ep->name().c_str(), ep->numRegions());
-        endpoints.push_back(ep);
+        endpoints.push_back(ep.get());
       }
     } else {
       for (const auto &iter : endpointStrs) {
@@ -216,14 +199,15 @@ void TcrConnectionManager::connect(
 
 TcrEndpoint *TcrConnectionManager::addRefToTcrEndpoint(std::string endpointName,
                                                        ThinClientBaseDM *dm) {
-  TcrEndpoint *ep = nullptr;
+  std::shared_ptr<TcrEndpoint> ep;
 
   auto &&guard = m_endpoints.make_lock();
   const auto &find = m_endpoints.find(endpointName);
   if (find == m_endpoints.end()) {
     // this endpoint does not exist
-    ep = new TcrEndpoint(endpointName, m_cache, m_failoverSema, m_cleanupSema,
-                         m_redundancySema, dm, false);
+    ep = std::make_shared<TcrEndpoint>(endpointName, m_cache,
+                                       failover_semaphore_, cleanup_semaphore_,
+                                       redundancy_semaphore_, dm, false);
     m_endpoints.emplace(endpointName, ep);
   } else {
     ep = find->second;
@@ -233,7 +217,7 @@ TcrEndpoint *TcrConnectionManager::addRefToTcrEndpoint(std::string endpointName,
   LOGFINER("TCCM: incremented region reference count for endpoint %s to %d",
            ep->name().c_str(), ep->numRegions());
 
-  return ep;
+  return ep.get();
 }
 
 void TcrConnectionManager::disconnect(ThinClientBaseDM *distMng,
@@ -272,41 +256,26 @@ bool TcrConnectionManager::removeRefToEndpoint(TcrEndpoint *ep,
   return hasRemovedEndpoint;
 }
 
-int TcrConnectionManager::processEventIdMap(const ACE_Time_Value &currTime,
-                                            const void *) {
-  return m_redundancyManager->processEventIdMap(currTime, nullptr);
-}
-
-int TcrConnectionManager::checkConnection(const ACE_Time_Value &,
-                                          const void *) {
+void TcrConnectionManager::ping_endpoints() {
   auto &&guard = m_endpoints.make_lock();
   for (const auto &currItr : m_endpoints) {
     if (currItr.second->connected() && !m_isNetDown) {
       currItr.second->pingServer();
     }
   }
-  return 0;
-}
-
-int TcrConnectionManager::checkRedundancy(const ACE_Time_Value &,
-                                          const void *) {
-  m_redundancySema.release();
-  return 0;
 }
 
 void TcrConnectionManager::failover(std::atomic<bool> &isRunning) {
   LOGFINE("TcrConnectionManager: starting failover thread");
+
+  failover_semaphore_.acquire();
   while (isRunning) {
-    m_failoverSema.acquire();
-    if (isRunning && !m_isNetDown) {
+    if (!m_isNetDown) {
       try {
         std::lock_guard<decltype(m_distMngrsLock)> guard(m_distMngrsLock);
         for (const auto &it : m_distMngrs) {
           it->failover();
         }
-        while (m_failoverSema.tryacquire() != -1) {
-          ;
-        }
       } catch (const Exception &e) {
         LOGERROR(e.what());
       } catch (const std::exception &e) {
@@ -317,7 +286,10 @@ void TcrConnectionManager::failover(std::atomic<bool> &isRunning) {
             "different endpoint");
       }
     }
+
+    failover_semaphore_.acquire();
   }
+
   LOGFINE("TcrConnectionManager: ending failover thread");
 }
 
@@ -325,7 +297,7 @@ void TcrConnectionManager::getAllEndpoints(
     std::vector<TcrEndpoint *> &endpoints) {
   auto &&guard = m_endpoints.make_lock();
   for (const auto &currItr : m_endpoints) {
-    endpoints.push_back(currItr.second);
+    endpoints.push_back(currItr.second.get());
   }
 }
 
@@ -340,19 +312,13 @@ GfErrType TcrConnectionManager::registerInterestAllRegions(
   // TcrHADistributionManagers).
 
   GfErrType err = GF_NOERR;
-  GfErrType opErr = GF_NOERR;
   std::lock_guard<decltype(m_distMngrsLock)> guard(m_distMngrsLock);
-  std::list<ThinClientBaseDM *>::iterator begin = m_distMngrs.begin();
-  std::list<ThinClientBaseDM *>::iterator end = m_distMngrs.end();
-  for (std::list<ThinClientBaseDM *>::iterator it = begin; it != end; ++it) {
-    TcrHADistributionManager *tcrHADM =
-        dynamic_cast<TcrHADistributionManager *>(*it);
-    if (tcrHADM != nullptr) {
-      if ((opErr = tcrHADM->registerInterestForRegion(ep, request, reply)) !=
-          GF_NOERR) {
-        if (err == GF_NOERR) {
-          err = opErr;
-        }
+
+  for (const auto &it : m_distMngrs) {
+    if (auto tcrHADM = dynamic_cast<TcrHADistributionManager *>(it)) {
+      auto opErr = tcrHADM->registerInterestForRegion(ep, request, reply);
+      if (err == GF_NOERR) {
+        err = opErr;
       }
     }
   }
@@ -394,7 +360,7 @@ void TcrConnectionManager::removeHAEndpoints() {
   auto &&guard = m_endpoints.make_lock();
   auto currItr = m_endpoints.begin();
   while (currItr != m_endpoints.end()) {
-    if (removeRefToEndpoint(currItr->second)) {
+    if (removeRefToEndpoint(currItr->second.get())) {
       currItr = m_endpoints.begin();
     } else {
       currItr++;
@@ -430,44 +396,36 @@ void TcrConnectionManager::revive() {
 
 void TcrConnectionManager::redundancy(std::atomic<bool> &isRunning) {
   LOGFINE("Starting subscription maintain redundancy thread.");
+  redundancy_semaphore_.acquire();
+
   while (isRunning) {
-    m_redundancySema.acquire();
-    if (isRunning && !m_isNetDown) {
+    if (!m_isNetDown) {
       m_redundancyManager->maintainRedundancyLevel();
-      while (m_redundancySema.tryacquire() != -1) {
-        ;
-      }
     }
+
+    redundancy_semaphore_.acquire();
   }
   LOGFINE("Ending subscription maintain redundancy thread.");
 }
 
 void TcrConnectionManager::addNotificationForDeletion(
     Task<TcrEndpoint> *notifyReceiver, TcrConnection *notifyConnection,
-    ACE_Semaphore &notifyCleanupSema) {
+    binary_semaphore &notifyCleanupSema) {
   std::lock_guard<decltype(m_notificationLock)> guard(m_notificationLock);
   m_connectionReleaseList.put(notifyConnection);
   m_receiverReleaseList.put(notifyReceiver);
-  m_notifyCleanupSemaList.put(&notifyCleanupSema);
+  notify_cleanup_semaphore_list_.put(&notifyCleanupSema);
 }
 
 void TcrConnectionManager::cleanup(std::atomic<bool> &isRunning) {
   LOGFINE("TcrConnectionManager: starting cleanup thread");
-  do {
-    //  If we block on acquire, the queue must be empty (precondition).
-    if (m_receiverReleaseList.size() == 0) {
-      LOGDEBUG(
-          "TcrConnectionManager::cleanup(): waiting to acquire cleanup "
-          "semaphore.");
-      m_cleanupSema.acquire();
-    }
+
+  cleanup_semaphore_.acquire();
+
+  while (isRunning) {
     cleanNotificationLists();
-
-    while (m_cleanupSema.tryacquire() != -1) {
-      ;
-    }
-
-  } while (isRunning);
+    cleanup_semaphore_.acquire();
+  }
 
   LOGFINE("TcrConnectionManager: ending cleanup thread");
   //  Postcondition - all notification channels should be cleaned up by the end
@@ -477,7 +435,7 @@ void TcrConnectionManager::cleanup(std::atomic<bool> &isRunning) {
 void TcrConnectionManager::cleanNotificationLists() {
   Task<TcrEndpoint> *notifyReceiver;
   TcrConnection *notifyConnection;
-  ACE_Semaphore *notifyCleanupSema;
+  binary_semaphore *semaphore;
 
   while (true) {
     {
@@ -485,12 +443,12 @@ void TcrConnectionManager::cleanNotificationLists() {
       notifyReceiver = m_receiverReleaseList.get();
       if (!notifyReceiver) break;
       notifyConnection = m_connectionReleaseList.get();
-      notifyCleanupSema = m_notifyCleanupSemaList.get();
+      semaphore = notify_cleanup_semaphore_list_.get();
     }
     notifyReceiver->wait();
     //_GEODE_SAFE_DELETE(notifyReceiver);
     _GEODE_SAFE_DELETE(notifyConnection);
-    notifyCleanupSema->release();
+    semaphore->release();
   }
 }
 
@@ -508,6 +466,18 @@ bool TcrConnectionManager::getEndpointStatus(const std::string &endpoint) {
   }
   return false;
 }
+// TESTING: Disconnections of endpoint - return number of times that endpoint
+// disconnected
+int TcrConnectionManager::getNumberOfTimeEndpointDisconnected(
+    const std::string &endpoint) {
+  auto &&guard = m_endpoints.make_lock();
+  for (auto &currItr : m_endpoints) {
+    auto ep = currItr.second;
+    const std::string epName = ep->name();
+    if (epName == endpoint) return ep->numberOfTimesFailed();
+  }
+  throw IllegalStateException("Endpoint not found");
+}
 
 GfErrType TcrConnectionManager::sendSyncRequestCq(
     TcrMessage &request, TcrMessageReply &reply,
