@@ -19,6 +19,7 @@
 
 #include <geode/SystemProperties.hpp>
 
+#include "CacheImpl.hpp"
 #include "ThinClientPoolDM.hpp"
 
 namespace apache {
@@ -26,9 +27,9 @@ namespace geode {
 namespace client {
 
 TcrPoolEndPoint::TcrPoolEndPoint(const std::string& name, CacheImpl* cache,
-                                 ACE_Semaphore& failoverSema,
-                                 ACE_Semaphore& cleanupSema,
-                                 ACE_Semaphore& redundancySema,
+                                 binary_semaphore& failoverSema,
+                                 binary_semaphore& cleanupSema,
+                                 binary_semaphore& redundancySema,
                                  ThinClientPoolDM* dm)
     : TcrEndpoint(name, cache, failoverSema, cleanupSema, redundancySema, dm),
       m_dm(dm) {}
@@ -61,7 +62,6 @@ void TcrPoolEndPoint::closeNotification() {
 GfErrType TcrPoolEndPoint::registerDM(bool, bool isSecondary, bool,
                                       ThinClientBaseDM*) {
   GfErrType err = GF_NOERR;
-  std::lock_guard<decltype(m_dm->getPoolLock())> _guard(m_dm->getPoolLock());
   std::lock_guard<decltype(getQueueHostedMutex())> guardQueueHosted(
       getQueueHostedMutex());
   auto& sysProp = m_cacheImpl->getDistributedSystem().getSystemProperties();
@@ -74,7 +74,6 @@ GfErrType TcrPoolEndPoint::registerDM(bool, bool isSecondary, bool,
       return err;
     }
     m_dm->addConnection(newConn);
-    // m_connected = true;
     setConnected(true);
   }
 
