@@ -22,10 +22,16 @@
 #include <cstdlib>
 #include <iomanip>
 
-#include <ace/INET_Addr.h>
-#include <ace/OS.h>
 #include <boost/asio.hpp>
 #include <boost/dll/import.hpp>
+#include <boost/dll/runtime_symbol_info.hpp>
+#include <boost/process/detail/config.hpp>
+
+#include "config.h"
+
+#if defined(HAVE_uname)
+#include <sys/utsname.h>
+#endif
 
 namespace apache {
 namespace geode {
@@ -39,6 +45,14 @@ std::string Utils::getEnv(const char* varName) {
   return env;
 }
 
+std::error_code Utils::getLastError() {
+  if (errno != 0) {
+    return std::error_code(errno, std::system_category());
+  }
+
+  return boost::process::detail::get_last_error();
+}
+
 void Utils::parseEndpointString(const char* endpoints, std::string& host,
                                 uint16_t& port) {
   std::string endpointsStr(endpoints);
@@ -69,47 +83,36 @@ void Utils::parseEndpointString(const char* endpoints, std::string& host,
   port = atoi(endpointsStr.c_str());
 }
 
-std::string Utils::convertHostToCanonicalForm(const char* endpoints) {
-  if (endpoints == nullptr) return nullptr;
-  std::string hostString("");
-  uint16_t port = 0;
-  std::string endpointsStr(endpoints);
-  std::string endpointsStr1(endpoints);
-  // Parse this string to get all hostnames and port numbers.
-  std::string endpoint;
-  std::string::size_type length = endpointsStr.size();
-  std::string::size_type pos = 0;
-  ACE_TCHAR hostName[256], fullName[512];
-  pos = endpointsStr.find(':', 0);
-  if (pos != std::string::npos) {
-    endpoint = endpointsStr.substr(0, pos);
-    pos += 1;  // skip ':'
-    length -= (pos);
-    endpointsStr = endpointsStr.substr(pos, length);
-  } else {
-    hostString = "";
-    return "";
+std::string Utils::convertHostToCanonicalForm(const std::string& endpoints) {
+  using boost::asio::io_service;
+  using boost::asio::ip::tcp;
+
+  if (endpoints.empty()) {
+    return {};
   }
-  hostString = endpoint;
-  port = atoi(endpointsStr.c_str());
-  if (strcmp(hostString.c_str(), "localhost") == 0) {
-    ACE_OS::hostname(hostName, sizeof(hostName) - 1);
-    struct hostent* host;
-    host = ACE_OS::gethostbyname(hostName);
-    if (host) {
-      std::snprintf(fullName, sizeof(fullName), "%s:%d", host->h_name, port);
-      return fullName;
-    }
-  } else {
-    pos = endpointsStr1.find('.', 0);
-    if (pos != std::string::npos) {
-      ACE_INET_Addr addr(endpoints);
-      addr.get_host_name(hostName, 256);
-      std::snprintf(fullName, sizeof(fullName), "%s:%d", hostName, port);
-      return fullName;
-    }
+
+  auto pos = endpoints.rfind(':');
+  if (pos == std::string::npos) {
+    return {};
   }
-  return endpoints;
+
+  auto hostname = endpoints.substr(0, pos);
+  auto port = endpoints.substr(pos + 1);
+
+  if (hostname == "localhost") {
+    hostname = boost::asio::ip::host_name();
+  }
+
+  io_service svc;
+  boost::system::error_code ec;
+  tcp::resolver resolver{svc};
+  auto results = resolver.resolve(hostname, ec);
+
+  if (!ec) {
+    hostname = results->host_name();
+  }
+
+  return hostname + ':' + port;
 }
 
 void Utils::parseEndpointNamesString(
@@ -173,20 +176,22 @@ const boost::dll::shared_library& getSharedLibrary(
 
   const auto& find = sharedLibraries.find(libraryName);
   if (find == sharedLibraries.end()) {
+    auto path = libraryName.empty() ? boost::dll::program_location()
+                                    : boost::dll::fs::path{libraryName};
     try {
       return *sharedLibraries
                   .emplace(
                       libraryName,
                       std::make_shared<boost::dll::shared_library>(
-                          libraryName,
+                          path,
                           boost::dll::load_mode::rtld_global |
                               boost::dll::load_mode::rtld_lazy |
                               boost::dll::load_mode::append_decorations |
                               boost::dll::load_mode::search_system_folders))
                   .first->second;
     } catch (const boost::dll::fs::system_error& e) {
-      throw IllegalArgumentException("cannot open library: " + libraryName +
-                                     ": reason: " + e.what());
+      throw IllegalArgumentException("cannot open library: \"" + path.string() +
+                                     "\": reason: " + e.what());
     }
   }
 
@@ -199,8 +204,10 @@ void* Utils::getFactoryFunctionVoid(const std::string& lib,
     const auto& sharedLibrary = getSharedLibrary(lib);
     return reinterpret_cast<void*>(sharedLibrary.get<void*()>(funcName));
   } catch (const boost::dll::fs::system_error&) {
+    std::string location =
+        lib.empty() ? "the application" : "library \"" + lib + "\"";
     throw IllegalArgumentException("cannot find factory function " + funcName +
-                                   " in library " + lib);
+                                   " in " + location);
   }
 }
 
@@ -235,6 +242,88 @@ void Utils::updateStatOpTime(statistics::Statistics* m_regionStats,
   m_regionStats->incLong(statId, startStatOpTime() - start);
 }
 
+std::string Utils::getSystemInfo() {
+  std::string sysname{"Unknown"};
+  std::string machine{"Unknown"};
+  std::string nodename{"Unknown"};
+  std::string release{"Unknown"};
+  std::string version{"Unknown"};
+
+#if defined(HAVE_uname)
+  struct utsname name;
+  auto rc = ::uname(&name);
+  if (rc == 0) {
+    sysname = name.sysname;
+    machine = name.machine;
+    nodename = name.nodename;
+    release = name.release;
+    version = name.version;
+  }
+#elif defined(_WIN32) /* HAVE_uname */
+  sysname = "Win32";
+
+/* Since MS found it necessary to deprecate these. */
+#pragma warning(push)
+#pragma warning(disable : 4996)
+#if defined(__clang__)
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wdeprecated-declarations"
+#endif /* __clang__ */
+  OSVERSIONINFOA vinfo;
+  vinfo.dwOSVersionInfoSize = sizeof(OSVERSIONINFOA);
+  ::GetVersionExA(&vinfo);
+#if defined(__clang__)
+#pragma clang diagnostic pop
+#endif /* __clang__ */
+#pragma warning(pop)
+
+  if (vinfo.dwPlatformId == VER_PLATFORM_WIN32_NT) {
+    // Get information from the two structures
+    release = "Windows NT " + std::to_string(vinfo.dwMajorVersion) + '.' +
+              std::to_string(vinfo.dwMinorVersion);
+    version = "Build " + std::to_string(vinfo.dwBuildNumber) + ' ' +
+              vinfo.szCSDVersion;
+  }
+
+  {
+    HKEY key;
+    DWORD size = 0;
+    DWORD type = 0;
+    auto key_name = "ProcessorNameString";
+    auto key_path = "HARDWARE\\DESCRIPTION\\System\\CentralProcessor\\0";
+    auto rc = ::RegOpenKeyExA(HKEY_LOCAL_MACHINE, key_path, 0, KEY_READ, &key);
+    if (rc == ERROR_SUCCESS) {
+      rc = ::RegQueryValueExA(key, key_name, nullptr, &type, nullptr, &size);
+      if (rc == ERROR_SUCCESS && type == REG_SZ && size > 0) {
+        std::vector<char> buffer(size, 0);
+        auto ptr = reinterpret_cast<LPBYTE>(buffer.data());
+        rc = ::RegQueryValueExA(key, key_name, nullptr, &type, ptr, &size);
+        if (rc == ERROR_SUCCESS && buffer[0] != '\0') {
+          machine = buffer.data();
+        }
+      }
+
+      ::RegCloseKey(key);
+    }
+  }
+
+  nodename = boost::asio::ip::host_name();
+#endif /* _WIN32 */
+
+  std::string info = "SystemName=";
+  info += sysname;
+  info += " Machine=";
+  info += machine;
+  info += " Host=";
+  info += nodename;
+  info += " Release=";
+  info += release;
+  info += " Version=";
+  info += version;
+
+  return info;
+}
+
 }  // namespace client
 }  // namespace geode
 }  // namespace apache
