@@ -59,6 +59,8 @@ class APACHE_GEODE_EXPORT Utils {
    */
   static std::string getEnv(const char* varName);
 
+  static std::error_code getLastError();
+
 #ifdef __GNUC__
   inline static char* _gnuDemangledName(const char* typeIdName, size_t& len) {
     int status;
@@ -154,7 +156,9 @@ class APACHE_GEODE_EXPORT Utils {
   static void parseEndpointString(const char* endpoints, std::string& host,
                                   uint16_t& port);
 
-  static std::string convertHostToCanonicalForm(const char* endpoints);
+  static std::string convertHostToCanonicalForm(const std::string& endpoints);
+
+  static std::string getSystemInfo();
 
   static char* copyString(const char* str);
 
@@ -162,8 +166,9 @@ class APACHE_GEODE_EXPORT Utils {
    * Convert the byte array to a string as "%d %d ...".
    * <code>maxLength</code> as zero implies no limit.
    */
-  static std::string convertBytesToString(const uint8_t* bytes, size_t length,
-                                          size_t maxLength = _GF_MSG_LIMIT);
+  static std::string convertBytesToString(
+      const uint8_t* bytes, size_t length,
+      size_t maxLength = _GEODE_LOG_MESSAGE_LIMIT);
 
   /**
    * lib should be in the form originally required by ACE_DLL, typically just
@@ -181,15 +186,17 @@ class APACHE_GEODE_EXPORT Utils {
    * Convert the byte array to a string as "%d %d ...".
    * <code>maxLength</code> as zero implies no limit.
    */
-  static std::string convertBytesToString(const int8_t* bytes, size_t length,
-                                          size_t maxLength = _GF_MSG_LIMIT);
+  static std::string convertBytesToString(
+      const int8_t* bytes, size_t length,
+      size_t maxLength = _GEODE_LOG_MESSAGE_LIMIT);
 
   /**
    * Convert the byte array to a string as "%d %d ...".
    * <code>maxLength</code> as zero implies no limit.
    */
   inline static std::string convertBytesToString(
-      const char* bytes, size_t length, size_t maxLength = _GF_MSG_LIMIT) {
+      const char* bytes, size_t length,
+      size_t maxLength = _GEODE_LOG_MESSAGE_LIMIT) {
     return convertBytesToString(reinterpret_cast<const uint8_t*>(bytes), length,
                                 maxLength);
   }
@@ -202,9 +209,25 @@ class APACHE_GEODE_EXPORT Utils {
 // Generate random numbers 0 to max-1
 class RandGen {
  public:
-  template <typename T, class G = std::default_random_engine>
-  inline T operator()(T max) {
-    return std::uniform_int_distribution<T>{0, max - 1}(generator<G>());
+  typedef std::size_t argument_type, result_type;
+
+  template <class G = std::default_random_engine>
+  result_type operator()(argument_type max) {
+    return std::uniform_int_distribution<result_type>{0,
+                                                      max - 1}(generator<G>());
+  }
+
+  template <class G = std::default_random_engine>
+  result_type operator()() {
+    return std::uniform_int_distribution<result_type>{
+        0, (max)() - 1}(generator<G>());
+  }
+
+  static constexpr result_type(min)() {
+    return (std::numeric_limits<result_type>::min)();
+  }
+  static constexpr result_type(max)() {
+    return (std::numeric_limits<result_type>::max)();
   }
 
  private:
