@@ -85,10 +85,6 @@ OsStatisticsImpl::OsStatisticsImpl(StatisticsType* typeArg,
   this->numericId = calcNumericId(system, numericIdArg);
   this->uniqueId = uniqueIdArg;
   this->closed = false;
-  ;
-  /* adongre
-   * CID 28981: Uninitialized pointer field (UNINIT_CTOR)
-   */
   doubleStorage = nullptr;
   intStorage = nullptr;
   longStorage = nullptr;
@@ -125,22 +121,18 @@ OsStatisticsImpl::OsStatisticsImpl(StatisticsType* typeArg,
 }
 
 OsStatisticsImpl::~OsStatisticsImpl() noexcept {
-  try {
-    statsType = nullptr;
-    if (intStorage != nullptr) {
-      delete[] intStorage;
-      intStorage = nullptr;
-    }
-    if (longStorage != nullptr) {
-      delete[] longStorage;
-      longStorage = nullptr;
-    }
-    if (doubleStorage != nullptr) {
-      delete[] doubleStorage;
-      doubleStorage = nullptr;
-    }
-  } catch (...) {
-    LOGERROR("Exception in ~OsStatisticsImpl");
+  statsType = nullptr;
+  if (intStorage != nullptr) {
+    delete[] intStorage;
+    intStorage = nullptr;
+  }
+  if (longStorage != nullptr) {
+    delete[] longStorage;
+    longStorage = nullptr;
+  }
+  if (doubleStorage != nullptr) {
+    delete[] doubleStorage;
+    doubleStorage = nullptr;
   }
 }
 
@@ -162,34 +154,27 @@ void OsStatisticsImpl::close() {
 
 void OsStatisticsImpl::_setInt(int32_t offset, int32_t value) {
   if (offset >= statsType->getIntStatCount()) {
-    char s[128] = {'\0'};
-    std::snprintf(
-        s, 128, "setInt:The id (%d) of the Statistic Descriptor is not valid ",
-        offset);
-    throw IllegalArgumentException(s);
+    throw IllegalArgumentException(
+        "setInt:The id(" + std::to_string(offset) +
+        ") of the Statistic Descriptor is not valid");
   }
   intStorage[offset] = value;
 }
 
 void OsStatisticsImpl::_setLong(int32_t offset, int64_t value) {
   if (offset >= statsType->getLongStatCount()) {
-    char s[128] = {'\0'};
-    std::snprintf(
-        s, 128, "setLong:The id (%d) of the Statistic Descriptor is not valid ",
-        offset);
-    throw IllegalArgumentException(s);
+    throw IllegalArgumentException(
+        "setLong:The id(" + std::to_string(offset) +
+        ") of the Statistic Descriptor is not valid");
   }
   longStorage[offset] = value;
 }
 
 void OsStatisticsImpl::_setDouble(int32_t offset, double value) {
   if (offset >= statsType->getDoubleStatCount()) {
-    char s[128] = {'\0'};
-    std::snprintf(
-        s, 128,
-        "setDouble:The id (%d) of the Statistic Descriptor is not valid ",
-        offset);
-    throw IllegalArgumentException(s);
+    throw IllegalArgumentException(
+        "setDouble:The id(" + std::to_string(offset) +
+        ") of the Statistic Descriptor is not valid");
   }
   doubleStorage[offset] = value;
 }
@@ -198,11 +183,9 @@ void OsStatisticsImpl::_setDouble(int32_t offset, double value) {
 
 int32_t OsStatisticsImpl::_getInt(int32_t offset) const {
   if (offset >= statsType->getIntStatCount()) {
-    char s[128] = {'\0'};
-    std::snprintf(
-        s, 128, "getInt:The id (%d) of the Statistic Descriptor is not valid ",
-        offset);
-    throw IllegalArgumentException(s);
+    throw IllegalArgumentException(
+        "getInt:The id(" + std::to_string(offset) +
+        ") of the Statistic Descriptor is not valid");
   }
 
   return intStorage[offset];
@@ -210,11 +193,9 @@ int32_t OsStatisticsImpl::_getInt(int32_t offset) const {
 
 int64_t OsStatisticsImpl::_getLong(int32_t offset) const {
   if (offset >= statsType->getLongStatCount()) {
-    char s[128] = {'\0'};
-    std::snprintf(
-        s, 128, "getLong:The id (%d) of the Statistic Descriptor is not valid ",
-        offset);
-    throw IllegalArgumentException(s);
+    throw IllegalArgumentException(
+        "getLong:The id(" + std::to_string(offset) +
+        ") of the Statistic Descriptor is not valid");
   }
 
   return longStorage[offset];
@@ -222,12 +203,9 @@ int64_t OsStatisticsImpl::_getLong(int32_t offset) const {
 
 double OsStatisticsImpl::_getDouble(int32_t offset) const {
   if (offset >= statsType->getDoubleStatCount()) {
-    char s[128] = {'\0'};
-    std::snprintf(
-        s, 128,
-        "getDouble:The id (%d) of the Statistic Descriptor is not valid ",
-        offset);
-    throw IllegalArgumentException(s);
+    throw IllegalArgumentException(
+        "getDouble:The id(" + std::to_string(offset) +
+        ") of the Statistic Descriptor is not valid");
   }
 
   return doubleStorage[offset];
@@ -255,11 +233,9 @@ int64_t OsStatisticsImpl::_getRawBits(
 
 int32_t OsStatisticsImpl::_incInt(int32_t offset, int32_t delta) {
   if (offset >= statsType->getIntStatCount()) {
-    char s[128] = {'\0'};
-    std::snprintf(
-        s, 128, "incInt:The id (%d) of the Statistic Descriptor is not valid ",
-        offset);
-    throw IllegalArgumentException(s);
+    throw IllegalArgumentException(
+        "incInt:The id(" + std::to_string(offset) +
+        ") of the Statistic Descriptor is not valid");
   }
 
   intStorage[offset] += delta;
@@ -268,11 +244,9 @@ int32_t OsStatisticsImpl::_incInt(int32_t offset, int32_t delta) {
 
 int64_t OsStatisticsImpl::_incLong(int32_t offset, int64_t delta) {
   if (offset >= statsType->getLongStatCount()) {
-    char s[128] = {'\0'};
-    std::snprintf(
-        s, 128, "incLong:The id (%d) of the Statistic Descriptor is not valid ",
-        offset);
-    throw IllegalArgumentException(s);
+    throw IllegalArgumentException(
+        "incLong:The id(" + std::to_string(offset) +
+        ") of the Statistic Descriptor is not valid");
   }
   longStorage[offset] += delta;
   return longStorage[offset];
@@ -280,12 +254,9 @@ int64_t OsStatisticsImpl::_incLong(int32_t offset, int64_t delta) {
 
 double OsStatisticsImpl::_incDouble(int32_t offset, double delta) {
   if (offset >= statsType->getDoubleStatCount()) {
-    char s[128] = {'\0'};
-    std::snprintf(
-        s, 128,
-        "incDouble:The id (%d) of the Statistic Descriptor is not valid ",
-        offset);
-    throw IllegalArgumentException(s);
+    throw IllegalArgumentException(
+        "incDouble:The id(" + std::to_string(offset) +
+        ") of the Statistic Descriptor is not valid");
   }
   doubleStorage[offset] += delta;
   return doubleStorage[offset];
