@@ -37,7 +37,7 @@ namespace statistics {
  * setting, incrementing and getting individual <code>StatisticDescriptor</code>
  * values.
  */
-class APACHE_GEODE_EXPORT Statistics {
+class Statistics {
  public:
   /**
    * Closes these statistics.  After statistics have been closed, they
