@@ -30,15 +30,13 @@ namespace apache {
 namespace geode {
 namespace client {
 
-extern void APACHE_GEODE_EXPORT GfErrTypeThrowException(const char* str,
-                                                        GfErrType err);
+extern void GfErrTypeThrowException(const char* str, GfErrType err);
 
-#define throwExceptionIfError(str, err)  \
-  do {                                   \
-    if (err != GF_NOERR) {               \
-      GfErrTypeThrowException(str, err); \
-    }                                    \
-  } while (0)
+inline void throwExceptionIfError(const char* str, GfErrType err) {
+  if (err != GF_NOERR) {
+    GfErrTypeThrowException(str, err);
+  }
+}
 
 }  // namespace client
 }  // namespace geode
