@@ -26,25 +26,25 @@ TEST(CacheableKeysTest, boolDifferentHashCodes) {
       << "Two different bool values have different hashcodes";
 }
 
-TEST(CacheableKeysTest, int8_tDifferentHashCodes) {
+TEST(CacheableKeysTest, int8DifferentHashCodes) {
   EXPECT_NE(hashcode(static_cast<int8_t>(37)),
             hashcode(static_cast<int8_t>(42)))
       << "Two different int8_t values have different hashcodes";
 }
 
-TEST(CacheableKeysTest, int16_tDifferentHashCodes) {
+TEST(CacheableKeysTest, int16DifferentHashCodes) {
   EXPECT_NE(hashcode(static_cast<int8_t>(37)),
             hashcode(static_cast<int8_t>(42)))
       << "Two different int16_t values have different hashcodes";
 }
 
-TEST(CacheableKeysTest, int32_tDifferentHashCodes) {
+TEST(CacheableKeysTest, int32DifferentHashCodes) {
   EXPECT_NE(hashcode(static_cast<int8_t>(37)),
             hashcode(static_cast<int8_t>(42)))
       << "Two different int32_t values have different hashcodes";
 }
 
-TEST(CacheableKeysTest, int64_tDifferentHashCodes) {
+TEST(CacheableKeysTest, int64DifferentHashCodes) {
   EXPECT_NE(hashcode(static_cast<int8_t>(37)),
             hashcode(static_cast<int8_t>(42)))
       << "Two different int64_t values have different hashcodes";
