@@ -62,9 +62,7 @@ class TestDataInput {
  public:
   explicit TestDataInput(const char *str)
       : m_byteArray(ByteArray::fromString(str)),
-        m_dataInput(m_byteArray.get(), m_byteArray.size()) {
-    // NOP
-  }
+        m_dataInput(m_byteArray.get(), m_byteArray.size()) {}
 
   void read(uint8_t *value) { *value = m_dataInput.read(); }
 
@@ -258,8 +256,16 @@ TEST_F(DataInputTest, CanReadUTFWithAnUTFStringInput) {
   DataOutputInternal stream;
   stream.writeUTF(expectedString);
 
-  DataInputUnderTest dataInput(stream.getBufferCopy(),
-                               stream.getBufferLength());
+  size_t outputBufferSize;
+  auto outputBuffer = stream.getBuffer(&outputBufferSize);
+
+  auto buffer = std::unique_ptr<uint8_t, decltype(free) *>{
+      reinterpret_cast<uint8_t *>(
+          std::malloc(sizeof(uint8_t) * outputBufferSize)),
+      std::free};
+  std::memcpy(buffer.get(), outputBuffer, outputBufferSize);
+
+  DataInputUnderTest dataInput(buffer.get(), stream.getBufferLength());
   auto actualString = dataInput.readUTF();
 
   EXPECT_TRUE(expectedString == actualString);
@@ -315,7 +321,7 @@ TEST_F(DataInputTest, TestReadBoolean) {
   EXPECT_EQ(true, value) << "Correct bool";
 }
 
-TEST_F(DataInputTest, TestReadUint8_tBytesOnly) {
+TEST_F(DataInputTest, TestReadUint8BytesOnly) {
   TestDataInput dataInput("BABEFACE");
   uint8_t buffer[4];
   ::memset(buffer, 0U, 4 * sizeof(uint8_t));
@@ -326,7 +332,7 @@ TEST_F(DataInputTest, TestReadUint8_tBytesOnly) {
   EXPECT_EQ(static_cast<uint8_t>(206U), buffer[3]) << "Correct third uint8_t";
 }
 
-TEST_F(DataInputTest, TestReadInt8_tBytesOnly) {
+TEST_F(DataInputTest, TestReadInt8BytesOnly) {
   TestDataInput dataInput("DEADBEEF");
   int8_t buffer[4];
   ::memset(buffer, 0, 4 * sizeof(int8_t));
@@ -337,32 +343,38 @@ TEST_F(DataInputTest, TestReadInt8_tBytesOnly) {
   EXPECT_EQ(static_cast<int8_t>(-17), buffer[3]) << "Correct third int8_t";
 }
 
-TEST_F(DataInputTest, TestReadUint8_tBytes) {
+TEST_F(DataInputTest, TestReadUint8Bytes) {
   TestDataInput dataInput("04BABEFACE");
   uint8_t *buffer = nullptr;
   int32_t len = 0;
   dataInput.readBytes(&buffer, &len);
-  EXPECT_NE(static_cast<uint8_t *>(nullptr), buffer) << "Non-null buffer";
+  auto bufferGuard = std::unique_ptr<uint8_t[]>{buffer};
+  ASSERT_NE(nullptr, buffer) << "Non-null buffer";
   ASSERT_EQ(4, len) << "Correct length";
-  EXPECT_EQ(static_cast<uint8_t>(186U), buffer[0]) << "Correct zeroth uint8_t";
-  EXPECT_EQ(static_cast<uint8_t>(190U), buffer[1]) << "Correct first uint8_t";
-  EXPECT_EQ(static_cast<uint8_t>(250U), buffer[2]) << "Correct second uint8_t";
-  EXPECT_EQ(static_cast<uint8_t>(206U), buffer[3]) << "Correct third uint8_t";
-  _GEODE_SAFE_DELETE_ARRAY(buffer);
+  if (buffer) {
+    EXPECT_EQ(static_cast<uint8_t>(186U), buffer[0])
+        << "Correct zeroth uint8_t";
+    EXPECT_EQ(static_cast<uint8_t>(190U), buffer[1]) << "Correct first uint8_t";
+    EXPECT_EQ(static_cast<uint8_t>(250U), buffer[2])
+        << "Correct second uint8_t";
+    EXPECT_EQ(static_cast<uint8_t>(206U), buffer[3]) << "Correct third uint8_t";
+  }
 }
 
-TEST_F(DataInputTest, TestReadInt8_tBytes) {
+TEST_F(DataInputTest, TestReadInt8Bytes) {
   TestDataInput dataInput("04DEADBEEF");
   int8_t *buffer = nullptr;
   int32_t len = 0;
   dataInput.readBytes(&buffer, &len);
-  EXPECT_NE(static_cast<int8_t *>(nullptr), buffer) << "Non-null buffer";
+  auto bufferGuard = std::unique_ptr<int8_t[]>{buffer};
+  ASSERT_NE(nullptr, buffer) << "Non-null buffer";
   ASSERT_EQ(4, len) << "Correct length";
-  EXPECT_EQ(static_cast<int8_t>(-34), buffer[0]) << "Correct zeroth int8_t";
-  EXPECT_EQ(static_cast<int8_t>(-83), buffer[1]) << "Correct first int8_t";
-  EXPECT_EQ(static_cast<int8_t>(-66), buffer[2]) << "Correct second int8_t";
-  EXPECT_EQ(static_cast<int8_t>(-17), buffer[3]) << "Correct third int8_t";
-  _GEODE_SAFE_DELETE_ARRAY(buffer);
+  if (buffer) {
+    EXPECT_EQ(static_cast<int8_t>(-34), buffer[0]) << "Correct zeroth int8_t";
+    EXPECT_EQ(static_cast<int8_t>(-83), buffer[1]) << "Correct first int8_t";
+    EXPECT_EQ(static_cast<int8_t>(-66), buffer[2]) << "Correct second int8_t";
+    EXPECT_EQ(static_cast<int8_t>(-17), buffer[3]) << "Correct third int8_t";
+  }
 }
 
 TEST_F(DataInputTest, TestReadIntUint16) {
@@ -590,22 +602,25 @@ TEST_F(DataInputTest, TestReadArrayOfByteArrays) {
   int32_t *elementLength = nullptr;
   dataInput.readArrayOfByteArrays(&arrayOfByteArrays, arrayLength,
                                   &elementLength);
-  EXPECT_NE(static_cast<int8_t **>(nullptr), arrayOfByteArrays)
-      << "Non-null array of byte arrays";
+  auto arrayOfByteArraysGuard =
+      std::unique_ptr<int8_t *[]> { arrayOfByteArrays };
+  auto elementLengthGuard = std::unique_ptr<int32_t[]>{elementLength};
+
+  ASSERT_NE(nullptr, arrayOfByteArrays) << "Non-null array of byte arrays";
   ASSERT_EQ(1, arrayLength) << "Correct array length";
-  EXPECT_NE(static_cast<int8_t *>(nullptr), arrayOfByteArrays[0])
-      << "Non-null first byte array";
-  ASSERT_EQ(4, elementLength[0]) << "Correct length";
-  EXPECT_EQ(static_cast<int8_t>(-34), arrayOfByteArrays[0][0])
-      << "Correct zeroth int8_t";
-  EXPECT_EQ(static_cast<int8_t>(-83), arrayOfByteArrays[0][1])
-      << "Correct first int8_t";
-  EXPECT_EQ(static_cast<int8_t>(-66), arrayOfByteArrays[0][2])
-      << "Correct second int8_t";
-  EXPECT_EQ(static_cast<int8_t>(-17), arrayOfByteArrays[0][3])
-      << "Correct third int8_t";
-  _GEODE_SAFE_DELETE_ARRAY(elementLength);
-  _GEODE_SAFE_DELETE_ARRAY(arrayOfByteArrays);
+  if (arrayOfByteArrays) {
+    EXPECT_NE(static_cast<int8_t *>(nullptr), arrayOfByteArrays[0])
+        << "Non-null first byte array";
+    ASSERT_EQ(4, elementLength[0]) << "Correct length";
+    EXPECT_EQ(static_cast<int8_t>(-34), arrayOfByteArrays[0][0])
+        << "Correct zeroth int8_t";
+    EXPECT_EQ(static_cast<int8_t>(-83), arrayOfByteArrays[0][1])
+        << "Correct first int8_t";
+    EXPECT_EQ(static_cast<int8_t>(-66), arrayOfByteArrays[0][2])
+        << "Correct second int8_t";
+    EXPECT_EQ(static_cast<int8_t>(-17), arrayOfByteArrays[0][3])
+        << "Correct third int8_t";
+  }
 }
 
 TEST_F(DataInputTest, TestGetBytesRead) {
