@@ -18,11 +18,13 @@
 #include <TcrMessage.hpp>
 #include <iostream>
 
+#include <gtest/gtest.h>
+
 #include <geode/CacheFactory.hpp>
 #include <geode/CqState.hpp>
 
 #include "ByteArrayFixture.hpp"
-#include "gtest/gtest.h"
+#include "SerializationRegistry.hpp"
 
 namespace {
 
@@ -78,7 +80,7 @@ TEST_F(TcrMessageTest, intializeDefaultConstructor) {
   EXPECT_EQ(TcrMessage::INVALID, message.getMessageType());
 }
 
-TEST_F(TcrMessageTest, testConstructor1MessageDataContentWithDESTROY_REGION) {
+TEST_F(TcrMessageTest, testConstructor1MessageDataContentWithDestoryRegion) {
   using apache::geode::client::TcrMessageDestroyRegion;
 
   const Region *region = nullptr;
@@ -99,7 +101,7 @@ TEST_F(TcrMessageTest, testConstructor1MessageDataContentWithDESTROY_REGION) {
       message);
 }
 
-TEST_F(TcrMessageTest, testConstructor1MessageDataContentWithCLEAR_REGION) {
+TEST_F(TcrMessageTest, testConstructor1MessageDataContentWithClearRegion) {
   using apache::geode::client::TcrMessageClearRegion;
 
   const Region *region = nullptr;
@@ -135,7 +137,7 @@ TEST_F(TcrMessageTest, testQueryConstructorMessageDataContent) {
       message);
 }
 
-TEST_F(TcrMessageTest, testQueryConstructorWithQUERY) {
+TEST_F(TcrMessageTest, testQueryConstructorWithQuery) {
   using apache::geode::client::TcrMessageQuery;
 
   std::chrono::milliseconds messageResponseTimeout{1000};
@@ -152,7 +154,7 @@ TEST_F(TcrMessageTest, testQueryConstructorWithQUERY) {
       message);
 }
 
-TEST_F(TcrMessageTest, testQueryConstructorWithSTOPCQ_MSG_TYPE) {
+TEST_F(TcrMessageTest, testQueryConstructorWithStopCq) {
   using apache::geode::client::TcrMessageStopCQ;
 
   std::chrono::milliseconds messageResponseTimeout{1000};
@@ -169,7 +171,7 @@ TEST_F(TcrMessageTest, testQueryConstructorWithSTOPCQ_MSG_TYPE) {
       message);
 }
 
-TEST_F(TcrMessageTest, testQueryConstructorWithCLOSECQ_MSG_TYPE) {
+TEST_F(TcrMessageTest, testQueryConstructorWithCloseCq) {
   using apache::geode::client::TcrMessageCloseCQ;
 
   std::chrono::milliseconds messageResponseTimeout{1000};
@@ -187,7 +189,7 @@ TEST_F(TcrMessageTest, testQueryConstructorWithCLOSECQ_MSG_TYPE) {
 }
 
 TEST_F(TcrMessageTest,
-       testParameterizedQueryConstructorWithQUERY_WITH_PARAMETERS) {
+       testParameterizedQueryConstructorWithQueryWithParameters) {
   using apache::geode::client::TcrMessageQueryWithParameters;
 
   std::chrono::milliseconds messageResponseTimeout{1000};
@@ -207,7 +209,7 @@ TEST_F(TcrMessageTest,
       message);
 }
 
-TEST_F(TcrMessageTest, testConstructorWithCONTAINS_KEY) {
+TEST_F(TcrMessageTest, testConstructorWithContainsKey) {
   using apache::geode::client::TcrMessageContainsKey;
 
   TcrMessageContainsKey message(
@@ -226,7 +228,7 @@ TEST_F(TcrMessageTest, testConstructorWithCONTAINS_KEY) {
       message);
 }
 
-TEST_F(TcrMessageTest, testConstructorWithGETDURABLECQS_MSG_TYPE) {
+TEST_F(TcrMessageTest, testConstructorWithGetDurableCqs) {
   using apache::geode::client::TcrMessageGetDurableCqs;
 
   TcrMessageGetDurableCqs message(new DataOutputUnderTest(),
@@ -256,26 +258,26 @@ TEST_F(TcrMessageTest, testConstructor2WithREQUEST) {
       message);
 }
 
-TEST_F(TcrMessageTest, testConstructor2WithDESTROY) {
+TEST_F(TcrMessageTest, testConstructor2WithDestroy) {
   using apache::geode::client::TcrMessageDestroy;
 
   TcrMessageDestroy message(
       new DataOutputUnderTest(), static_cast<const Region *>(nullptr),
       CacheableString::create("mykey"),
-      static_cast<const std::shared_ptr<CacheableKey>>(nullptr),
+      static_cast<const std::shared_ptr<CacheableKey>>(nullptr), true,
       static_cast<const std::shared_ptr<Serializable>>(nullptr),
       static_cast<ThinClientBaseDM *>(nullptr));
 
   EXPECT_EQ(TcrMessage::DESTROY, message.getMessageType());
 
   EXPECT_MESSAGE_EQ(
-      "000000090000004800000005FFFFFFFF000000001300494E56414C49445F524547494F4E"
-      "5F4E414D4500000008015700056D796B6579000000010129000000010129000000120003"
-      "000000000000000103\\h{16}",
+      "000000090000004900000005FFFFFFFF000000001300494E56414C49445F524547494F4E"
+      "5F4E414D4500000008015700056D796B6579000000010129000000020137080000001200"
+      "03000000000000000103\\h{16}",
       message);
 }
 
-TEST_F(TcrMessageTest, testConstructor2WithINVALIDATE) {
+TEST_F(TcrMessageTest, testConstructor2WithInvalidate) {
   using apache::geode::client::TcrMessageInvalidate;
 
   TcrMessageInvalidate message(
@@ -295,7 +297,7 @@ TEST_F(TcrMessageTest, testConstructor2WithINVALIDATE) {
       message);
 }
 
-TEST_F(TcrMessageTest, testConstructor3WithPUT) {
+TEST_F(TcrMessageTest, testConstructor3WithPut) {
   using apache::geode::client::TcrMessagePut;
 
   TcrMessagePut message(
@@ -373,7 +375,7 @@ TEST_F(TcrMessageTest, TcrMessageRegisterInterestListWithManyKeys) {
       message);
 }
 
-TEST_F(TcrMessageTest, testConstructor5WithUNREGISTER_INTERST_LIST) {
+TEST_F(TcrMessageTest, testConstructor5WithUnregisterInteresetList) {
   using apache::geode::client::TcrMessageUnregisterInterestList;
 
   std::vector<std::shared_ptr<CacheableKey>> keys;
@@ -381,9 +383,7 @@ TEST_F(TcrMessageTest, testConstructor5WithUNREGISTER_INTERST_LIST) {
 
   TcrMessageUnregisterInterestList message(
       new DataOutputUnderTest(), static_cast<const Region *>(nullptr), keys,
-      false,  // isDurable
-      false,  // receiveValues
-      InterestResultPolicy::NONE, static_cast<ThinClientBaseDM *>(nullptr));
+      false, static_cast<ThinClientBaseDM *>(nullptr));
 
   EXPECT_EQ(TcrMessage::UNREGISTER_INTEREST_LIST, message.getMessageType());
 
@@ -394,7 +394,7 @@ TEST_F(TcrMessageTest, testConstructor5WithUNREGISTER_INTERST_LIST) {
       message);
 }
 
-TEST_F(TcrMessageTest, testConstructorGET_FUNCTION_ATTRIBUTES) {
+TEST_F(TcrMessageTest, testConstructorGetFunctionAttributes) {
   using apache::geode::client::TcrMessageGetFunctionAttributes;
 
   TcrMessageGetFunctionAttributes message(
@@ -408,7 +408,7 @@ TEST_F(TcrMessageTest, testConstructorGET_FUNCTION_ATTRIBUTES) {
       message);
 }
 
-TEST_F(TcrMessageTest, testConstructorKEY_SET) {
+TEST_F(TcrMessageTest, testConstructorKeySet) {
   using apache::geode::client::TcrMessageKeySet;
 
   TcrMessageKeySet message(new DataOutputUnderTest(),
@@ -423,30 +423,28 @@ TEST_F(TcrMessageTest, testConstructorKEY_SET) {
       message);
 }
 
-TEST_F(TcrMessageTest, testConstructor6WithCREATE_REGION) {
+TEST_F(TcrMessageTest, testConstructor6WithCreateRegion) {
   using apache::geode::client::TcrMessageCreateRegion;
 
-  TcrMessageCreateRegion message(new DataOutputUnderTest(),
-                                 "str1",  // TODO: what does this parameter do?!
-                                 "str2",  // TODO: what does this parameter do?!
-                                 false,   // isDurable
-                                 false,   // receiveValues
+  TcrMessageCreateRegion message(new DataOutputUnderTest(), "parentRegionName",
+                                 "regionName",
+                                 false,  // isDurable
+                                 false,  // receiveValues
                                  static_cast<ThinClientBaseDM *>(nullptr));
 
   EXPECT_EQ(TcrMessage::CREATE_REGION, message.getMessageType());
 
   EXPECT_MESSAGE_EQ(
-      "0000001D0000001200000002FFFFFFFF00000000040073747231000000040073747232",
+      "0000001D0000002400000002FFFFFFFF000000001000706172656E74526567696F6E4E61"
+      "6D650000000A00726567696F6E4E616D65",
       message);
 }
 
-TEST_F(TcrMessageTest, testConstructor6WithREGISTER_INTEREST) {
-  using apache::geode::client::TcrMessageRegisterInterest;
+TEST_F(TcrMessageTest, testConstructor6WithRegisterInterest) {
+  using apache::geode::client::TcrMessageRegisterInterestRegex;
 
-  TcrMessageRegisterInterest message(
-      new DataOutputUnderTest(),
-      "str1",  // TODO: what does this parameter do?!
-      "str2",  // TODO: what does this parameter do?!
+  TcrMessageRegisterInterestRegex message(
+      new DataOutputUnderTest(), "regionName", "regexString",
       InterestResultPolicy::NONE,
       false,  // isDurable
       false,  // isCacheingEnabled
@@ -456,32 +454,109 @@ TEST_F(TcrMessageTest, testConstructor6WithREGISTER_INTEREST) {
   EXPECT_EQ(TcrMessage::REGISTER_INTEREST, message.getMessageType());
 
   EXPECT_MESSAGE_EQ(
-      "000000140000003600000007FFFFFFFF0000000004007374723100000004000000000100"
-      "0000030101250000000001000000000004007374723200000001000100000002000000",
+      "000000140000004300000007FFFFFFFF000000000A00726567696F6E4E616D6500000004"
+      "000000000100000003010125000000000100000000000B007265676578537472696E6700"
+      "000001000100000002000000",
       message);
-}
 
-TEST_F(TcrMessageTest, testConstructor6WithUNREGISTER_INTEREST) {
-  using apache::geode::client::TcrMessageUnregisterInterest;
+  TcrMessageRegisterInterestRegex message2(
+      new DataOutputUnderTest(), "regionName", "regexString",
+      InterestResultPolicy::NONE,
+      true,   // isDurable
+      false,  // isCacheingEnabled
+      false,  // receiveValues
+      static_cast<ThinClientBaseDM *>(nullptr));
 
-  TcrMessageUnregisterInterest message(
-      new DataOutputUnderTest(),
-      "str1",  // TODO: what does this parameter do?!
-      "str2",  // TODO: what does this parameter do?!
+  EXPECT_EQ(TcrMessage::REGISTER_INTEREST, message2.getMessageType());
+
+  EXPECT_MESSAGE_EQ(
+      "000000140000004300000007FFFFFFFF000000000A00726567696F6E4E616D6500000004"
+      "000000000100000003010125000000000100010000000B007265676578537472696E6700"
+      "000001000100000002000000",
+      message2);
+
+  TcrMessageRegisterInterestRegex message3(
+      new DataOutputUnderTest(), "regionName", "regexString",
       InterestResultPolicy::NONE,
       false,  // isDurable
+      true,   // isCacheingEnabled
       false,  // receiveValues
       static_cast<ThinClientBaseDM *>(nullptr));
 
+  EXPECT_EQ(TcrMessage::REGISTER_INTEREST, message3.getMessageType());
+
+  EXPECT_MESSAGE_EQ(
+      "000000140000004300000007FFFFFFFF000000000A00726567696F6E4E616D6500000004"
+      "000000000100000003010125000000000100000000000B007265676578537472696E6700"
+      "000001000100000002000100",
+      message3);
+
+  TcrMessageRegisterInterestRegex message4(
+      new DataOutputUnderTest(), "regionName", "regexString",
+      InterestResultPolicy::NONE,
+      false,  // isDurable
+      false,  // isCacheingEnabled
+      true,   // receiveValues
+      static_cast<ThinClientBaseDM *>(nullptr));
+
+  EXPECT_EQ(TcrMessage::REGISTER_INTEREST, message4.getMessageType());
+
+  EXPECT_MESSAGE_EQ(
+      "000000140000004300000007FFFFFFFF000000000A00726567696F6E4E616D6500000004"
+      "000000000100000003010125000000000100000000000B007265676578537472696E6700"
+      "000001000000000002000000",
+      message4);
+
+  TcrMessageRegisterInterestRegex message5(
+      new DataOutputUnderTest(), "regionName", "regexString",
+      InterestResultPolicy::KEYS,
+      true,  // isDurable
+      true,  // isCacheingEnabled
+      true,  // receiveValues
+      static_cast<ThinClientBaseDM *>(nullptr));
+
+  EXPECT_EQ(TcrMessage::REGISTER_INTEREST, message5.getMessageType());
+
+  EXPECT_MESSAGE_EQ(
+      "000000140000004300000007FFFFFFFF000000000A00726567696F6E4E616D6500000004"
+      "000000000100000003010125010000000100010000000B007265676578537472696E6700"
+      "000001000000000002000100",
+      message5);
+
+  TcrMessageRegisterInterestRegex message6(
+      new DataOutputUnderTest(), "regionName", "regexString",
+      InterestResultPolicy::KEYS_VALUES,
+      true,  // isDurable
+      true,  // isCacheingEnabled
+      true,  // receiveValues
+      static_cast<ThinClientBaseDM *>(nullptr));
+
+  EXPECT_EQ(TcrMessage::REGISTER_INTEREST, message6.getMessageType());
+
+  EXPECT_MESSAGE_EQ(
+      "000000140000004300000007FFFFFFFF000000000A00726567696F6E4E616D6500000004"
+      "000000000100000003010125020000000100010000000B007265676578537472696E6700"
+      "000001000000000002000100",
+      message6);
+}
+
+TEST_F(TcrMessageTest, testConstructor6WithUnregisterInterest) {
+  using apache::geode::client::TcrMessageUnregisterInterestRegex;
+
+  TcrMessageUnregisterInterestRegex message(
+      new DataOutputUnderTest(), "regionName", "regexString",
+      false,  // isDurable
+      static_cast<ThinClientBaseDM *>(nullptr));
+
   EXPECT_EQ(TcrMessage::UNREGISTER_INTEREST, message.getMessageType());
 
   EXPECT_MESSAGE_EQ(
-      "000000160000002700000005FFFFFFFF0000000004007374723100000004000000000100"
-      "0000040073747232000000010000000000010000",
+      "000000160000003400000005FFFFFFFF000000000A00726567696F6E4E616D6500000004"
+      "00000000010000000B007265676578537472696E67000000010000000000010000",
       message);
 }
 
-TEST_F(TcrMessageTest, testConstructorGET_PDX_TYPE_BY_ID) {
+TEST_F(TcrMessageTest, testConstructorGetPdxTypeById) {
   using apache::geode::client::TcrMessageGetPdxTypeById;
 
   TcrMessageGetPdxTypeById message(new DataOutputUnderTest(), 42,
@@ -493,7 +568,7 @@ TEST_F(TcrMessageTest, testConstructorGET_PDX_TYPE_BY_ID) {
                     message);
 }
 
-TEST_F(TcrMessageTest, testConstructorGET_PDX_ENUM_BY_ID) {
+TEST_F(TcrMessageTest, testConstructorGetPdxEnumById) {
   using apache::geode::client::TcrMessageGetPdxEnumById;
 
   TcrMessageGetPdxEnumById message(new DataOutputUnderTest(), 42,
@@ -505,7 +580,7 @@ TEST_F(TcrMessageTest, testConstructorGET_PDX_ENUM_BY_ID) {
                     message);
 }
 
-TEST_F(TcrMessageTest, testConstructorGET_PDX_ID_FOR_TYPE) {
+TEST_F(TcrMessageTest, testConstructorGetPdxIdForType) {
   using apache::geode::client::TcrMessageGetPdxIdForType;
 
   std::shared_ptr<Cacheable> myPtr(CacheableString::createDeserializable());
@@ -518,7 +593,7 @@ TEST_F(TcrMessageTest, testConstructorGET_PDX_ID_FOR_TYPE) {
                     message);
 }
 
-TEST_F(TcrMessageTest, testConstructorADD_PDX_TYPE) {
+TEST_F(TcrMessageTest, testConstructorAddPdxType) {
   using apache::geode::client::TcrMessageAddPdxType;
 
   std::shared_ptr<Cacheable> myPtr(CacheableString::createDeserializable());
@@ -532,7 +607,7 @@ TEST_F(TcrMessageTest, testConstructorADD_PDX_TYPE) {
       message);
 }
 
-TEST_F(TcrMessageTest, testConstructorGET_PDX_ID_FOR_ENUM) {
+TEST_F(TcrMessageTest, testConstructorGetPdxIdForEnum) {
   using apache::geode::client::TcrMessageGetPdxIdForEnum;
 
   TcrMessageGetPdxIdForEnum message(
@@ -545,11 +620,9 @@ TEST_F(TcrMessageTest, testConstructorGET_PDX_ID_FOR_ENUM) {
   EXPECT_MESSAGE_EQ("000000610000000600000001FFFFFFFF00000000010129", message);
 }
 
-TEST_F(TcrMessageTest, testConstructorADD_PDX_ENUM) {
+TEST_F(TcrMessageTest, testConstructorAddPdxEnum) {
   using apache::geode::client::TcrMessageAddPdxEnum;
 
-  std::shared_ptr<Cacheable> myPtr(CacheableString::createDeserializable());
-
   TcrMessageAddPdxEnum message(new DataOutputUnderTest(),
                                static_cast<std::shared_ptr<Cacheable>>(nullptr),
                                static_cast<ThinClientBaseDM *>(nullptr), 42);
@@ -574,7 +647,7 @@ TEST_F(TcrMessageTest, testConstructorEventId) {
   EXPECT_MESSAGE_EQ("000000440000000600000001FFFFFFFF00000000010129", message);
 }
 
-TEST_F(TcrMessageTest, testConstructorREMOVE_USER_AUTH) {
+TEST_F(TcrMessageTest, testConstructorRemoveUserAuth) {
   using apache::geode::client::TcrMessageRemoveUserAuth;
 
   TcrMessageRemoveUserAuth message(new DataOutputUnderTest(), true,
@@ -592,7 +665,7 @@ TEST_F(TcrMessageTest, testConstructorREMOVE_USER_AUTH) {
   EXPECT_MESSAGE_EQ("0000004E0000000600000001FFFFFFFF00000000010000", message2);
 }
 
-TEST_F(TcrMessageTest, testConstructorUSER_CREDENTIAL_MESSAGE) {
+TEST_F(TcrMessageTest, testConstructorUserCredential) {
   using apache::geode::client::Properties;
   using apache::geode::client::TcrMessageUserCredential;
 
@@ -607,7 +680,7 @@ TEST_F(TcrMessageTest, testConstructorUSER_CREDENTIAL_MESSAGE) {
   EXPECT_MESSAGE_EQ("", message);
 }
 
-TEST_F(TcrMessageTest, testConstructorGET_CLIENT_PARTITION_ATTRIBUTES) {
+TEST_F(TcrMessageTest, testConstructorGetClientPartitionAttributes) {
   using apache::geode::client::TcrMessageGetClientPartitionAttributes;
 
   TcrMessageGetClientPartitionAttributes message(new DataOutputUnderTest(),
@@ -622,7 +695,7 @@ TEST_F(TcrMessageTest, testConstructorGET_CLIENT_PARTITION_ATTRIBUTES) {
       message);
 }
 
-TEST_F(TcrMessageTest, testConstructorGET_CLIENT_PR_METADATA) {
+TEST_F(TcrMessageTest, testConstructorGetClientPrMetadata) {
   using apache::geode::client::TcrMessageGetClientPrMetadata;
 
   TcrMessageGetClientPrMetadata message(new DataOutputUnderTest(),
@@ -635,7 +708,7 @@ TEST_F(TcrMessageTest, testConstructorGET_CLIENT_PR_METADATA) {
       "6F6E50524D455441",
       message);
 }
-TEST_F(TcrMessageTest, testConstructorSIZE) {
+TEST_F(TcrMessageTest, testConstructorSize) {
   using apache::geode::client::TcrMessageSize;
 
   TcrMessageSize message(new DataOutputUnderTest(), "testClientRegionSIZE");
@@ -648,7 +721,7 @@ TEST_F(TcrMessageTest, testConstructorSIZE) {
       message);
 }
 
-TEST_F(TcrMessageTest, testConstructorEXECUTE_REGION_FUNCTION_SINGLE_HOP) {
+TEST_F(TcrMessageTest, testConstructorExecuteRegionFunctionSingleHop) {
   using apache::geode::client::TcrMessageExecuteRegionFunctionSingleHop;
 
   const Region *region = nullptr;
@@ -676,7 +749,7 @@ TEST_F(TcrMessageTest, testConstructorEXECUTE_REGION_FUNCTION_SINGLE_HOP) {
   EXPECT_TRUE(message.hasResult());
 }
 
-TEST_F(TcrMessageTest, testConstructorEXECUTE_REGION_FUNCTION) {
+TEST_F(TcrMessageTest, testConstructorExecuteRegionFunction) {
   using apache::geode::client::TcrMessageExecuteRegionFunction;
 
   const Region *region = nullptr;
@@ -705,7 +778,7 @@ TEST_F(TcrMessageTest, testConstructorEXECUTE_REGION_FUNCTION) {
   EXPECT_TRUE(testMessage.hasResult());
 }
 
-TEST_F(TcrMessageTest, DISABLED_testConstructorEXECUTE_FUNCTION) {
+TEST_F(TcrMessageTest, DISABLED_testConstructorExecuteFunction) {
   using apache::geode::client::TcrMessageExecuteFunction;
 
   std::shared_ptr<Cacheable> myCacheablePtr(
@@ -725,7 +798,7 @@ TEST_F(TcrMessageTest, DISABLED_testConstructorEXECUTE_FUNCTION) {
       testMessage);
 }
 
-TEST_F(TcrMessageTest, testConstructorEXECUTECQ_MSG_TYPE) {
+TEST_F(TcrMessageTest, testConstructorExecuteCq) {
   using apache::geode::client::TcrMessageExecuteCq;
 
   std::shared_ptr<Cacheable> myCacheablePtr(
@@ -744,12 +817,9 @@ TEST_F(TcrMessageTest, testConstructorEXECUTECQ_MSG_TYPE) {
       testMessage);
 }
 
-TEST_F(TcrMessageTest, testConstructorWithGinormousQueryEXECUTECQ_MSG_TYPE) {
+TEST_F(TcrMessageTest, testConstructorWithGinormousQueryExecuteCq) {
   using apache::geode::client::TcrMessageExecuteCq;
 
-  std::shared_ptr<Cacheable> myCacheablePtr(
-      CacheableString::createDeserializable());
-
   std::ostringstream oss;
   oss << "select * from /somewhere s where s.data.id in SET(";
   // Ensure over 64KiB of query string.
@@ -778,12 +848,9 @@ TEST_F(TcrMessageTest, testConstructorWithGinormousQueryEXECUTECQ_MSG_TYPE) {
       testMessage);
 }
 
-TEST_F(TcrMessageTest, testConstructorEXECUTECQ_WITH_IR_MSG_TYPE) {
+TEST_F(TcrMessageTest, testConstructorExecuteCqWithIr) {
   using apache::geode::client::TcrMessageExecuteCqWithIr;
 
-  std::shared_ptr<Cacheable> myCacheablePtr(
-      CacheableString::createDeserializable());
-
   TcrMessageExecuteCqWithIr testMessage(
       new DataOutputUnderTest(), "ExecuteCQWithIr", "select * from /somewhere",
       CqState::RUNNING, false, static_cast<ThinClientBaseDM *>(nullptr));
@@ -798,26 +865,25 @@ TEST_F(TcrMessageTest, testConstructorEXECUTECQ_WITH_IR_MSG_TYPE) {
       testMessage);
 }
 
-TEST_F(TcrMessageTest, testConstructorPING) {
+TEST_F(TcrMessageTest, testConstructorPing) {
   using apache::geode::client::TcrMessagePing;
 
-  std::shared_ptr<Cacheable> myCacheablePtr(
-      CacheableString::createDeserializable());
-
-  TcrMessagePing testMessage(new DataOutputUnderTest(), false);
+  TcrMessagePing testMessage(
+      std::unique_ptr<DataOutput>(new DataOutputUnderTest()));
 
   EXPECT_EQ(TcrMessage::PING, testMessage.getMessageType());
 
   EXPECT_MESSAGE_EQ("000000050000000000000000FFFFFFFF00", testMessage);
 }
 
-TEST_F(TcrMessageTest, testConstructorCLOSE_CONNECTION) {
+TEST_F(TcrMessageTest, testConstructorCloseConnection) {
   using apache::geode::client::TcrMessageCloseConnection;
 
   std::shared_ptr<Cacheable> myCacheablePtr(
       CacheableString::createDeserializable());
 
-  TcrMessageCloseConnection testMessage(new DataOutputUnderTest(), false);
+  TcrMessageCloseConnection testMessage(
+      std::unique_ptr<DataOutput>(new DataOutputUnderTest()), false);
 
   EXPECT_EQ(TcrMessage::CLOSE_CONNECTION, testMessage.getMessageType());
 
@@ -825,4 +891,19 @@ TEST_F(TcrMessageTest, testConstructorCLOSE_CONNECTION) {
                     testMessage);
 }
 
+TEST_F(TcrMessageTest, testConstructorCloseConnectionKeepAlive) {
+  using apache::geode::client::TcrMessageCloseConnection;
+
+  std::shared_ptr<Cacheable> myCacheablePtr(
+      CacheableString::createDeserializable());
+
+  TcrMessageCloseConnection testMessage(
+      std::unique_ptr<DataOutput>(new DataOutputUnderTest()), true);
+
+  EXPECT_EQ(TcrMessage::CLOSE_CONNECTION, testMessage.getMessageType());
+
+  EXPECT_MESSAGE_EQ("000000120000000600000001FFFFFFFF00000000010001",
+                    testMessage);
+}
+
 }  // namespace
