@@ -17,6 +17,14 @@
 
 set -x -e -o pipefail
 
-apt-get -y install clang-format-6.0
+. /etc/os-release
 
-ln -s /usr/bin/clang-format-6.0 /usr/bin/clang-format
\ No newline at end of file
+CLANG_VERSION=11
+
+wget -O - https://apt.llvm.org/llvm-snapshot.gpg.key | apt-key add -
+apt-add-repository "deb http://apt.llvm.org/${VERSION_CODENAME}/ llvm-toolchain-${VERSION_CODENAME}-${CLANG_VERSION} main"
+
+apt-get update
+apt-get -y install clang-format-${CLANG_VERSION}
+
+update-alternatives --install /usr/bin/clang-format    clang-format    /usr/bin/clang-format-${CLANG_VERSION} 10
