@@ -928,10 +928,11 @@ namespace PdxVersionTests
       return false;
     }
 
-    //public override int GetHashCode()
-    //{
-    //  return _id.GetHashCode();
-    //}
+    public override int GetHashCode()
+    {
+      return base.GetHashCode();
+    }
+
     #region IPdxSerializer Members
 
     public object FromData(string classname, IPdxReader reader)
@@ -1584,6 +1585,13 @@ namespace PdxVersionTests
                 throw new Exception("pdx enum is not equal");
             return true;
         }
+
+
+        public override int GetHashCode()
+        {
+            return base.GetHashCode();
+        }
+
         public void FromData(IPdxReader reader)
         {
             //byte[][] baa = reader.ReadArrayOfByteArrays("m_byteByteArray");
